@@ -1,23 +1,17 @@
-/* Copyright (C) 1996, 2001, Ghostgum Software Pty Ltd.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
+  
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
+*/
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
-
- */
-
-
-/* $Id: dwdll.h,v 1.3.2.1.2.1 2003/01/17 00:49:00 giles Exp $*/
+/* $Id: dwdll.h 8022 2007-06-05 22:23:38Z giles $*/
 
 /* gsdll structure for MS-Windows */
 
@@ -41,6 +35,7 @@ typedef struct GSDLL_S {
 	PFN_gsapi_init_with_args init_with_args;
 	PFN_gsapi_run_string run_string;
 	PFN_gsapi_exit exit;
+        PFN_gsapi_set_visual_tracer set_visual_tracer;
 } GSDLL;
 
 /* Load the Ghostscript DLL.
