@@ -1,23 +1,17 @@
-/* Copyright (C) 1996-2001 Ghostgum Software Pty Ltd.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-
-/* $Id: dwtext.c,v 1.5.2.1.2.1 2003/01/17 00:49:00 giles Exp $ */
+/* $Id: dwtext.c 8022 2007-06-05 22:23:38Z giles $ */
 
 /* Microsoft Windows text window for Ghostscript.
 
@@ -448,7 +442,8 @@ int n;
     while (cnt>0) {
 	p = tw->ScreenBuffer + tw->CursorPos.y*tw->ScreenSize.x + tw->CursorPos.x;
 	limit = tw->ScreenSize.x - tw->CursorPos.x;
-	for (count=0; (count < limit) && (cnt>0) && (isprint(*str) || *str=='\t'); count++) {
+	for (count=0; (count < limit) && (cnt>0) && 
+	    (isprint((unsigned char)(*str)) || *str=='\t'); count++) {
 	    if (*str=='\t') {
 		for (n = 8 - ((tw->CursorPos.x+count) % 8); (count < limit) & (n>0); n--, count++ )
 		    *p++ = ' ';
@@ -469,7 +464,7 @@ int n;
 		str++;
 		cnt--;
 	    }
-	    else if (!isprint(*str) && *str!='\t') {
+	    else if (!isprint((unsigned char)(*str)) && *str!='\t') {
 		text_putch(tw, *str++);
 		cnt--;
 	    }
@@ -908,58 +903,31 @@ WndTextProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 	    }
 	    return(0);
 	case WM_KEYDOWN:
-	    if (GetKeyState(VK_SHIFT) < 0) {
-	      switch(wParam) {
-		case VK_HOME:
-			SendMessage(hwnd, WM_VSCROLL, SB_TOP, (LPARAM)0);
-			break;
-		case VK_END:
-			SendMessage(hwnd, WM_VSCROLL, SB_BOTTOM, (LPARAM)0);
-			break;
-		case VK_PRIOR:
-			SendMessage(hwnd, WM_VSCROLL, SB_PAGEUP, (LPARAM)0);
-			break;
-		case VK_NEXT:
-			SendMessage(hwnd, WM_VSCROLL, SB_PAGEDOWN, (LPARAM)0);
-			break;
-		case VK_UP:
-			SendMessage(hwnd, WM_VSCROLL, SB_LINEUP, (LPARAM)0);
-			break;
-		case VK_DOWN:
-			SendMessage(hwnd, WM_VSCROLL, SB_LINEDOWN, (LPARAM)0);
-			break;
-		case VK_LEFT:
-			SendMessage(hwnd, WM_HSCROLL, SB_LINEUP, (LPARAM)0);
-			break;
-		case VK_RIGHT:
-			SendMessage(hwnd, WM_HSCROLL, SB_LINEDOWN, (LPARAM)0);
-			break;
-	      }
-	    }
-	    else {
-	        switch(wParam) {
-		    case VK_HOME:
-		    case VK_END:
-		    case VK_PRIOR:
-		    case VK_NEXT:
-		    case VK_UP:
-		    case VK_DOWN:
-		    case VK_LEFT:
-		    case VK_RIGHT:
-		    case VK_DELETE:
-		    { /* store key in circular buffer */
-			long count = tw->KeyBufIn - tw->KeyBufOut;
-			if (count < 0) count += tw->KeyBufSize;
-			if (count < tw->KeyBufSize-2) {
-			    *tw->KeyBufIn++ = 0;
-			    if (tw->KeyBufIn - tw->KeyBuf >= tw->KeyBufSize)
-				tw->KeyBufIn = tw->KeyBuf; /* wrap around */
-			    *tw->KeyBufIn++ = HIWORD(lParam) & 0xff;
-			    if (tw->KeyBufIn - tw->KeyBuf >= tw->KeyBufSize)
-				tw->KeyBufIn = tw->KeyBuf; /* wrap around */
-			}
-		    }
-	        }
+	    switch(wParam) {
+	      case VK_HOME:
+		      SendMessage(hwnd, WM_VSCROLL, SB_TOP, (LPARAM)0);
+		      break;
+	      case VK_END:
+		      SendMessage(hwnd, WM_VSCROLL, SB_BOTTOM, (LPARAM)0);
+		      break;
+	      case VK_PRIOR:
+		      SendMessage(hwnd, WM_VSCROLL, SB_PAGEUP, (LPARAM)0);
+		      break;
+	      case VK_NEXT:
+		      SendMessage(hwnd, WM_VSCROLL, SB_PAGEDOWN, (LPARAM)0);
+		      break;
+	      case VK_UP:
+		      SendMessage(hwnd, WM_VSCROLL, SB_LINEUP, (LPARAM)0);
+		      break;
+	      case VK_DOWN:
+		      SendMessage(hwnd, WM_VSCROLL, SB_LINEDOWN, (LPARAM)0);
+		      break;
+	      case VK_LEFT:
+		      SendMessage(hwnd, WM_HSCROLL, SB_LINEUP, (LPARAM)0);
+		      break;
+	      case VK_RIGHT:
+		      SendMessage(hwnd, WM_HSCROLL, SB_LINEDOWN, (LPARAM)0);
+		      break;
 	    }
 	    break;
 	case WM_CHAR:
