@@ -10,7 +10,7 @@
    or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
-/* $Id: gdevddrw.c 8250 2007-09-25 13:31:24Z giles $ */
+/* $Id: gdevddrw.c 8517 2008-02-04 22:18:08Z leonardo $ */
 /* Default polygon and image drawing device procedures */
 #include "math_.h"
 #include "memory_.h"
@@ -606,6 +606,8 @@ gx_default_fill_parallelogram(gx_device * dev,
 	gs_int_rect r;
 
 	INT_RECT_FROM_PARALLELOGRAM(&r, px, py, ax, ay, bx, by);
+	vd_rect(int2fixed(r.p.x), int2fixed(r.p.y), int2fixed(r.q.x), int2fixed(r.q.y),
+		    1, (int)pdevc->colors.pure);
 	return gx_fill_rectangle_device_rop(r.p.x, r.p.y, r.q.x - r.p.x,
 					    r.q.y - r.p.y, pdevc, dev, lop);
     }
