@@ -1,22 +1,16 @@
-/* Copyright (C) 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
-
-/*$Id: gdevdgbr.c,v 1.2.6.1.2.1 2003/01/17 00:49:00 giles Exp $ */
+/* $Id: gdevdgbr.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Default implementation of device get_bits[_rectangle] */
 #include "memory_.h"
 #include "gx.h"
@@ -66,7 +60,7 @@ gx_default_get_bits(gx_device * dev, int y, byte * data, byte ** actual_data)
  * Determine whether we can satisfy a request by simply using the stored
  * representation.  dev is used only for color_info.{num_components, depth}.
  */
-private bool
+static bool
 requested_includes_stored(const gx_device *dev,
 			  const gs_get_bits_params_t *requested,
 			  const gs_get_bits_params_t *stored)
@@ -172,7 +166,7 @@ gx_get_bits_return_pointer(gx_device * dev, int x, int h,
 		    bytes = bit_offset / step * step;
 		} else {
 		    /* Use a faster algorithm if depth is a power of 2. */
-		    bytes = bit_offset & (-depth & -align_mod);
+		    bytes = bit_offset & (-depth & -(int)align_mod);
 		}
 		base = stored_base + arith_rshift(bytes, 3);
 		params->x_offset = (bit_offset - bytes) / depth;
@@ -209,7 +203,7 @@ gx_get_bits_return_pointer(gx_device * dev, int x, int h,
  * Implement gx_get_bits_copy (see below) for the case of converting
  * 4-bit CMYK to 24-bit RGB with standard mapping, used heavily by PCL.
  */
-private void
+static void
 gx_get_bits_copy_cmyk_1bit(byte *dest_line, uint dest_raster,
 			   const byte *src_line, uint src_raster,
 			   int src_bit, int w, int h)
@@ -252,17 +246,17 @@ gx_get_bits_copy_cmyk_1bit(byte *dest_line, uint dest_raster,
  * factored out into single-use procedures strictly for readability.
  * A good optimizing compiler would compile them in-line.
  */
-private int
-    gx_get_bits_std_to_native(P10(gx_device * dev, int x, int w, int h,
+static int
+    gx_get_bits_std_to_native(gx_device * dev, int x, int w, int h,
 				  gs_get_bits_params_t * params,
-				  const gs_get_bits_params_t *stored,
-				  const byte * src_base, uint dev_raster,
-				  int x_offset, uint raster)),
-    gx_get_bits_native_to_std(P11(gx_device * dev, int x, int w, int h,
-				  gs_get_bits_params_t * params,
-				  const gs_get_bits_params_t *stored,
-				  const byte * src_base, uint dev_raster,
-				  int x_offset, uint raster, uint std_raster));
+			      const gs_get_bits_params_t *stored,
+			      const byte * src_base, uint dev_raster,
+			      int x_offset, uint raster),
+    gx_get_bits_native_to_std(gx_device * dev, int x, int w, int h,
+			      gs_get_bits_params_t * params,
+			      const gs_get_bits_params_t *stored,
+			      const byte * src_base, uint dev_raster,
+			      int x_offset, uint raster, uint std_raster);
 int
 gx_get_bits_copy(gx_device * dev, int x, int w, int h,
 		 gs_get_bits_params_t * params,
@@ -326,6 +320,7 @@ gx_get_bits_copy(gx_device * dev, int x, int w, int h,
 	     */
 	    gx_device_memory tdev;
 	    byte *line_ptr = data;
+	    int bit_w = w * depth;
 
 	    tdev.line_ptrs = &tdev.base;
 	    for (; h > 0; line_ptr += raster, src += dev_raster, --h) {
@@ -333,9 +328,12 @@ gx_get_bits_copy(gx_device * dev, int x, int w, int h,
 		int align = ALIGNMENT_MOD(line_ptr, align_bitmap_mod);
 
 		tdev.base = line_ptr - align;
+		/* set up parameters required by copy_mono's fit_copy */
+		tdev.width = dest_bit_x + (align << 3) + bit_w;
+		tdev.height = 1;
 		(*dev_proc(&mem_mono_device, copy_mono))
 		    ((gx_device *) & tdev, src, bit_x, dev_raster, gx_no_bitmap_id,
-		     dest_bit_x + (align << 3), 0, w, 1,
+		     dest_bit_x + (align << 3), 0, bit_w, 1,
 		     (gx_color_index) 0, (gx_color_index) 1);
 	    }
 	} else if (options & ~stored_options & GB_COLORS_NATIVE) {
@@ -398,7 +396,7 @@ gx_get_bits_copy(gx_device * dev, int x, int w, int h,
  * Convert standard colors to native.  Note that the source
  * may have depths other than 8 bits per component.
  */
-private int
+static int
 gx_get_bits_std_to_native(gx_device * dev, int x, int w, int h,
 			  gs_get_bits_params_t * params,
 			  const gs_get_bits_params_t *stored,
@@ -430,44 +428,67 @@ gx_get_bits_std_to_native(gx_device * dev, int x, int w, int h,
 	sample_store_declare_setup(dest, dbit, dbyte, dest_line,
 				   dest_bit_offset & 7, depth);
 
-	for (i = 0; i < w; ++i) {
-	    int j;
-	    gx_color_value v[4], va = alpha_default;
-	    gx_color_index pixel;
+#define v2frac(value) ((long)(value) * frac_1 / src_max)
 
-	    /* Fetch the source data. */
-	    if (stored->options & GB_ALPHA_FIRST) {
-		sample_load_next16(va, src, sbit, src_depth);
-		va = v2cv(va);
-	    }
-	    for (j = 0; j < ncolors; ++j) {
-		gx_color_value vj;
+        for (i = 0; i < w; ++i) {
+            int j;
+            frac sc[4], dc[GX_DEVICE_COLOR_MAX_COMPONENTS];
+            gx_color_value v[GX_DEVICE_COLOR_MAX_COMPONENTS], va = alpha_default;
+            gx_color_index pixel;
+            bool do_alpha = false;
+            const gx_cm_color_map_procs * map_procs;
 
-		sample_load_next16(vj, src, sbit, src_depth);
-		v[j] = v2cv(vj);
-	    }
-	    if (stored->options & GB_ALPHA_LAST) {
-		sample_load_next16(va, src, sbit, src_depth);
-		va = v2cv(va);
-	    }
-	    /* Convert and store the pixel value. */
-	    switch (ncolors) {
-	    case 1:
-		v[2] = v[1] = v[0];
-	    case 3:
-		pixel = (*dev_proc(dev, map_rgb_alpha_color))
-		    (dev, v[0], v[1], v[2], va);
-		break;
-	    case 4:
-		/****** NO ALPHA FOR CMYK ******/
-		pixel = (*dev_proc(dev, map_cmyk_color))
-		    (dev, v[0], v[1], v[2], v[3]);
-		break;
-	    default:
-		return_error(gs_error_rangecheck);
-	    }
-	    sample_store_next32(pixel, dest, dbit, depth, dbyte);
-	}
+            map_procs = dev_proc(dev, get_color_mapping_procs)(dev);
+
+            /* Fetch the source data. */
+            if (stored->options & GB_ALPHA_FIRST) {
+                sample_load_next16(va, src, sbit, src_depth);
+                va = v2cv(va);
+                do_alpha = true;
+            }
+            for (j = 0; j < ncolors; ++j) {
+                gx_color_value vj;
+
+                sample_load_next16(vj, src, sbit, src_depth);
+                sc[j] = v2frac(vj);
+            }
+            if (stored->options & GB_ALPHA_LAST) {
+                sample_load_next16(va, src, sbit, src_depth);
+                va = v2cv(va);
+                do_alpha = true;
+            }
+
+            /* Convert and store the pixel value. */
+            if (do_alpha) {
+                for (j = 0; j < ncolors; j++)
+                    v[j] = frac2cv(sc[j]);
+                if (ncolors == 1)
+                    v[2] = v[1] = v[0];
+                pixel = dev_proc(dev, map_rgb_alpha_color)
+                    (dev, v[0], v[1], v[2], va);
+            } else {
+
+                switch (ncolors) {
+                case 1:
+                    map_procs->map_gray(dev, sc[0], dc);
+                    break;
+                case 3:
+                    map_procs->map_rgb(dev, 0, sc[0], sc[1], sc[2], dc);
+                    break;
+                case 4:
+                    map_procs->map_cmyk(dev, sc[0], sc[1], sc[2], sc[3], dc);
+                    break;
+                default:
+                    return_error(gs_error_rangecheck);
+                }
+
+                for (j = 0; j < dev->color_info.num_components; j++)
+                    v[j] = frac2cv(dc[j]);
+
+                pixel = dev_proc(dev, encode_color)(dev, v);
+            }
+            sample_store_next_any(pixel, dest, dbit, depth, dbyte);
+        }
 	sample_store_flush(dest, dbit, depth, dbyte);
     }
     return 0;
@@ -476,7 +497,7 @@ gx_get_bits_std_to_native(gx_device * dev, int x, int w, int h,
 /*
  * Convert native colors to standard.  Only GB_DEPTH_8 is supported.
  */
-private int
+static int
 gx_get_bits_native_to_std(gx_device * dev, int x, int w, int h,
 			  gs_get_bits_params_t * params,
 			  const gs_get_bits_params_t *stored,
@@ -545,7 +566,7 @@ gx_get_bits_native_to_std(gx_device * dev, int x, int w, int h,
 	    gx_color_index pixel = 0;
 	    gx_color_value rgba[4];
 
-	    sample_load_next32(pixel, src, bit, depth);
+	    sample_load_next_any(pixel, src, bit, depth);
 	    if (pixel < 16) {
 		if (mapped[pixel]) {
 		    /* Use the value from the cache. */
@@ -644,11 +665,13 @@ gx_default_get_bits_rectangle(gx_device * dev, const gs_int_rect * prect,
 		goto ret;
 	    }
 	}
-	code = (*dev_proc(dev, get_bits))
-	    (dev, prect->p.y, row, &params->data[0]);
+	code = (*dev_proc(dev, get_bits)) (dev, prect->p.y, row,
+		(params->options & GB_RETURN_POINTER) ? &params->data[0]
+						      : NULL );
 	if (code >= 0) {
 	    if (row != data) {
-		if (prect->p.x == 0 && params->data[0] != row) {
+		if (prect->p.x == 0 && params->data[0] != row
+		    && params->options & GB_RETURN_POINTER) {
 		    /*
 		     * get_bits returned an appropriate pointer: we can
 		     * avoid doing any copying.
@@ -664,7 +687,7 @@ gx_default_get_bits_rectangle(gx_device * dev, const gs_int_rect * prect,
 		    tdev.line_ptrs = &tdev.base;
 		    tdev.base = data;
 		    code = (*dev_proc(&mem_mono_device, copy_mono))
-			((gx_device *) & tdev, params->data[0], prect->p.x * depth,
+			((gx_device *) & tdev, row, prect->p.x * depth,
 			 min_raster, gx_no_bitmap_id, 0, 0, width_bits, 1,
 			 (gx_color_index) 0, (gx_color_index) 1);
 		    params->data[0] = data;
@@ -748,51 +771,4 @@ gx_default_get_bits_rectangle(gx_device * dev, const gs_int_rect * prect,
     return (code < 0 ? code : 0);
 }
 
-/* ------ Debugging printout ------ */
 
-#ifdef DEBUG
-
-void
-debug_print_gb_options(gx_bitmap_format_t options)
-{
-    static const char *const option_names[] = {
-	GX_BITMAP_FORMAT_NAMES
-    };
-    const char *prev = "   ";
-    int i;
-
-    dlprintf1("0x%lx", (ulong) options);
-    for (i = 0; i < sizeof(options) * 8; ++i)
-	if ((options >> i) & 1) {
-	    dprintf2("%c%s",
-		     (!memcmp(prev, option_names[i], 3) ? '|' : ','),
-		     option_names[i]);
-	    prev = option_names[i];
-	}
-    dputc('\n');
-}
-
-void 
-debug_print_gb_planes(const gs_get_bits_params_t * params, int num_planes)
-{
-    gs_get_bits_options_t options = params->options;
-    int i;
-
-    debug_print_gb_options(options);
-    for (i = 0; i < num_planes; ++i)
-	dprintf2("data[%d]=0x%lx ", i, (ulong)params->data[i]);
-    if (options & GB_OFFSET_SPECIFIED)
-	dprintf1("x_offset=%d ", params->x_offset);
-    if (options & GB_RASTER_SPECIFIED)
-	dprintf1("raster=%u", params->raster);
-    dputc('\n');
-}
-
-void 
-debug_print_gb_params(const gs_get_bits_params_t * params)
-{
-    debug_print_gb_planes(params, 1);
-}
-
-
-#endif /* DEBUG */
