@@ -1,22 +1,16 @@
-/* Copyright (C) 1992, 1993, 1994, 1996 by artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
-
-*/
- 
-/*$Id: gdevimgn.c,v 1.4.2.1.2.1 2003/01/17 00:49:00 giles Exp $*/
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
+*/ 
+/* $Id: gdevimgn.c 8250 2007-09-25 13:31:24Z giles $*/
 /*
  * Imagen ImPRESS printer driver - version 1.4
  *
@@ -227,9 +221,9 @@
 /*-------------------------------------------*/ 
 /* The device descriptor */ 
 
-private dev_proc_print_page(imagen_print_page); 
-private dev_proc_open_device(imagen_prn_open);
-private dev_proc_close_device(imagen_prn_close);
+static dev_proc_print_page(imagen_print_page); 
+static dev_proc_open_device(imagen_prn_open);
+static dev_proc_close_device(imagen_prn_close);
 
 gx_device_procs imagen_procs =
 	prn_procs(imagen_prn_open, gdev_prn_output_page, imagen_prn_close);
@@ -250,7 +244,7 @@ const gx_device_printer far_data gs_imagen_device =
 /*-------------------------------------------*/ 
 
 /*-------------------------------------------*/ 
-private void 
+static void 
 iWrite(FILE *Out, byte Val) 
 { /* iWrite */ 
   char *hexList = "0123456789ABCDEF"; 
@@ -282,7 +276,7 @@ iWrite2(FILE *Out, int Val)
  
 /* --------------------------------------------------------- */ 
 
-private int
+static int
 imagen_prn_open(gx_device *pdev)
 { /* imagen_prn_open */
   int	code;
@@ -318,7 +312,7 @@ imagen_prn_open(gx_device *pdev)
   return code;
 } /* imagen_prn_open */
 
-private int
+static int
 imagen_prn_close(gx_device *pdev)
 { /* imagen_prn_close */
   int		code;
@@ -352,12 +346,12 @@ imagen_prn_close(gx_device *pdev)
 
 /*-------------------------------------------*/ 
 /* Send the page to the printer. */ 
-private int 
+static int 
 imagen_print_page(gx_device_printer *pdev, FILE *prn_stream) 
 { 
   int line_size = gdev_mem_bytes_per_scan_line((gx_device *)pdev); 
   /* input buffer: one line of bytes rasterized by gs */
-  byte *in = (byte *)gs_malloc(BIGSIZE, line_size / BIGSIZE + 1,
+  byte *in = (byte *)gs_malloc(pdev->memory, BIGSIZE, line_size / BIGSIZE + 1,
 	"imagen_print_page(in)"); 
   /* output buffer: 32 lines, interleaved into imPress swatches */
   byte *out; 
@@ -403,10 +397,10 @@ imagen_print_page(gx_device_printer *pdev, FILE *prn_stream)
   DebugMsg(2,"Swatch count = %d\n",swatchCount);
   DebugMsg(2,"Line size = %d\n",line_size );
 
-  out = (byte *)gs_malloc(TotalBytesPerSw , swatchCount + 1, 
+  out = (byte *)gs_malloc(pdev->memory, TotalBytesPerSw , swatchCount + 1, 
 		    "imagen_print_page(out)"); 
 
-  swatchMap = (byte *)gs_malloc(BIGSIZE,swatchCount / BIGSIZE + 1,
+  swatchMap = (byte *)gs_malloc(pdev->memory, BIGSIZE,swatchCount / BIGSIZE + 1,
 	"imagen_print_page(swatchMap)" );
  
   if ( in == 0 || out == 0 ) 
@@ -555,10 +549,10 @@ imagen_print_page(gx_device_printer *pdev, FILE *prn_stream)
  
   fflush(prn_stream); 
  
-  gs_free((char *)swatchMap, BIGSIZE, swatchCount / BIGSIZE + 1,
+  gs_free(pdev->memory, (char *)swatchMap, BIGSIZE, swatchCount / BIGSIZE + 1,
 	"imagen_print_page(swatchMap)" );
-  gs_free((char *)out, TotalBytesPerSw, swatchCount+1, "imagen_print_page(out)"); 
-  gs_free((char *)in, BIGSIZE, line_size / BIGSIZE + 1, "imagen_print_page(in)"); 
+  gs_free(pdev->memory, (char *)out, TotalBytesPerSw, swatchCount+1, "imagen_print_page(out)"); 
+  gs_free(pdev->memory, (char *)in, BIGSIZE, line_size / BIGSIZE + 1, "imagen_print_page(in)"); 
   /* ----------------------------------------- */
 
   DebugMsg(1,"Debug: Grey: %d \n",totalGreySwatches);
