@@ -10,7 +10,7 @@
    or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
-/* $Id: gdevp14.h 8170 2007-08-02 08:53:09Z leonardo $ */
+/* $Id: gdevp14.h 8484 2008-01-16 22:55:42Z leonardo $ */
 /* Definitions and interface for PDF 1.4 rendering device */
 
 #ifndef gdevp14_INCLUDED
@@ -52,10 +52,10 @@ struct pdf14_buf_s {
     int n_chan; /* number of pixel planes including alpha */
     int n_planes; /* total number of planes including alpha, shape, alpha_g */
     byte *data;
-
     byte *transfer_fn;
-
     gs_int_rect bbox;
+    pdf14_buf *maskbuf; /* Save pdf14_ctx_s::maksbuf. */
+    bool idle;
 };
 
 struct pdf14_ctx_s {
