@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gdevpdfe.c 8273 2007-10-08 10:05:33Z ken $ */
+/* $Id: gdevpdfe.c 8488 2008-01-17 13:37:19Z leonardo $ */
 /* Metadata writer. */
 #include "gx.h"
 #include "gserrors.h"
@@ -323,7 +323,8 @@ pdf_xmp_write_translated(gx_device_pdf *pdev, stream *s, const byte *data, int d
 	write(s, data, data_length);
 	return 0;
     } else {
-	UTF16 *buf0, *buf0b;
+	UTF16 *buf0;
+	const UTF16 *buf0b;
 	UTF8 *buf1, *buf1b;
 	int i, j = 0;
 
