@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gdevpdfi.c 8341 2007-11-01 15:56:22Z alexcher $ */
+/* $Id: gdevpdfi.c 8565 2008-02-29 23:59:31Z ray $ */
 /* Image handling for PDF-writing driver */
 #include "memory_.h"
 #include "math_.h"
@@ -1379,6 +1379,9 @@ gdev_pdf_pattern_manage(gx_device *pdev1, gx_bitmap_id id,
 	    code = pdf_store_pattern1_params(pdev, pres, pinst);
 	    if (code < 0)
 		return code;
+	    /* Scale the coordinate system, because object handlers assume so. See none_to_stream. */
+	    pprintg2(pdev->strm, "%g 0 0 %g 0 0 cm\n",
+		     72.0 / pdev->HWResolution[0], 72.0 / pdev->HWResolution[1]);
 	    return 1;
 	case pattern_manage__finish_accum:
 	    code = pdf_add_procsets(pdev->substream_Resources, pdev->procsets);
