@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gdevpdtb.c 8271 2007-10-07 18:09:11Z leonardo $ */
+/* $Id: gdevpdtb.c 8474 2008-01-02 13:10:59Z ken $ */
 /* BaseFont implementation for pdfwrite */
 #include "memory_.h"
 #include "ctype_.h"
@@ -121,7 +121,7 @@ pdf_end_fontfile(gx_device_pdf *pdev, pdf_data_writer_t *pdw)
 int
 pdf_base_font_alloc(gx_device_pdf *pdev, pdf_base_font_t **ppbfont,
 		    gs_font_base *font, const gs_matrix *orig_matrix, 
-		    bool is_standard, bool orig_name)
+		    bool is_standard)
 {
     gs_memory_t *mem = pdev->pdf_memory;
     gs_font *copied;
@@ -129,7 +129,7 @@ pdf_base_font_alloc(gx_device_pdf *pdev, pdf_base_font_t **ppbfont,
     pdf_base_font_t *pbfont =
 	gs_alloc_struct(mem, pdf_base_font_t,
 			&st_pdf_base_font, "pdf_base_font_alloc");
-    const gs_font_name *pfname = pdf_choose_font_name((gs_font *)font, orig_name);
+    const gs_font_name *pfname = &font->font_name;
     gs_const_string font_name;
     char fnbuf[3 + sizeof(long) / 3 + 1]; /* .F#######\0 */
     int code;
