@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gdevpdts.c 8265 2007-10-02 07:31:58Z ken $ */
+/* $Id: gdevpdts.c 8518 2008-02-07 09:33:22Z ken $ */
 /* Text state management for pdfwrite */
 #include "math_.h"
 #include "memory_.h"
@@ -520,7 +520,8 @@ pdf_render_mode_uses_stroke(const gx_device_pdf *pdev,
 			    const pdf_text_state_values_t *ptsv)
 {
     return (pdev->text->text_state->in.render_mode != ptsv->render_mode &&
-	    ptsv->render_mode != 0);
+	    ptsv->render_mode == 1 || ptsv->render_mode == 2 ||
+	    ptsv->render_mode == 5 || ptsv->render_mode == 6);
 }
 
 /*
