@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gdevprn.h 8250 2007-09-25 13:31:24Z giles $ */
+/* $Id: gdevprn.h 8528 2008-02-17 22:32:15Z leonardo $ */
 /* Common header file for memory-buffered printers */
 
 #ifndef gdevprn_INCLUDED
@@ -635,7 +635,7 @@ int gdev_prn_free_memory(gx_device *pdev);
  */
 typedef dev_proc_create_buf_device((*create_buf_device_proc_t));
 int gdev_create_buf_device(create_buf_device_proc_t cbd_proc,
-			   gx_device **pbdev, gx_device *target,
+			   gx_device **pbdev, gx_device *target, int y,
 			   const gx_render_plane_t *render_plane,
 			   gs_memory_t *mem, gx_band_complexity_t *band_complexity);
 
