@@ -1,22 +1,17 @@
-/* Copyright (C) 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gdevprna.h,v 1.2.6.1.2.1 2003/01/17 00:49:01 giles Exp $ */
+/* $Id: gdevprna.h 8022 2007-06-05 22:23:38Z giles $ */
 /* Generic asynchronous printer driver support */
 
 /* Initial version 2/1/1998 by John Desrosiers (soho@crl.com) */
@@ -160,15 +155,15 @@ struct gdev_prn_start_render_params_s {
  * This routine is always called by the concrete device's xx_open routine 
  * in lieu of gdev_prn_open.
  */
-int gdev_prn_async_write_open(P4(gx_device_printer *pdev, int max_raster,
-				 int min_band_height, int max_src_image_row));
+int gdev_prn_async_write_open(gx_device_printer *pdev, int max_raster,
+			      int min_band_height, int max_src_image_row);
 
 /* Open the render portion of a printer device in ASYNC (overlapped) mode.
  *
  * This routine is always called by concrete device's xx_open_render_device
  * in lieu of gdev_prn_open.
  */
-int gdev_prn_async_render_open(P1(gx_device_printer *prdev));
+int gdev_prn_async_render_open(gx_device_printer *prdev);
 
 /*
  * Must be called by async device driver implementation (see
@@ -177,6 +172,6 @@ int gdev_prn_async_render_open(P1(gx_device_printer *prdev));
  * the device is open. This proc only returns after the device is closed.
  */
 int	/* rets 0 ok, -ve error code */
-gdev_prn_async_render_thread(P1(gdev_prn_start_render_params *));
+gdev_prn_async_render_thread(gdev_prn_start_render_params *);
 
 #endif				/* gdevprna_INCLUDED */
