@@ -1,22 +1,17 @@
-/* Copyright (C) 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gdevpxut.c,v 1.2.6.1.2.1 2003/01/17 00:49:01 giles Exp $ */
+/* $Id: gdevpxut.c 8026 2007-06-06 22:03:27Z till $ */
 /* Utilities for PCL XL generation */
 #include "math_.h"
 #include "string_.h"
@@ -34,9 +29,13 @@
 int
 px_write_file_header(stream *s, const gx_device *dev)
 {
+    static const char *const enter_pjl_header =
+        "\033%-12345X@PJL SET RENDERMODE=";
+    static const char *const rendermode_gray = "GRAYSCALE";
+    static const char *const rendermode_color = "COLOR";
     static const char *const file_header =
-	"\033%-12345X@PJL ENTER LANGUAGE = PCLXL\n\
-) HP-PCL XL;1;1;Comment Copyright Aladdin Enterprises 1996\000\n";
+	"\n@PJL ENTER LANGUAGE = PCLXL\n\
+) HP-PCL XL;1;1;Comment Copyright Artifex Sofware, Inc. 2005\000\n";
     static const byte stream_header[] = {
 	DA(pxaUnitsPerMeasure),
 	DUB(0), DA(pxaMeasure),
@@ -47,6 +46,16 @@ px_write_file_header(stream *s, const gx_device *dev)
 	pxtOpenDataSource
     };
 
+    px_put_bytes(s, (const byte *)enter_pjl_header,
+		 strlen(enter_pjl_header));
+
+    if (dev->color_info.num_components == 1)
+	px_put_bytes(s, (const byte *)rendermode_gray,
+		     strlen(rendermode_gray));
+    else
+	px_put_bytes(s, (const byte *)rendermode_color,
+		     strlen(rendermode_color));
+
     /* We have to add 2 to the strlen because the next-to-last */
     /* character is a null. */
     px_put_bytes(s, (const byte *)file_header,
@@ -71,10 +80,12 @@ px_write_page_header(stream *s, const gx_device *dev)
 
 /* Write the media selection command if needed, updating the media size. */
 int
-px_write_select_media(stream *s, const gx_device *dev, pxeMediaSize_t *pms)
+px_write_select_media(stream *s, const gx_device *dev, 
+		      pxeMediaSize_t *pms, byte *media_source,
+		      int page, bool Duplex, bool Tumble)
 {
 #define MSD(ms, res, w, h)\
-  { ms, (w) * 1.0 / (res), (h) * 1.0 / res },
+  { ms, (float)((w) * 1.0 / (res)), (float)((h) * 1.0 / res) },
     static const struct {
 	pxeMediaSize_t ms;
 	float width, height;
@@ -87,6 +98,7 @@ px_write_select_media(stream *s, const gx_device *dev, pxeMediaSize_t *pms)
 	h = dev->height / dev->HWResolution[1];
     int i;
     pxeMediaSize_t size;
+    byte tray = eAutoSelect;
 
     /* The default is eLetterPaper, media size 0. */
     for (i = countof(media_sizes) - 2; i > 0; --i)
@@ -99,16 +111,30 @@ px_write_select_media(stream *s, const gx_device *dev, pxeMediaSize_t *pms)
      * According to the PCL XL documentation, MediaSize must always
      * be specified, but MediaSource is optional.
      */
-    px_put_uba(s, size, pxaMediaSize);
-    if (!pms || size != *pms) {
-	static const byte page_header_2[] = {
-	    DUB(eAutoSelect), DA(pxaMediaSource)
-	};
+    px_put_uba(s, (byte)size, pxaMediaSize);
 
-	PX_PUT_LIT(s, page_header_2);
-	if (pms)
-	    *pms = size;
+    if (media_source != NULL)
+	tray = *media_source;
+    px_put_uba(s, tray, pxaMediaSource);
+
+    if (Duplex)
+    {
+      if (Tumble)
+	px_put_uba(s, (byte)eDuplexHorizontalBinding, pxaDuplexPageMode);
+      else
+	px_put_uba(s, (byte)eDuplexVerticalBinding, pxaDuplexPageMode);
+
+      if (page & 1)
+	px_put_uba(s, (byte)eFrontMediaSide, pxaDuplexPageSide);
+      else
+	px_put_uba(s, (byte)eBackMediaSide, pxaDuplexPageSide);
     }
+    else
+      px_put_uba(s, (byte)eSimplexFrontSide, pxaSimplexPageMode);
+
+    if (pms)
+	*pms = size;
+
     return 0;
 }
 
@@ -146,13 +172,13 @@ void
 px_put_a(stream * s, px_attribute_t a)
 {
     sputc(s, pxt_attr_ubyte);
-    sputc(s, a);
+    sputc(s, (byte)a);
 }
 void
 px_put_ac(stream *s, px_attribute_t a, px_tag_t op)
 {
     px_put_a(s, a);
-    sputc(s, op);
+    sputc(s, (byte)op);
 }
 
 void
@@ -190,7 +216,7 @@ void
 px_put_u(stream * s, uint i)
 {
     if (i <= 255)
-	px_put_ub(s, i);
+	px_put_ub(s, (byte)i);
     else
 	px_put_us(s, i);
 }
@@ -247,7 +273,7 @@ px_put_r(stream * s, floatp r)
     spputc(s, (byte) mantissa);
     spputc(s, (byte) (mantissa >> 8));
     spputc(s, (byte) (((exp + 127) << 7) + ((mantissa >> 16) & 0x7f)));
-    spputc(s, (exp + 127) >> 1);
+    spputc(s, (byte) ((exp + 127) >> 1));
 }
 void
 px_put_rl(stream * s, floatp r)
