@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
    This software is provided AS-IS with no warranty, either express or
@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gdevtfax.c 6651 2006-03-13 16:18:19Z stefan $ */
+/* $Id: gdevtfax.c 8250 2007-09-25 13:31:24Z giles $ */
 /* TIFF and TIFF/fax devices */
 #include "gdevprn.h"
 #include "gdevtifs.h"
@@ -24,12 +24,12 @@
 
 /* The device descriptors */
 
-private dev_proc_get_params(tfax_get_params);
-private dev_proc_put_params(tfax_put_params);
-private dev_proc_print_page(tiffcrle_print_page);
-private dev_proc_print_page(tiffg3_print_page);
-private dev_proc_print_page(tiffg32d_print_page);
-private dev_proc_print_page(tiffg4_print_page);
+static dev_proc_get_params(tfax_get_params);
+static dev_proc_put_params(tfax_put_params);
+static dev_proc_print_page(tiffcrle_print_page);
+static dev_proc_print_page(tiffg3_print_page);
+static dev_proc_print_page(tiffg32d_print_page);
+static dev_proc_print_page(tiffg4_print_page);
 
 struct gx_device_tfax_s {
     gx_device_common;
@@ -43,7 +43,7 @@ struct gx_device_tfax_s {
 typedef struct gx_device_tfax_s gx_device_tfax;
 
 /* Define procedures that adjust the paper size. */
-private const gx_device_procs gdev_tfax_std_procs =
+static const gx_device_procs gdev_tfax_std_procs =
     prn_params_procs(gdev_prn_open, gdev_prn_output_page, gdev_prn_close,
 		     tfax_get_params, tfax_put_params);
 
@@ -67,7 +67,7 @@ const gx_device_tfax gs_tiffg4_device =
     TFAX_DEVICE("tiffg4", tiffg4_print_page);
 
 /* Get/put the MaxStripSize parameter. */
-private int
+static int
 tfax_get_params(gx_device * dev, gs_param_list * plist)
 {
     gx_device_tfax *const tfdev = (gx_device_tfax *)dev;
@@ -80,7 +80,7 @@ tfax_get_params(gx_device * dev, gs_param_list * plist)
         ecode = code;
     return ecode;
 }
-private int
+static int
 tfax_put_params(gx_device * dev, gs_param_list * plist)
 {
     gx_device_tfax *const tfdev = (gx_device_tfax *)dev;
@@ -135,7 +135,7 @@ tfax_put_params(gx_device * dev, gs_param_list * plist)
 /* Print a page with a specified width, which may differ from	*/
 /* the width stored in the device. The TIFF file may have	*/
 /* multiple strips of height 'rows'.				*/
-private int
+static int
 gdev_stream_print_page_strips(gx_device_printer * pdev, FILE * prn_stream,
 			      const stream_template * temp, stream_state * ss,
 			      int width, long rows_per_strip)
@@ -158,7 +158,7 @@ gdev_stream_print_page_strips(gx_device_printer * pdev, FILE * prn_stream,
 
 /* Print a page with a specified width, which may differ from the */
 /* width stored in the device. */
-private int
+static int
 gdev_stream_print_page_width(gx_device_printer * pdev, FILE * prn_stream,
 			     const stream_template * temp, stream_state * ss,
 			     int width)
@@ -167,7 +167,7 @@ gdev_stream_print_page_width(gx_device_printer * pdev, FILE * prn_stream,
 					 width, pdev->height);
 }
 
-private int
+static int
 gdev_stream_print_page(gx_device_printer * pdev, FILE * prn_stream,
 		       const stream_template * temp, stream_state * ss)
 {
@@ -191,8 +191,8 @@ gdev_fax_print_page_stripped(gx_device_printer * pdev, FILE * prn_stream,
 #include "srlx.h"
 
 /* Device descriptors for TIFF formats other than fax. */
-private dev_proc_print_page(tifflzw_print_page);
-private dev_proc_print_page(tiffpack_print_page);
+static dev_proc_print_page(tifflzw_print_page);
+static dev_proc_print_page(tiffpack_print_page);
 
 const gx_device_tfax gs_tifflzw_device = {
     prn_device_std_body(gx_device_tfax, prn_std_procs, "tifflzw",
@@ -222,7 +222,7 @@ typedef struct tiff_mono_directory_s {
     /* Don't use CleanFaxData. */
     /*  TIFF_dir_entry  CleanFaxData;   */
 } tiff_mono_directory;
-private const tiff_mono_directory dir_mono_template =
+static const tiff_mono_directory dir_mono_template =
 {
     {TIFFTAG_BitsPerSample, TIFF_SHORT, 1, 1},
     {TIFFTAG_Compression, TIFF_SHORT, 1, Compression_CCITT_T4},
@@ -234,11 +234,11 @@ private const tiff_mono_directory dir_mono_template =
 };
 
 /* Forward references */
-private int tfax_begin_page(gx_device_tfax *, FILE *,
+static int tfax_begin_page(gx_device_tfax *, FILE *,
 			    const tiff_mono_directory *, int);
 
 /* Print a fax-encoded page. */
-private int
+static int
 tifff_print_page(gx_device_printer * dev, FILE * prn_stream,
 		 stream_CFE_state * pstate, tiff_mono_directory * pdir)
 {
@@ -252,7 +252,7 @@ tifff_print_page(gx_device_printer * dev, FILE * prn_stream,
     gdev_tiff_end_page(&tfdev->tiff, prn_stream);
     return code;
 }
-private int
+static int
 tiffcrle_print_page(gx_device_printer * dev, FILE * prn_stream)
 {
     stream_CFE_state state;
@@ -267,7 +267,7 @@ tiffcrle_print_page(gx_device_printer * dev, FILE * prn_stream)
     dir.T4T6Options.value = T4Options_fill_bits;
     return tifff_print_page(dev, prn_stream, &state, &dir);
 }
-private int
+static int
 tiffg3_print_page(gx_device_printer * dev, FILE * prn_stream)
 {
     stream_CFE_state state;
@@ -282,13 +282,13 @@ tiffg3_print_page(gx_device_printer * dev, FILE * prn_stream)
     dir.T4T6Options.value = T4Options_fill_bits;
     return tifff_print_page(dev, prn_stream, &state, &dir);
 }
-private int
+static int
 tiffg32d_print_page(gx_device_printer * dev, FILE * prn_stream)
 {
     stream_CFE_state state;
     tiff_mono_directory dir;
 
-    gdev_fax_init_state(&state, (gx_device_fax *)dev);
+    gdev_fax_init_fax_state(&state, (gx_device_fax *)dev);
     state.K = (dev->y_pixels_per_inch < 100 ? 2 : 4);
     state.EndOfLine = true;
     state.EncodedByteAlign = true;
@@ -298,13 +298,13 @@ tiffg32d_print_page(gx_device_printer * dev, FILE * prn_stream)
     dir.T4T6Options.value = T4Options_2D_encoding | T4Options_fill_bits;
     return tifff_print_page(dev, prn_stream, &state, &dir);
 }
-private int
+static int
 tiffg4_print_page(gx_device_printer * dev, FILE * prn_stream)
 {
     stream_CFE_state state;
     tiff_mono_directory dir;
 
-    gdev_fax_init_state(&state, (gx_device_fax *)dev);
+    gdev_fax_init_fax_state(&state, (gx_device_fax *)dev);
     state.K = -1;
     /*state.EncodedByteAlign = false; *//* no fill_bits option for T6 */
     dir = dir_mono_template;
@@ -314,7 +314,7 @@ tiffg4_print_page(gx_device_printer * dev, FILE * prn_stream)
 }
 
 /* Print an LZW page. */
-private int
+static int
 tifflzw_print_page(gx_device_printer * dev, FILE * prn_stream)
 {
     gx_device_tfax *const tfdev = (gx_device_tfax *)dev;
@@ -337,7 +337,7 @@ tifflzw_print_page(gx_device_printer * dev, FILE * prn_stream)
 }
 
 /* Print a PackBits page. */
-private int
+static int
 tiffpack_print_page(gx_device_printer * dev, FILE * prn_stream)
 {
     gx_device_tfax *const tfdev = (gx_device_tfax *)dev;
@@ -358,7 +358,7 @@ tiffpack_print_page(gx_device_printer * dev, FILE * prn_stream)
 }
 
 /* Begin a TIFF fax page. */
-private int
+static int
 tfax_begin_page(gx_device_tfax * tfdev, FILE * fp,
 		const tiff_mono_directory * pdir, int width)
 {
