@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gp_psync.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: gp_psync.c 8250 2007-09-25 13:31:24Z giles $ */
 /* POSIX pthreads threads / semaphore / monitor implementation */
 #include "std.h"
 #include "malloc_.h"
@@ -190,7 +190,7 @@ typedef struct gp_thread_creation_closure_s {
 } gp_thread_creation_closure_t;
 
 /* Wrapper procedure called to start the new thread. */
-private void *
+static void *
 gp_thread_begin_wrapper(void *thread_data /* gp_thread_creation_closure_t * */)
 {
     gp_thread_creation_closure_t closure;
