@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gsalloc.c 8250 2007-09-25 13:31:24Z giles $ */
+/* $Id: gsalloc.c 8496 2008-01-21 20:59:55Z leonardo $ */
 /* Standard memory allocator */
 #include "gx.h"
 #include "memory_.h"
@@ -322,10 +322,10 @@ ialloc_reset(gs_ref_memory_t * mem)
     mem->cc.rtop = 0;
     mem->cc.has_refs = false;
     mem->allocated = 0;
-    mem->inherited = 0;
     mem->changes = 0;
     mem->scan_limit = 0;
     mem->total_scanned = 0;
+    mem->total_scanned_after_compacting = 0;
     ialloc_reset_free(mem);
 }
 
