@@ -1,22 +1,17 @@
-/* Copyright (C) 1995, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gscparam.c,v 1.7.2.1.2.1 2003/01/17 00:49:02 giles Exp $ */
+/* $Id: gscparam.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Default implementation of parameter lists */
 #include "memory_.h"
 #include "string_.h"
@@ -75,7 +70,7 @@ ENUM_PTRS_WITH(c_param_enum_ptrs, gs_c_param *param) {
 
 	value.value = *(const gs_param_value *)&param->value;
 	value.type = param->type;
-	return gs_param_typed_value_enum_ptrs(&value, sizeof(value), index,
+	return gs_param_typed_value_enum_ptrs(mem, &value, sizeof(value), index,
 					      pep, NULL, gcst);
     }
     }
@@ -130,7 +125,7 @@ gs_c_param_list_alloc(gs_memory_t *mem, client_name_t cname)
     return gs_alloc_struct(mem, gs_c_param_list, &st_c_param_list, cname);
 }
 
-private gs_c_param *
+static gs_c_param *
 c_param_find(const gs_c_param_list *plist, gs_param_name pkey, bool any)
 {
     gs_c_param *pparam = plist->head;
@@ -144,12 +139,12 @@ c_param_find(const gs_c_param_list *plist, gs_param_name pkey, bool any)
 
 /* ---------------- Writing parameters to a list ---------------- */
 
-private param_proc_begin_xmit_collection(c_param_begin_write_collection);
-private param_proc_end_xmit_collection(c_param_end_write_collection);
-private param_proc_xmit_typed(c_param_write_typed);
-private param_proc_request(c_param_request);
-private param_proc_requested(c_param_requested);
-private const gs_param_list_procs c_write_procs =
+static param_proc_begin_xmit_collection(c_param_begin_write_collection);
+static param_proc_end_xmit_collection(c_param_end_write_collection);
+static param_proc_xmit_typed(c_param_write_typed);
+static param_proc_request(c_param_request);
+static param_proc_requested(c_param_requested);
+static const gs_param_list_procs c_write_procs =
 {
     c_param_write_typed,
     c_param_begin_write_collection,
@@ -232,7 +227,7 @@ gs_c_param_list_release(gs_c_param_list * plist)
 }
 
 /* Add an entry to a list.  Doesn't set: value, type, plist->head. */
-private gs_c_param *
+static gs_c_param *
 c_param_add(gs_c_param_list * plist, gs_param_name pkey)
 {
     gs_c_param *pparam =
@@ -266,7 +261,7 @@ c_param_add(gs_c_param_list * plist, gs_param_name pkey)
 }
 
 /*  Write a dynamically typed parameter to a list. */
-private int
+static int
 c_param_write(gs_c_param_list * plist, gs_param_name pkey, void *pvalue,
 	      gs_param_type type)
 {
@@ -345,7 +340,7 @@ c_param_write(gs_c_param_list * plist, gs_param_name pkey, void *pvalue,
 }
 
 /* Individual writing routines. */
-private int
+static int
 c_param_begin_write_collection(gs_param_list * plist, gs_param_name pkey,
 	       gs_param_dict * pvalue, gs_param_collection_type_t coll_type)
 {
@@ -361,7 +356,7 @@ c_param_begin_write_collection(gs_param_list * plist, gs_param_name pkey,
     pvalue->list = (gs_param_list *) dlist;
     return 0;
 }
-private int
+static int
 c_param_end_write_collection(gs_param_list * plist, gs_param_name pkey,
 			     gs_param_dict * pvalue)
 {
@@ -374,7 +369,7 @@ c_param_end_write_collection(gs_param_list * plist, gs_param_name pkey,
 		     dlist->coll_type == gs_param_collection_array ?
 		     gs_param_type_array : gs_param_type_dict));
 }
-private int
+static int
 c_param_write_typed(gs_param_list * plist, gs_param_name pkey,
 		    gs_param_typed_value * pvalue)
 {
@@ -400,7 +395,7 @@ c_param_write_typed(gs_param_list * plist, gs_param_name pkey,
 
 /* Other procedures */
 
-private int
+static int
 c_param_request(gs_param_list * plist, gs_param_name pkey)
 {
     gs_c_param_list *const cplist = (gs_c_param_list *)plist;
@@ -417,7 +412,7 @@ c_param_request(gs_param_list * plist, gs_param_name pkey)
     return 0;
 }
 
-private int
+static int
 c_param_requested(const gs_param_list * plist, gs_param_name pkey)
 {
     const gs_c_param_list *const cplist = (const gs_c_param_list *)plist;
@@ -436,14 +431,14 @@ c_param_requested(const gs_param_list * plist, gs_param_name pkey)
 
 /* ---------------- Reading from a list to parameters ---------------- */
 
-private param_proc_begin_xmit_collection(c_param_begin_read_collection);
-private param_proc_end_xmit_collection(c_param_end_read_collection);
-private param_proc_xmit_typed(c_param_read_typed);
-private param_proc_next_key(c_param_get_next_key);
-private param_proc_get_policy(c_param_read_get_policy);
-private param_proc_signal_error(c_param_read_signal_error);
-private param_proc_commit(c_param_read_commit);
-private const gs_param_list_procs c_read_procs =
+static param_proc_begin_xmit_collection(c_param_begin_read_collection);
+static param_proc_end_xmit_collection(c_param_end_read_collection);
+static param_proc_xmit_typed(c_param_read_typed);
+static param_proc_next_key(c_param_get_next_key);
+static param_proc_get_policy(c_param_read_get_policy);
+static param_proc_signal_error(c_param_read_signal_error);
+static param_proc_commit(c_param_read_commit);
+static const gs_param_list_procs c_read_procs =
 {
     c_param_read_typed,
     c_param_begin_read_collection,
@@ -465,7 +460,7 @@ gs_c_param_list_read(gs_c_param_list * plist)
 
 /* Generic routine for reading a parameter from a list. */
 
-private int
+static int
 c_param_read_typed(gs_param_list * plist, gs_param_name pkey,
 		   gs_param_typed_value * pvalue)
 {
@@ -524,7 +519,7 @@ c_param_read_typed(gs_param_list * plist, gs_param_name pkey,
 }
 
 /* Individual reading routines. */
-private int
+static int
 c_param_begin_read_collection(gs_param_list * plist, gs_param_name pkey,
 	       gs_param_dict * pvalue, gs_param_collection_type_t coll_type)
 {
@@ -556,7 +551,7 @@ c_param_begin_read_collection(gs_param_list * plist, gs_param_name pkey,
     pvalue->size = pparam->value.d.count;
     return 0;
 }
-private int
+static int
 c_param_end_read_collection(gs_param_list * plist, gs_param_name pkey,
 			    gs_param_dict * pvalue)
 {
@@ -564,7 +559,7 @@ c_param_end_read_collection(gs_param_list * plist, gs_param_name pkey,
 }
 
 /* Other procedures */
-private int			/* ret 0 ok, 1 if EOF, or -ve err */
+static int			/* ret 0 ok, 1 if EOF, or -ve err */
 c_param_get_next_key(gs_param_list * plist, gs_param_enumerator_t * penum,
 		     gs_param_key_t * key)
 {
@@ -579,17 +574,17 @@ c_param_get_next_key(gs_param_list * plist, gs_param_enumerator_t * penum,
     *key = pparam->key;
     return 0;
 }
-private int
+static int
 c_param_read_get_policy(gs_param_list * plist, gs_param_name pkey)
 {
     return gs_param_policy_ignore;
 }
-private int
+static int
 c_param_read_signal_error(gs_param_list * plist, gs_param_name pkey, int code)
 {
     return code;
 }
-private int
+static int
 c_param_read_commit(gs_param_list * plist)
 {
     return 0;
