@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
    This software is provided AS-IS with no warranty, either express or
@@ -11,14 +11,15 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gscpixel.h 6651 2006-03-13 16:18:19Z stefan $ */
+/* $Id: gscpixel.h 8022 2007-06-05 22:23:38Z giles $ */
 /* Interface to DevicePixel color space */
 /* Requires gscspace.h */
 
 #ifndef gscpixel_INCLUDED
 #  define gscpixel_INCLUDED
 
-/* Initialize a DevicePixel color space. */
-int gs_cspace_init_DevicePixel(gs_memory_t *mem, gs_color_space * pcs, int depth);
+/* Construct a new DevicePixel color space. */
+int gs_cspace_new_DevicePixel(gs_memory_t *mem, gs_color_space **ppcs,
+			      int depth);
 
 #endif /* gscpixel_INCLUDED */
