@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gsstate.c 8250 2007-09-25 13:31:24Z giles $ */
+/* $Id: gsstate.c 8407 2007-11-27 18:11:10Z leonardo $ */
 /* Miscellaneous graphics state operators for Ghostscript library */
 #include "gx.h"
 #include "memory_.h"
@@ -411,7 +411,7 @@ gs_grestore_only(gs_state * pgs)
     gs_free_object(pgs->memory, saved, "gs_grestore");
 
     /* update the overprint compositor, if necessary */
-    if (prior_overprint || pgs->overprint)
+    if (prior_overprint != pgs->overprint)
         return gs_do_set_overprint(pgs);
     else
         return 0;
