@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gstype2.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: gstype2.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Adobe Type 2 charstring interpreter */
 #include "math_.h"
 #include "memory_.h"
@@ -50,7 +50,7 @@
 	return type2_sbw(pcis, csp, cstack, ipsp, explicit_width);\
       }\
   END
-private int
+static int
 type2_sbw(gs_type1_state * pcis, cs_ptr csp, cs_ptr cstack, ip_state_t * ipsp,
 	  bool explicit_width)
 {
@@ -92,7 +92,7 @@ type2_sbw(gs_type1_state * pcis, cs_ptr csp, cs_ptr cstack, ip_state_t * ipsp,
     }
     return type1_result_sbw;
 }
-private int
+static int
 type2_vstem(gs_type1_state * pcis, cs_ptr csp, cs_ptr cstack)
 {
     fixed x = 0;
