@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gxcllzw.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: gxcllzw.c 8250 2007-09-25 13:31:24Z giles $ */
 /* LZW filter initialization for RAM-based band lists */
 #include "std.h"
 #include "gstypes.h"
@@ -19,8 +19,8 @@
 #include "gxclmem.h"
 #include "slzwx.h"
 
-private stream_LZW_state cl_LZWE_state;
-private stream_LZW_state cl_LZWD_state;
+static stream_LZW_state cl_LZWE_state;
+static stream_LZW_state cl_LZWD_state;
 
 /* Initialize the states to be copied. */
 int
