@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gxclmem.c 8250 2007-09-25 13:31:24Z giles $ */
+/* $Id: gxclmem.c 8488 2008-01-17 13:37:19Z leonardo $ */
 /* RAM-based command list implementation */
 #include "memory_.h"
 #include "gx.h"
@@ -947,7 +947,7 @@ memfile_free_mem(MEMFILE * f)
     if (tot_cache_hits != 0) {
 	if_debug3(':', "[:]Cache hits=%ld, cache misses=%ld, swapouts=%ld\n",
 		 tot_cache_hits,
-		 tot_cache_miss - (f->log_length / MEMFILE_DATA_SIZE),
+		 (long)(tot_cache_miss - (f->log_length / MEMFILE_DATA_SIZE)),
 		 tot_swap_out);
     }
     tot_raw = 0;
