@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
    This software is provided AS-IS with no warranty, either express or
@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gxclmem.h 6651 2006-03-13 16:18:19Z stefan $ */
+/* $Id: gxclmem.h 8022 2007-06-05 22:23:38Z giles $ */
 /* Definitions and declarations for clist implementation in memory. */
 
 #ifndef gxclmem_INCLUDED
@@ -61,7 +61,7 @@ typedef struct LOG_MEMFILE_BLK {
     RAW_BUFFER *raw_block;	/* or NULL */
 } LOG_MEMFILE_BLK;
 
-typedef struct MEMFILE {
+struct MEMFILE_s {
     gs_memory_t *memory;	/* storage allocator */
     gs_memory_t *data_memory;	/* storage allocator for data */
     bool ok_to_compress;	/* if true, OK to compress this file */
@@ -88,12 +88,12 @@ typedef struct MEMFILE {
     /* logical file properties */
     LOG_MEMFILE_BLK *log_head;
     LOG_MEMFILE_BLK *log_curr_blk;
-    long log_length;		/* updated during write             */
-    long log_curr_pos;		/* updated during seek, close, read */
+    int64_t log_length;		/* updated during write             */
+    int64_t log_curr_pos;	/* updated during seek, close, read */
     char *pdata;		/* raw data */
     char *pdata_end;
     /* physical file properties */
-    long total_space;		/* so we know when to start compress */
+    int64_t total_space;	/* so we know when to start compress */
     PHYS_MEMFILE_BLK *phys_curr;	/* NULL if not compressing      */
     RAW_BUFFER *raw_head, *raw_tail;
     int error_code;		/* used by CLIST_ferror         */
@@ -102,7 +102,11 @@ typedef struct MEMFILE {
     bool compressor_initialized;
     stream_state *compress_state;
     stream_state *decompress_state;
-} MEMFILE;
+};
+#ifndef MEMFILE_DEFINED
+#define MEMFILE_DEFINED
+typedef struct MEMFILE_s MEMFILE;
+#endif
 
 /*
  * Only the MEMFILE and stream_state structures are GC-compatible, so we
@@ -113,29 +117,6 @@ typedef struct MEMFILE {
   gs_private_st_ptrs2(st_MEMFILE, MEMFILE, "MEMFILE",\
     MEMFILE_enum_ptrs, MEMFILE_reloc_ptrs, compress_state, decompress_state)
 
-/* Make the memfile_... operations aliases for the clist_... operations. */
-
-#define memfile_fopen(fname, fmode, pcf, mem, data_mem, compress)\
-  clist_fopen(fname, fmode, pcf, mem, data_mem, compress)
-#define memfile_fclose(cf, fname, delete)\
-  clist_fclose(cf, fname, delete)
-#define memfile_unlink(fname)\
-  clist_unlink(fname)
-
-#define memfile_space_available(req)\
-  clist_space_available(req)
-#define memfile_fwrite_chars(data, len, cf)\
-  clist_fwrite_chars(data, len, cf)
-
-#define memfile_fread_chars(data, len, cf)\
-  clist_fread_chars(data, len, cf)
-
-#define memfile_set_memory_warning(cf, nbytes) clist_set_memory_warning(cf, nbytes)
-#define memfile_ferror_code(cf) clist_ferror_code(cf)
-#define memfile_ftell(cf) clist_ftell(cf)
-#define memfile_rewind(cf, discard, fname) clist_rewind(cf, discard, fname)
-#define memfile_fseek(cf, offset, mode, fname) clist_fseek(cf, offset, mode, fname)
-
 /* Declare the procedures for returning the prototype filter states */
 /* for compressing and decompressing the band list. */
 const stream_state *clist_compressor_state(void *);
