@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gxclpath.c 8250 2007-09-25 13:31:24Z giles $ */
+/*$Id: gxclpath.c 8426 2007-12-07 23:39:06Z leonardo $ */
 /* Higher-level path operations for band lists */
 #include "math_.h"
 #include "memory_.h"
@@ -301,6 +301,18 @@ cmd_write_ctm_return_length(gx_device_clist_writer * cldev, const gs_matrix *m)
     return (uint)stell(&s);
 }
 
+/* Compute the written CTM length. */
+int
+cmd_write_ctm_return_length_nodevice(const gs_matrix *m)
+{
+    stream s;
+
+    s_init(&s, NULL);
+    swrite_position_only(&s);
+    sput_matrix(&s, m);
+    return (uint)stell(&s);
+}
+
 /* Write out CTM. */
 int
 cmd_write_ctm(const gs_matrix *m, byte *dp, int len)
@@ -604,7 +616,12 @@ clist_fill_path(gx_device * dev, const gs_imager_state * pis, gx_path * ppath,
     {
 	gs_fixed_rect bbox;
 
-	gx_path_bbox(ppath, &bbox);
+	if (ppath != NULL)
+	    gx_path_bbox(ppath, &bbox);
+	else {
+	    /* gx_default_fill_path passes the clip path for shfill. */
+	    gx_cpath_outer_box(pcpath, &bbox);
+	}
 	ry = fixed2int(bbox.p.y) - 1;
 	rheight = fixed2int_ceiling(bbox.q.y) - ry + 1;
 	fit_fill_y(dev, ry, rheight);
