@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gxclzlib.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: gxclzlib.c 8250 2007-09-25 13:31:24Z giles $ */
 /* zlib filter initialization for RAM-based band lists */
 /* Must be compiled with -I$(ZSRCDIR) */
 #include "std.h"
@@ -20,8 +20,8 @@
 #include "gxclmem.h"
 #include "szlibx.h"
 
-private stream_zlib_state cl_zlibE_state;
-private stream_zlib_state cl_zlibD_state;
+static stream_zlib_state cl_zlibE_state;
+static stream_zlib_state cl_zlibD_state;
 
 /* Initialize the states to be copied. */
 int
