@@ -1,22 +1,17 @@
-/* Copyright (C) 1993, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gxcolor2.h,v 1.4.6.1.2.1 2003/01/17 00:49:03 giles Exp $ */
+/* $Id: gxcolor2.h 8022 2007-06-05 22:23:38Z giles $ */
 /* Internal definitions for Level 2 color routines */
 /* Requires gsstruct.h, gxfixed.h */
 
@@ -32,8 +27,8 @@
 struct gs_indexed_map_s {
     rc_header rc;
     union {
-	int (*lookup_index)(P3(const gs_indexed_params *, int, float *));
-	int (*tint_transform)(P3(const gs_separation_params *, floatp, float *));
+	int (*lookup_index)(const gs_color_space *, int, float *);
+	int (*tint_transform)(const gs_separation_params *, floatp, float *);
     } proc;
     void *proc_data;
     uint num_values;	/* base_space->type->num_components * (hival + 1) */
@@ -44,12 +39,12 @@ struct gs_indexed_map_s {
     indexed_map_enum_ptrs, indexed_map_reloc_ptrs, proc_data, values)
 
 /* Define a lookup_index procedure that just returns the map values. */
-int lookup_indexed_map(P3(const gs_indexed_params *, int, float *));
+int lookup_indexed_map(const gs_color_space *, int, float *);
 
 /* Allocate an indexed map and its values. */
 /* The initial reference count is 1. */
-int alloc_indexed_map(P4(gs_indexed_map ** ppmap, int num_values,
-			 gs_memory_t * mem, client_name_t cname));
+int alloc_indexed_map(gs_indexed_map ** ppmap, int num_values,
+		      gs_memory_t * mem, client_name_t cname);
 
 /* Free an indexed map and its values when the reference count goes to 0. */
 rc_free_proc(free_indexed_map);
@@ -68,7 +63,12 @@ rc_free_proc(free_indexed_map);
  * arrange it so that all 4 transformation factors are non-negative.
  */
 
-typedef struct gs_pattern1_instance_s {
+#ifndef gs_pattern1_instance_t_DEFINED
+#  define gs_pattern1_instance_t_DEFINED
+typedef struct gs_pattern1_instance_s gs_pattern1_instance_t;
+#endif
+
+struct gs_pattern1_instance_s {
     gs_pattern_instance_common;	/* must be first */
     gs_pattern1_template_t template;
     /* Following are created by makepattern */
@@ -82,7 +82,7 @@ typedef struct gs_pattern1_instance_s {
     bool uses_mask;	        /* if true, pattern mask must be created */
     gs_int_point size;		/* in device coordinates */
     gx_bitmap_id id;		/* key for cached bitmap (= id of mask) */
-} gs_pattern1_instance_t;
+};
 
 #define private_st_pattern1_instance() /* in gsptype1.c */\
   gs_private_st_composite(st_pattern1_instance, gs_pattern1_instance_t,\
