@@ -1,22 +1,17 @@
-/* Copyright (C) 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gximag3x.c,v 1.7.6.1.2.1 2003/01/17 00:49:04 giles Exp $ */
+/* $Id: gximag3x.c 8250 2007-09-25 13:31:24Z giles $ */
 /* ImageType 3x image implementation */
 /****** THE REAL WORK IS NYI ******/
 #include "math_.h"		/* for ceil, floor */
@@ -36,11 +31,11 @@
 extern_st(st_color_space);
 
 /* Forward references */
-private dev_proc_begin_typed_image(gx_begin_image3x);
-private image_enum_proc_plane_data(gx_image3x_plane_data);
-private image_enum_proc_end_image(gx_image3x_end_image);
-private image_enum_proc_flush(gx_image3x_flush);
-private image_enum_proc_planes_wanted(gx_image3x_planes_wanted);
+static dev_proc_begin_typed_image(gx_begin_image3x);
+static image_enum_proc_plane_data(gx_image3x_plane_data);
+static image_enum_proc_end_image(gx_image3x_end_image);
+static image_enum_proc_flush(gx_image3x_flush);
+static image_enum_proc_planes_wanted(gx_image3x_planes_wanted);
 
 /* GC descriptor */
 private_st_gs_image3x();
@@ -51,13 +46,13 @@ const gx_image_type_t gs_image_type_3x = {
     gx_image_no_sput, gx_image_no_sget, gx_image_default_release,
     IMAGE3X_IMAGETYPE
 };
-private const gx_image_enum_procs_t image3x_enum_procs = {
+static const gx_image_enum_procs_t image3x_enum_procs = {
     gx_image3x_plane_data, gx_image3x_end_image,
     gx_image3x_flush, gx_image3x_planes_wanted
 };
 
 /* Initialize an ImageType 3x image. */
-private void
+static void
 gs_image3x_mask_init(gs_image3x_mask_t *pimm)
 {
     pimm->InterleaveType = 0;	/* not a valid type */
@@ -66,7 +61,7 @@ gs_image3x_mask_init(gs_image3x_mask_t *pimm)
     pimm->MaskDict.BitsPerComponent = 0;	/* not supplied */
 }
 void
-gs_image3x_t_init(gs_image3x_t * pim, const gs_color_space * color_space)
+gs_image3x_t_init(gs_image3x_t * pim, gs_color_space * color_space)
 {
     gs_pixel_image_t_init((gs_pixel_image_t *) pim, color_space);
     pim->type = &gs_image_type_3x;
@@ -121,13 +116,12 @@ typedef struct image3x_channel_values_s {
     gs_int_rect rect;
     gs_image_t image;
 } image3x_channel_values_t;
-private bool is_multiple(P2(int x, int y));
-private int check_image3x_mask(P6(const gs_image3x_t *pim,
-				  const gs_image3x_mask_t *pimm,
-				  const image3x_channel_values_t *ppcv,
-				  image3x_channel_values_t *pmcv,
-				  image3x_channel_state_t *pmcs,
-				  gs_memory_t *mem));
+static int check_image3x_mask(const gs_image3x_t *pim,
+			       const gs_image3x_mask_t *pimm,
+			       const image3x_channel_values_t *ppcv,
+			       image3x_channel_values_t *pmcv,
+			       image3x_channel_state_t *pmcs,
+			       gs_memory_t *mem);
 int
 gx_begin_image3x_generic(gx_device * dev,
 			const gs_imager_state *pis, const gs_matrix *pmat,
@@ -215,15 +209,13 @@ gx_begin_image3x_generic(gx_device * dev,
 	gs_color_space *pmcs;
 
 	if (penum->mask[i].depth == 0) {	/* mask not supplied */
-	    midev[0] = 0;
-	    minfo[0] = 0;
+	    midev[i] = 0;
+	    minfo[i] = 0;
 	    continue;
 	}
-	pmcs =  gs_alloc_struct(mem, gs_color_space, &st_color_space,
-				"gx_begin_image3x_generic");
-	if (pmcs == 0)
-	    return_error(gs_error_VMerror);
-	gs_cspace_init_DevicePixel(pmcs, penum->mask[i].depth);
+	code = gs_cspace_new_DevicePixel(mem, &pmcs, penum->mask[i].depth);
+	if (code < 0)
+	    return code;
 	mrect.p.x = mrect.p.y = 0;
 	mrect.q.x = penum->mask[i].width;
 	mrect.q.y = penum->mask[i].height;
@@ -231,8 +223,8 @@ gx_begin_image3x_generic(gx_device * dev,
 	    (code = gs_bbox_transform(&mrect, &mat, &mrect)) < 0
 	    )
 	    return code;
-	origin[i].x = floor(mrect.p.x);
-	origin[i].y = floor(mrect.p.y);
+	origin[i].x = (int)floor(mrect.p.x);
+	origin[i].y = (int)floor(mrect.p.y);
 	code = make_mid(&mdev, dev,
 			(int)ceil(mrect.q.x) - origin[i].x,
 			(int)ceil(mrect.q.y) - origin[i].y,
@@ -240,7 +232,7 @@ gx_begin_image3x_generic(gx_device * dev,
 	if (code < 0)
 	    goto out1;
 	penum->mask[i].mdev = mdev;
-	gs_image_t_init_gray(&mask[i].image, pis); /* gray is bogus */
+        gs_image_t_init(&mask[i].image, pmcs);
 	mask[i].image.ColorSpace = pmcs;
 	mask[i].image.adjust = false;
 	{
@@ -263,12 +255,15 @@ gx_begin_image3x_generic(gx_device * dev,
 	    m_mat.tx -= origin[i].x;
 	    m_mat.ty -= origin[i].y;
 	    /*
-	     * Note that pis = NULL here, since we don't want to have to
-	     * create another imager state with default log_op, etc.
+	     * Peter put in a comment that said " Note that pis = NULL here,
+	     * since we don't want to have to create another imager state with
+	     * default log_op, etc." and passed NULL instead of pis to this
+	     * routine.  However Image type 1 need the imager state (see
+	     * bug 688348) thus his optimization was removed.
 	     * dcolor = NULL is OK because this is an opaque image with
 	     * CombineWithColor = false.
 	     */
-	    code = gx_device_begin_typed_image(mdev, NULL, &m_mat,
+	    code = gx_device_begin_typed_image(mdev, pis, &m_mat,
 			       (const gs_image_common_t *)&mask[i].image,
 					       &mask[i].rect, NULL, NULL,
 					       mem, &penum->mask[i].info);
@@ -356,12 +351,7 @@ gx_begin_image3x_generic(gx_device * dev,
     gs_free_object(mem, penum, "gx_begin_image3x");
     return code;
 }
-private bool
-is_multiple(int x, int y)
-{
-    return (x % y == 0 || y % x == 0);
-}
-private bool
+static bool
 check_image3x_extent(floatp mask_coeff, floatp data_coeff)
 {
     if (mask_coeff == 0)
@@ -370,10 +360,13 @@ check_image3x_extent(floatp mask_coeff, floatp data_coeff)
 	return false;
     return true;
 }
-/* Check mask parameters. */
-/* Reads ppcv->{matrix,corner,rect}, sets pmcv->{matrix,corner,rect} and */
-/* pmcs->{InterleaveType,width,height,full_height,data,y,skip}. */
-private bool
+/*
+ * Check mask parameters.
+ * Reads ppcv->{matrix,corner,rect}, sets pmcv->{matrix,corner,rect} and
+ * pmcs->{InterleaveType,width,height,full_height,depth,data,y,skip}.
+ * If the mask is omitted, sets pmcs->depth = 0 and returns normally.
+ */
+static bool
 check_image3x_mask(const gs_image3x_t *pim, const gs_image3x_mask_t *pimm,
 		   const image3x_channel_values_t *ppcv,
 		   image3x_channel_values_t *pmcv,
@@ -382,8 +375,11 @@ check_image3x_mask(const gs_image3x_t *pim, const gs_image3x_mask_t *pimm,
     int mask_width = pimm->MaskDict.Width, mask_height = pimm->MaskDict.Height;
     int code;
 
-    if (pimm->MaskDict.BitsPerComponent == 0) /* mask missing */
+    if (pimm->MaskDict.BitsPerComponent == 0) { /* mask missing */
+	pmcs->depth = 0;
+        pmcs->InterleaveType = 0;	/* not a valid type */
 	return 0;
+    }
     if (mask_height <= 0)
 	return_error(gs_error_rangecheck);
     switch (pimm->InterleaveType) {
@@ -398,12 +394,9 @@ check_image3x_mask(const gs_image3x_t *pim, const gs_image3x_mask_t *pimm,
 		)
 		return_error(gs_error_rangecheck);
 	    break;
-	    if (!is_multiple(mask_height, pim->Height))
-		return_error(gs_error_rangecheck);
-	    /* falls through */
 	case interleave_separate_source:
 	    switch (pimm->MaskDict.BitsPerComponent) {
-	    case 1: case 2: case 4: case 8:
+		    case 1: case 2: case 4: case 8: case 12: case 16:
 		break;
 	    default:
 		return_error(gs_error_rangecheck);
@@ -459,7 +452,7 @@ check_image3x_mask(const gs_image3x_t *pim, const gs_image3x_mask_t *pimm,
  * Return > 0 if we want more data from channel 1 now, < 0 if we want more
  * from channel 2 now, 0 if we want both.
  */
-private int
+static int
 channel_next(const image3x_channel_state_t *pics1,
 	     const image3x_channel_state_t *pics2)
 {
@@ -487,8 +480,8 @@ channel_next(const image3x_channel_state_t *pics1,
 }
 
 /* Define the default implementation of ImageType 3 processing. */
-private IMAGE3X_MAKE_MID_PROC(make_midx_default); /* check prototype */
-private int
+static IMAGE3X_MAKE_MID_PROC(make_midx_default); /* check prototype */
+static int
 make_midx_default(gx_device **pmidev, gx_device *dev, int width, int height,
 		 int depth, gs_memory_t *mem)
 {
@@ -496,6 +489,9 @@ make_midx_default(gx_device **pmidev, gx_device *dev, int width, int height,
     gx_device_memory *midev;
     int code;
 
+    if (width != 0)
+	if (height > max_ulong/width)	/* protect against overflow in bitmap size */
+	    return_error(gs_error_VMerror);
     if (mdproto == 0)
 	return_error(gs_error_rangecheck);
     midev = gs_alloc_struct(mem, gx_device_memory, &st_device_memory,
@@ -506,6 +502,7 @@ make_midx_default(gx_device **pmidev, gx_device *dev, int width, int height,
     midev->bitmap_memory = mem;
     midev->width = width;
     midev->height = height;
+    check_device_separable((gx_device *)midev);
     gx_device_fill_in_procs((gx_device *)midev);
     code = dev_proc(midev, open_device)((gx_device *)midev);
     if (code < 0) {
@@ -518,8 +515,8 @@ make_midx_default(gx_device **pmidev, gx_device *dev, int width, int height,
     *pmidev = (gx_device *)midev;
     return 0;
 }
-private IMAGE3X_MAKE_MCDE_PROC(make_mcdex_default);  /* check prototype */
-private int
+static IMAGE3X_MAKE_MCDE_PROC(make_mcdex_default);  /* check prototype */
+static int
 make_mcdex_default(gx_device *dev, const gs_imager_state *pis,
 		   const gs_matrix *pmat, const gs_image_common_t *pic,
 		   const gs_int_rect *prect, const gx_drawing_color *pdcolor,
@@ -546,7 +543,7 @@ make_mcdex_default(gx_device *dev, const gs_imager_state *pis,
 
     if (bbdev == 0)
 	return_error(gs_error_VMerror);
-    gx_device_bbox_init(bbdev, dev);
+    gx_device_bbox_init(bbdev, dev, mem);
     gx_device_bbox_fwd_open_close(bbdev, false);
     code = dev_proc(bbdev, begin_typed_image)
 	((gx_device *)bbdev, pis, pmat, pic, prect, pdcolor, pcpath, mem,
@@ -558,7 +555,7 @@ make_mcdex_default(gx_device *dev, const gs_imager_state *pis,
     *pmcdev = (gx_device *)bbdev;
     return 0;
 }
-private int
+static int
 gx_begin_image3x(gx_device * dev,
 		const gs_imager_state * pis, const gs_matrix * pmat,
 		const gs_image_common_t * pic, const gs_int_rect * prect,
@@ -571,7 +568,7 @@ gx_begin_image3x(gx_device * dev,
 }
 
 /* Process the next piece of an ImageType 3 image. */
-private int
+static int
 gx_image3x_plane_data(gx_image_enum_common_t * info,
 		     const gx_image_plane_t * planes, int height,
 		     int *rows_used)
@@ -747,10 +744,13 @@ gx_image3x_plane_data(gx_image_enum_common_t * info,
 	      h, (mask_plane[0].data ? "+" : ""), penum->mask[0].y,
 	      (mask_plane[1].data ? "+" : ""), penum->mask[1].y,
 	      (pixel_planes[0].data ? "+" : ""), penum->pixel.y);
-    if (penum->mask[0].y >= penum->mask[0].height &&
-	penum->mask[1].y >= penum->mask[1].height &&
-	penum->pixel.y >= penum->pixel.height)
-	return 1;
+    if (penum->mask[0].depth == 0 || penum->mask[0].y >= penum->mask[0].height) {
+        if (penum->mask[1].depth == 0 || penum->mask[1].y >= penum->mask[1].height) {
+	    if (penum->pixel.y >= penum->pixel.height) {
+	        return 1;
+            }
+        }
+    }
     /*
      * The mask may be complete (gx_image_plane_data_rows returned 1),
      * but there may still be pixel rows to go, so don't return 1 here.
@@ -759,7 +759,7 @@ gx_image3x_plane_data(gx_image_enum_common_t * info,
 }
 
 /* Flush buffered data. */
-private int
+static int
 gx_image3x_flush(gx_image_enum_common_t * info)
 {
     gx_image3x_enum_t * const penum = (gx_image3x_enum_t *) info;
@@ -773,7 +773,7 @@ gx_image3x_flush(gx_image_enum_common_t * info)
 }
 
 /* Determine which data planes are wanted. */
-private bool
+static bool
 gx_image3x_planes_wanted(const gx_image_enum_common_t * info, byte *wanted)
 {
     const gx_image3x_enum_t * const penum = (const gx_image3x_enum_t *) info;
@@ -825,7 +825,7 @@ gx_image3x_planes_wanted(const gx_image_enum_common_t * info, byte *wanted)
 }
 
 /* Clean up after processing an ImageType 3x image. */
-private int
+static int
 gx_image3x_end_image(gx_image_enum_common_t * info, bool draw_last)
 {
     gx_image3x_enum_t *penum = (gx_image3x_enum_t *) info;
