@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gximage.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: gximage.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Generic image support */
 #include "memory_.h"
 #include "gx.h"
@@ -237,7 +237,7 @@ gx_image_default_release(gs_image_common_t *pic, gs_memory_t *mem)
 }
 
 #ifdef DEBUG
-private void
+static void
 debug_b_print_matrix(const gs_pixel_image_t *pim)
 {
     if_debug6('b', "      ImageMatrix=[%g %g %g %g %g %g]\n",
@@ -245,7 +245,7 @@ debug_b_print_matrix(const gs_pixel_image_t *pim)
 	      pim->ImageMatrix.yx, pim->ImageMatrix.yy,
 	      pim->ImageMatrix.tx, pim->ImageMatrix.ty);
 }
-private void
+static void
 debug_b_print_decode(const gs_pixel_image_t *pim, int num_decode)
 {
     if (gs_debug_c('b')) {
