@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
    This software is provided AS-IS with no warranty, either express or
@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gxiparam.h 6651 2006-03-13 16:18:19Z stefan $ */
+/* $Id: gxiparam.h 8022 2007-06-05 22:23:38Z giles $ */
 /* Definitions for implementors of image types */
 
 #ifndef gxiparam_INCLUDED
@@ -75,7 +75,7 @@ struct gx_image_type_s {
      * use pcs.
      */
 #define image_proc_sget(proc)\
-  int proc(gs_image_common_t *pic, stream *s, const gs_color_space *pcs)
+  int proc(gs_image_common_t *pic, stream *s, gs_color_space *pcs)
 
     image_proc_sget((*sget));
 
@@ -114,7 +114,7 @@ image_proc_release(gx_image_default_release); /* just free the params */
 int gx_pixel_image_sput(const gs_pixel_image_t *pic, stream *s,
 			const gs_color_space **ppcs, int extra);
 int gx_pixel_image_sget(gs_pixel_image_t *pic, stream *s,
-			const gs_color_space *pcs);
+			gs_color_space *pcs);
 void gx_pixel_image_release(gs_pixel_image_t *pic, gs_memory_t *mem);
 
 /* Internal procedures for use in sput/sget implementations. */
@@ -214,6 +214,7 @@ typedef struct gx_image_enum_procs_s {
 	const gx_image_enum_procs_t *procs;\
 	gx_device *dev;\
 	gs_id id;\
+	bool skipping; /* don't render, just consume image streams. */\
 	int num_planes;\
 	int plane_depths[gs_image_max_planes];	/* [num_planes] */\
 	int plane_widths[gs_image_max_planes]	/* [num_planes] */
