@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gxmclip.c 8056 2007-06-18 06:37:58Z ray $ */
+/* $Id: gxmclip.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Mask clipping support */
 #include "gserrors.h"
 #include "gx.h"
@@ -23,7 +23,7 @@
 public_st_device_mask_clip();
 
 /* GC procedures */
-private ENUM_PTRS_WITH(device_mask_clip_enum_ptrs, gx_device_mask_clip *mcdev)
+static ENUM_PTRS_WITH(device_mask_clip_enum_ptrs, gx_device_mask_clip *mcdev)
 {
     if (index < st_gx_strip_bitmap_max_ptrs) {
 	return ENUM_USING(st_gx_strip_bitmap, &mcdev->tiles,
@@ -37,7 +37,7 @@ private ENUM_PTRS_WITH(device_mask_clip_enum_ptrs, gx_device_mask_clip *mcdev)
     ENUM_PREFIX(st_device_forward, st_device_memory_max_ptrs);
 }
 ENUM_PTRS_END
-private RELOC_PTRS_WITH(device_mask_clip_reloc_ptrs, gx_device_mask_clip *mcdev)
+static RELOC_PTRS_WITH(device_mask_clip_reloc_ptrs, gx_device_mask_clip *mcdev)
 {
     RELOC_PREFIX(st_device_forward);
     RELOC_USING(st_gx_strip_bitmap, &mcdev->tiles, sizeof(mcdev->tiles));
