@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: iinit.h 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: iinit.h 8342 2007-11-01 16:20:01Z leonardo $ */
 /* (Internal) interface to iinit.c */
 
 #ifndef iinit_INCLUDED
@@ -24,6 +24,9 @@
 int obj_init(i_ctx_t **, gs_dual_memory_t *);
 int zop_init(i_ctx_t *);
 int op_init(i_ctx_t *);
+#ifdef DEBUG_TRACE_PS_OPERATORS
+const char *op_get_name_string(op_proc_t opproc);
+#endif
 
 /*
  * Test whether there are any Level 2 operators in the executable.
