@@ -1,27 +1,23 @@
-/* Copyright (C) 1989, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: iscan.c,v 1.5.6.5.2.1 2003/01/17 00:49:04 giles Exp $ */
+/* $Id: iscan.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Token scanner for Ghostscript interpreter */
 #include "ghost.h"
 #include "memory_.h"
+#include "string_.h"
 #include "stream.h"
-#include "errors.h"
+#include "ierrors.h"
 #include "btoken.h"		/* for ref_binary_object_format */
 #include "files.h"		/* for fptr */
 #include "ialloc.h"
@@ -49,24 +45,15 @@
 #define recognize_btokens()\
   (ref_binary_object_format.value.intval != 0 && level2_enabled)
 
-#ifdef DEBUG
-/* Dummy comment processing procedure for testing. */
-private int
-no_comment_proc(const byte * str, uint len)
-{
-    return 0;
-}
-#endif
-
 /* Procedure for handling DSC comments if desired. */
 /* Set at initialization if a DSC handling module is included. */
-int (*scan_dsc_proc) (P2(const byte *, uint)) = NULL;
+int (*scan_dsc_proc) (const byte *, uint) = NULL;
 
 /* Procedure for handling all comments if desired. */
 /* Set at initialization if a comment handling module is included. */
 /* If both scan_comment_proc and scan_dsc_proc are set, */
 /* scan_comment_proc is called only for non-DSC comments. */
-int (*scan_comment_proc) (P2(const byte *, uint)) = NULL;
+int (*scan_comment_proc) (const byte *, uint) = NULL;
 
 /*
  * Level 2 includes some changes in the scanner:
@@ -81,7 +68,7 @@ int (*scan_comment_proc) (P2(const byte *, uint)) = NULL;
 /* ------ Dynamic strings ------ */
 
 /* Begin collecting a dynamically allocated string. */
-inline private void
+static inline void
 dynamic_init(da_ptr pda, gs_memory_t *mem)
 {
     pda->is_dynamic = false;
@@ -91,7 +78,7 @@ dynamic_init(da_ptr pda, gs_memory_t *mem)
 }
 
 /* Free a dynamic string. */
-private void
+static void
 dynamic_free(da_ptr pda)
 {
     if (pda->is_dynamic)
@@ -100,7 +87,7 @@ dynamic_free(da_ptr pda)
 
 /* Resize a dynamic string. */
 /* If the allocation fails, return e_VMerror; otherwise, return 0. */
-private int
+static int
 dynamic_resize(da_ptr pda, uint new_size)
 {
     uint old_size = da_size(pda);
@@ -130,7 +117,7 @@ dynamic_resize(da_ptr pda, uint new_size)
 /* Return 0 if the allocation failed, the new 'next' ptr if OK. */
 /* Return 0 or an error code, updating pda->next to point to the first */
 /* available byte after growing. */
-private int
+static int
 dynamic_grow(da_ptr pda, byte * next, uint max_size)
 {
     uint old_size = da_size(pda);
@@ -152,7 +139,7 @@ dynamic_grow(da_ptr pda, byte * next, uint max_size)
 
 /* Ensure that a dynamic string is either on the heap or in the */
 /* private buffer. */
-private void
+static void
 dynamic_save(da_ptr pda)
 {
     if (!pda->is_dynamic && pda->base != pda->buf) {
@@ -163,7 +150,7 @@ dynamic_save(da_ptr pda)
 }
 
 /* Finish collecting a dynamic string. */
-private int
+static int
 dynamic_make_string(i_ctx_t *i_ctx_p, ref * pref, da_ptr pda, byte * next)
 {
     uint size = (pda->next = next) - pda->base;
@@ -181,28 +168,36 @@ dynamic_make_string(i_ctx_t *i_ctx_p, ref * pref, da_ptr pda, byte * next)
 
 /* GC procedures */
 #define ssarray ssptr->s_ss.binary.bin_array
-private 
+static 
 CLEAR_MARKS_PROC(scanner_clear_marks)
 {
     scanner_state *const ssptr = vptr;
 
+    r_clear_attrs(&ssptr->s_file, l_mark);
     r_clear_attrs(&ssarray, l_mark);
+    r_clear_attrs(&ssptr->s_error.object, l_mark);
 }
-private 
+static 
 ENUM_PTRS_WITH(scanner_enum_ptrs, scanner_state *ssptr) return 0;
 case 0:
+    ENUM_RETURN_REF(&ssptr->s_file);
+case 1:
+    ENUM_RETURN_REF(&ssptr->s_error.object);
+case 2:
     if (ssptr->s_scan_type == scanning_none ||
 	!ssptr->s_da.is_dynamic
 	)
 	ENUM_RETURN(0);
     return ENUM_STRING2(ssptr->s_da.base, da_size(&ssptr->s_da));
-case 1:
+case 3:
     if (ssptr->s_scan_type != scanning_binary)
 	return 0;
     ENUM_RETURN_REF(&ssarray);
 ENUM_PTRS_END
-private RELOC_PTRS_WITH(scanner_reloc_ptrs, scanner_state *ssptr)
+static RELOC_PTRS_WITH(scanner_reloc_ptrs, scanner_state *ssptr)
 {
+    RELOC_REF_VAR(ssptr->s_file);
+    r_clear_attrs(&ssptr->s_file, l_mark);
     if (ssptr->s_scan_type != scanning_none && ssptr->s_da.is_dynamic) {
 	gs_string sda;
 
@@ -217,6 +212,8 @@ private RELOC_PTRS_WITH(scanner_reloc_ptrs, scanner_state *ssptr)
 	RELOC_REF_VAR(ssarray);
 	r_clear_attrs(&ssarray, l_mark);
     }
+    RELOC_REF_VAR(ssptr->s_error.object);
+    r_clear_attrs(&ssptr->s_error.object, l_mark);
 }
 RELOC_PTRS_END
 /* Structure type */
@@ -224,20 +221,70 @@ public_st_scanner_state();
 
 /* Initialize a scanner. */
 void
-scanner_state_init_options(scanner_state *sstate, int options)
+scanner_init_options(scanner_state *sstate, const ref *fop, int options)
 {
+    ref_assign(&sstate->s_file, fop);
     sstate->s_scan_type = scanning_none;
     sstate->s_pstack = 0;
     sstate->s_options = options;
+    SCAN_INIT_ERROR(sstate);
+}
+void scanner_init_stream_options(scanner_state *sstate, stream *s,
+				 int options)
+{
+    /*
+     * The file 'object' will never be accessed, but it must be in correct
+     * form for the GC.
+     */
+    ref fobj;
+
+    make_file(&fobj, a_read, 0, s);
+    scanner_init_options(sstate, &fobj, options);
+}
+
+/*
+ * Return the "error object" to be stored in $error.command instead of
+ * --token--, if any, or <0 if no special error object is available.
+ */
+int
+scanner_error_object(i_ctx_t *i_ctx_p, const scanner_state *pstate,
+		     ref *pseo)
+{
+    if (!r_has_type(&pstate->s_error.object, t__invalid)) {
+	ref_assign(pseo, &pstate->s_error.object);
+	return 0;
+    }
+    if (pstate->s_error.string[0]) {
+	int len = strlen(pstate->s_error.string);
+
+	if (pstate->s_error.is_name) {
+	    int code = name_ref(imemory, (const byte *)pstate->s_error.string, len, pseo, 1);
+
+	    if (code < 0)
+		return code;
+	    r_set_attrs(pseo, a_executable); /* Adobe compatibility */
+	    return 0;
+	} else {
+	    byte *estr = ialloc_string(len, "scanner_error_object");
+
+	    if (estr == 0)
+		return -1;		/* VMerror */
+	    memcpy(estr, (const byte *)pstate->s_error.string, len);
+	    make_string(pseo, a_all | icurrent_space, len, estr);
+	    return 0;
+	}
+    }
+    return -1;			/* no error object */
 }
 
 /* Handle a scan_Refill return from scan_token. */
 /* This may return o_push_estack, 0 (meaning just call scan_token again), */
 /* or an error code. */
 int
-scan_handle_refill(i_ctx_t *i_ctx_p, const ref * fop, scanner_state * sstate,
-		   bool save, bool push_file, op_proc_t cont)
+scan_handle_refill(i_ctx_t *i_ctx_p, scanner_state * sstate,
+		   bool save, op_proc_t cont)
 {
+    const ref *const fop = &sstate->s_file;
     stream *s = fptr(fop);
     uint avail = sbufavailable(s);
     int status;
@@ -261,9 +308,8 @@ scan_handle_refill(i_ctx_t *i_ctx_p, const ref * fop, scanner_state * sstate,
 	case INTC:
 	case CALLC:
 	    {
-		ref rstate[2];
+		ref rstate[1];
 		scanner_state *pstate;
-		int nstate = (push_file ? 2 : 1);
 
 		if (save) {
 		    pstate =
@@ -274,16 +320,9 @@ scan_handle_refill(i_ctx_t *i_ctx_p, const ref * fop, scanner_state * sstate,
 		    *pstate = *sstate;
 		} else
 		    pstate = sstate;
-		/* If push_file is true, we want to push the file on the */
-		/* o-stack before the state, for the continuation proc. */
-		/* Since the refs passed to s_handle_read_exception */
-		/* are pushed on the e-stack, we must ensure they are */
-		/* literal, and also pass them in the opposite order! */
 		make_istruct(&rstate[0], 0, pstate);
-		rstate[1] = *fop;
-		r_clear_attrs(&rstate[1], a_executable);
 		return s_handle_read_exception(i_ctx_p, status, fop,
-					       rstate, nstate, cont);
+					       rstate, 1, cont);
 	    }
     }
     /* No more data available, but no exception.  How can this be? */
@@ -295,7 +334,7 @@ scan_handle_refill(i_ctx_t *i_ctx_p, const ref * fop, scanner_state * sstate,
  * Handle a comment.  The 'saved' argument is needed only for
  * tracing printout.
  */
-private int
+static int
 scan_comment(i_ctx_t *i_ctx_p, ref *pref, scanner_state *pstate,
 	     const byte * base, const byte * end, bool saved)
 {
@@ -356,6 +395,7 @@ scan_comment(i_ctx_t *i_ctx_p, ref *pref, scanner_state *pstate,
 
 /* Read a token from a string. */
 /* Update the string if succesful. */
+/* Store the error object in i_ctx_p->error_object if not. */
 int
 scan_string_token_options(i_ctx_t *i_ctx_p, ref * pstr, ref * pref,
 			  int options)
@@ -369,8 +409,8 @@ scan_string_token_options(i_ctx_t *i_ctx_p, ref * pstr, ref * pref,
 	return_error(e_invalidaccess);
     s_init(s, NULL);
     sread_string(s, pstr->value.bytes, r_size(pstr));
-    scanner_state_init_options(&state, options | SCAN_FROM_STRING);
-    switch (code = scan_token(i_ctx_p, s, pref, &state)) {
+    scanner_init_stream_options(&state, s, options | SCAN_FROM_STRING);
+    switch (code = scan_token(i_ctx_p, pref, &state)) {
 	default:		/* error or comment */
 	    if (code < 0)
 		break;
@@ -389,6 +429,8 @@ scan_string_token_options(i_ctx_t *i_ctx_p, ref * pstr, ref * pref,
 	case scan_EOF:
 	    break;
     }
+    if (code < 0)
+	scanner_error_object(i_ctx_p, &state, &i_ctx_p->error_object);
     return code;
 }
 
@@ -401,8 +443,9 @@ scan_string_token_options(i_ctx_t *i_ctx_p, ref * pstr, ref * pref,
  * as well as for scan_Refill.
  */
 int
-scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
+scan_token(i_ctx_t *i_ctx_p, ref * pref, scanner_state * pstate)
 {
+    stream *const s = pstate->s_file.value.pfile;
     ref *myref = pref;
     int retcode = 0;
     int c;
@@ -417,8 +460,6 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 
 #define sreturn(code)\
   { retcode = gs_note_error(code); goto sret; }
-#define sreturn_no_error(code)\
-  { scan_end_inline(); return(code); }
 #define if_not_spush1()\
   if ( osp < ostop ) osp++;\
   else if ( (retcode = ref_stack_push(&o_stack, 1)) >= 0 )\
@@ -428,7 +469,13 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
   if ( osp >= osbot ) osp--;\
   else ref_stack_pop(&o_stack, 1)
     int max_name_ctype =
-    (recognize_btokens()? ctype_name : ctype_btoken);
+	(recognize_btokens()? ctype_name : ctype_btoken);
+    /*
+     * The following is a hack so that ^D will be self-delimiting in files
+     * (to compensate for bugs in some PostScript-generating applications)
+     * but not in strings (to match CPSI on the CET).
+     */
+    int ctrld = (pstate->s_options & SCAN_FROM_STRING ? 0x04 : 0xffff);
 
 #define scan_sign(sign, ptr)\
   switch ( *ptr ) {\
@@ -436,14 +483,18 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
     case '+': sign = 1; ptr++; break;\
     default: sign = 0;\
   }
+#define refill2_back(styp,nback)\
+  BEGIN sptr -= nback; scan_type = styp; goto pause; END
 #define ensure2_back(styp,nback)\
-  if ( sptr >= endptr ) { sptr -= nback; scan_type = styp; goto pause; }
+  if ( sptr >= endptr ) refill2_back(styp,nback)
 #define ensure2(styp) ensure2_back(styp, 1)
+#define refill2(styp) refill2_back(styp, 1)
     byte s1[2];
     const byte *const decoder = scan_char_decoder;
     int status;
     int sign;
     const bool check_only = (pstate->s_options & SCAN_CHECK_ONLY) != 0;
+    const bool PDFScanRules = (i_ctx_p->scanner_options & SCAN_PDF_RULES) != 0;
     scanner_state sstate;
 
 #define pstack sstate.s_pstack
@@ -453,6 +504,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 #define name_type sstate.s_ss.s_name.s_name_type
 #define try_number sstate.s_ss.s_name.s_try_number
 
+    sptr = endptr = NULL; /* Quiet compiler */
     if (pstate->s_pstack != 0) {
 	if_not_spush1()
 	    return retcode;
@@ -475,7 +527,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	switch (scan_type) {
 	    case scanning_binary:
 		retcode = (*sstate.s_ss.binary.cont)
-		    (i_ctx_p, s, myref, &sstate);
+		    (i_ctx_p, myref, &sstate);
 		scan_begin_inline();
 		if (retcode == scan_Refill)
 		    goto pause;
@@ -495,7 +547,9 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
     /* scan_type == scanning_none. */
     pstack = pstate->s_pstack;
     pdepth = pstate->s_pdepth;
+    ref_assign(&sstate.s_file, &pstate->s_file);
     sstate.s_options = pstate->s_options;
+    SCAN_INIT_ERROR(&sstate);
     scan_begin_inline();
     /*
      * Loop invariants:
@@ -511,10 +565,13 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	case char_EOL:
 	case char_NULL:
 	    goto top;
+	case 0x04:		/* see ctrld above */
+	    if (c == ctrld)	/* treat as ordinary name char */
+		goto begin_name;
 	case '[':
 	case ']':
 	    s1[0] = (byte) c;
-	    retcode = name_ref(s1, 1, myref, 1);	/* can't fail */
+	    retcode = name_ref(imemory, s1, 1, myref, 1);	/* can't fail */
 	    r_set_attrs(myref, a_executable);
 	    break;
 	case '<':
@@ -600,7 +657,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	    sstate.s_ss.pssd.from_string =
 		((pstate->s_options & SCAN_FROM_STRING) != 0) &&
 		!scan_enable_level2;
-	    s_PSSD_init_inline(&sstate.s_ss.pssd);
+	    s_PSSD_partially_init_inline(&sstate.s_ss.pssd);
 	    sstate.s_ss.st.template = &s_PSSD_template;
 	    goto str;
 	case '{':
@@ -685,9 +742,15 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	    }
 	    break;
 	case '/':
-	    ensure2(scanning_none);
+	    /*
+	     * If the last thing in the input is a '/', don't try to read
+	     * any more data.
+	     */
+	    if (sptr >= endptr && s->end_status != EOFC) {
+		refill2(scanning_none);
+	    }
 	    c = scan_getc();
-	    if (c == '/') {
+	    if (!PDFScanRules && (c == '/')) {
 		name_type = 2;
 		c = scan_getc();
 	    } else
@@ -710,6 +773,8 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 		     * that handled these specially.)
 		     */
 		case ctype_other:
+		    if (c == ctrld) /* see above */
+			goto do_name;
 		    da.base = da.limit = daptr = 0;
 		    da.is_dynamic = false;
 		    goto nx;
@@ -814,7 +879,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 
 		if (c1 == c) {
 		    s1[0] = s1[1] = c;
-		    name_ref(s1, 2, myref, 1);	/* can't fail */
+		    name_ref(imemory, s1, 2, myref, 1);	/* can't fail */
 		    goto have_name;
 		}
 		scan_putback();
@@ -843,7 +908,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	     */
 	    retcode = scan_number(sptr + (sign & 1),
 		    endptr /*(*endptr == char_CR ? endptr : endptr + 1) */ ,
-				  sign, myref, &newptr);
+				  sign, myref, &newptr, i_ctx_p->scanner_options);
 	    if (retcode == 1 && decoder[newptr[-1]] == ctype_space) {
 		sptr = newptr - 1;
 		if (*sptr == char_CR && sptr[1] == char_EOL)
@@ -869,7 +934,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 #undef case4
 	    if (recognize_btokens()) {
 		scan_end_inline();
-		retcode = scan_binary_token(i_ctx_p, s, myref, &sstate);
+		retcode = scan_binary_token(i_ctx_p, myref, &sstate);
 		scan_begin_inline();
 		if (retcode == scan_Refill)
 		    goto pause;
@@ -880,7 +945,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	    /* The default is a name. */
 	default:
 	    if (c < 0) {
-		dynamic_init(&da, name_memory());	/* da state must be clean */
+		dynamic_init(&da, name_memory(imemory));	/* da state must be clean */
 		scan_type = scanning_none;
 		goto pause;
 	    }
@@ -957,10 +1022,11 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	case 'z':
 	case '|':
 	case '~':
+	  begin_name:
 	    /* Common code for scanning a name. */
 	    /* try_number and name_type are already set. */
-	    /* We know c has ctype_name (or maybe ctype_btoken) */
-	    /* or is a digit. */
+	    /* We know c has ctype_name (or maybe ctype_btoken, */
+	    /* or is ^D) or is a digit. */
 	    name_type = 0;
 	    try_number = false;
 	  do_name:
@@ -976,7 +1042,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 		    if (sptr >= endp1)	/* stop 1 early! */
 			goto dyn_name;
 		}
-		while (decoder[*++sptr] <= max_name_ctype);	/* digit or name */
+		while (decoder[*++sptr] <= max_name_ctype || *sptr == ctrld);	/* digit or name */
 	    }
 	    /* Name ended within the buffer. */
 	    daptr = (byte *) sptr;
@@ -988,7 +1054,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	    /* We have to do this before the next */
 	    /* sgetc, which will overwrite the buffer. */
 	    da.limit = (byte *)++ sptr;
-	    da.memory = name_memory();
+	    da.memory = name_memory(imemory);
 	    retcode = dynamic_grow(&da, da.limit, name_max_string);
 	    if (retcode < 0) {
 		dynamic_save(&da);
@@ -1001,7 +1067,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	    /* Enter here to continue scanning a name. */
 	    /* daptr must be set. */
 	  cont_name:scan_begin_inline();
-	    while (decoder[c = scan_getc()] <= max_name_ctype) {
+	    while (decoder[c = scan_getc()] <= max_name_ctype || c == ctrld) {
 		if (daptr == da.limit) {
 		    retcode = dynamic_grow(&da, daptr,
 					   name_max_string);
@@ -1018,8 +1084,10 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 		*daptr++ = c;
 	    }
 	  nx:switch (decoder[c]) {
-		case ctype_btoken:
 		case ctype_other:
+		    if (c == ctrld) /* see above */
+			break;
+		case ctype_btoken:
 		    scan_putback();
 		    break;
 		case ctype_space:
@@ -1052,7 +1120,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 		const byte *base = da.base;
 
 		scan_sign(sign, base);
-		retcode = scan_number(base, daptr, sign, myref, &newptr);
+		retcode = scan_number(base, daptr, sign, myref, &newptr, i_ctx_p->scanner_options);
 		if (retcode == 1) {
 		    ref_mark_new(myref);
 		    retcode = 0;
@@ -1066,7 +1134,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 	    if (da.is_dynamic) {	/* We've already allocated the string on the heap. */
 		uint size = daptr - da.base;
 
-		retcode = name_ref(da.base, size, myref, -1);
+		retcode = name_ref(imemory, da.base, size, myref, -1);
 		if (retcode >= 0) {
 		    dynamic_free(&da);
 		} else {
@@ -1077,10 +1145,10 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 			scan_type = scanning_name;
 			goto pause_ret;
 		    }
-		    retcode = name_ref(da.base, size, myref, 2);
+		    retcode = name_ref(imemory, da.base, size, myref, 2);
 		}
 	    } else {
-		retcode = name_ref(da.base, (uint) (daptr - da.base),
+		retcode = name_ref(imemory, da.base, (uint) (daptr - da.base),
 				   myref, !s->foreign);
 	    }
 	    /* Done scanning.  Check for preceding /'s. */
@@ -1106,10 +1174,13 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
 		    {
 			ref *pvalue;
 
-			if (!r_has_type(myref, t_name))
-			    sreturn(e_undefined);
-			if ((pvalue = dict_find_name(myref)) == 0)
+			if (!r_has_type(myref, t_name) ||
+			    (pvalue = dict_find_name(myref)) == 0) {
+			    ref_assign(&sstate.s_error.object, myref);
+			    r_set_attrs(&sstate.s_error.object,
+				a_executable); /* Adobe compatibility */
 			    sreturn(e_undefined);
+			}
 			if (pstack != 0 &&
 			    r_space(pvalue) > ialloc_space(idmemory)
 			    )
@@ -1120,6 +1191,7 @@ scan_token(i_ctx_t *i_ctx_p, stream * s, ref * pref, scanner_state * pstate)
     }
   sret:if (retcode < 0) {
 	scan_end_inline();
+	pstate->s_error = sstate.s_error;
 	if (pstack != 0) {
 	    if (retcode == e_undefined)
 		*pref = *osp;	/* return undefined name as error token */
