@@ -1,27 +1,23 @@
-/* Copyright (C) 1994, 1995, 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: iscannum.c,v 1.3.2.1.2.1 2003/01/17 00:49:04 giles Exp $ */
+/* $Id: iscannum.c 8022 2007-06-05 22:23:38Z giles $ */
 /* Number scanner for Ghostscript interpreter */
 #include "math_.h"
 #include "ghost.h"
-#include "errors.h"
+#include "ierrors.h"
 #include "scommon.h"
+#include "iscan.h"
 #include "iscannum.h"		/* defines interface */
 #include "scanchar.h"
 #include "store.h"
@@ -38,7 +34,7 @@
  */
 int
 scan_number(const byte * str, const byte * end, int sign,
-	    ref * pref, const byte ** psp)
+	    ref * pref, const byte ** psp, int scanner_options)
 {
     const byte *sp = str;
 #define GET_NEXT(cvar, sp, end_action)\
@@ -62,6 +58,7 @@ scan_number(const byte * str, const byte * end, int sign,
     int exp10;
     int code = 0;
     int c, d;
+    uint max_scan; /* max signed or unsigned int */
     const byte *const decoder = scan_char_decoder;
 #define IS_DIGIT(d, c)\
   ((d = decoder[c]) < 10)
@@ -100,12 +97,13 @@ scan_number(const byte * str, const byte * end, int sign,
 	    goto ind;
 	ival = ival * 10 + d;
     }
+    max_scan = scanner_options & SCAN_PDF_UNSIGNED && sign >= 0 ? ~0 : max_int;
     for (;; ival = ival * 10 + d) {
 	GET_NEXT(c, sp, goto iret);
 	if (!IS_DIGIT(d, c))
 	    break;
-	if (WOULD_OVERFLOW(ival, d, max_int))
-	    goto i2l;
+        if (WOULD_OVERFLOW(((unsigned)ival), d, max_scan))
+            goto i2l;
     }
   ind:				/* We saw a non-digit while accumulating an integer in ival. */
     switch (c) {
@@ -192,8 +190,8 @@ iret:
 
     /* Accumulate a long in lval. */
 i2l:
-    for (lval = ival;;) {
-	if (WOULD_OVERFLOW(lval, d, max_long)) {
+    for (lval = (unsigned)ival;;) {
+	if (WOULD_OVERFLOW(((unsigned long)lval), d, ((unsigned long)max_long))) {
 	    /* Make a special check for entering the smallest */
 	    /* (most negative) integer. */
 	    if (lval == max_long / 10 &&
@@ -201,15 +199,19 @@ i2l:
 		) {
 		GET_NEXT(c, sp, c = EOFC);
 		dval = -(double)min_long;
-		if (c == 'e' || c == 'E' || c == '.') {
+		if (c == 'e' || c == 'E') {
 		    exp10 = 0;
 		    goto fs;
-		} else if (!IS_DIGIT(d, c)) {
+		} else if (c == '.') {
+                    GET_NEXT(c, sp, c = EOFC);
+		    exp10 = 0;
+		    goto fd;
+                } else if (!IS_DIGIT(d, c)) {
 		    lval = min_long;
 		    break;
 		}
 	    } else
-		dval = lval;
+		dval = (unsigned long)lval;
 	    goto l2d;
 	}
 	lval = lval * 10 + d;
@@ -272,7 +274,22 @@ l2d:
     /* We saw a '.' while accumulating an integer in ival. */
 i2r:
     exp10 = 0;
-    while (IS_DIGIT(d, c)) {
+    while (IS_DIGIT(d, c) || c == '-') {
+	/*
+	 * PostScript gives an error on numbers with a '-' following a '.'
+	 * Adobe Acrobat Reader (PDF) apparently doesn't treat this as an
+	 * error. Experiments show that the numbers following the '-' are
+	 * ignored, so we swallow the fractional part. SCAN_PDF_INV_NUM
+	 *  enables this compatibility kloodge.
+	 */
+	if (c == '-') {
+	    if ((SCAN_PDF_INV_NUM & scanner_options) == 0)
+		break;
+	    do {
+		GET_NEXT(c, sp, c = EOFC);
+	    } while (IS_DIGIT(d, c));
+	    break;
+	}
 	if (WOULD_OVERFLOW(ival, d, max_int)) {
 	    lval = ival;
 	    goto l2r;
@@ -295,7 +312,16 @@ i2r:
 
     /* We saw a '.' while accumulating a long in lval. */
 l2r:
-    while (IS_DIGIT(d, c)) {
+    while (IS_DIGIT(d, c) || c == '-') {
+	/* Handle bogus '-' following '.' as in i2r above.	*/
+	if (c == '-') {
+	    if ((scanner_options & SCAN_PDF_INV_NUM) == 0)
+		break;
+	    do {
+		GET_NEXT(c, sp, c = EOFC);
+	    } while (IS_DIGIT(d, c));
+	    break;
+	}
 	if (WOULD_OVERFLOW(lval, d, max_long)) {
 	    dval = lval;
 	    goto fd;
