@@ -1,30 +1,24 @@
-/* Copyright (C) 1994, 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: sdcte.c,v 1.4.2.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: sdcte.c 8250 2007-09-25 13:31:24Z giles $ */
 /* DCT encoding filter stream */
 #include "memory_.h"
 #include "stdio_.h"
 #include "jpeglib_.h"
 #include "jerror_.h"
 #include "gdebug.h"
-#include "gsmemory.h"		/* for gsmalloc.h */
-#include "gsmalloc.h"		/* for gs_memory_default */
+#include "gsmemory.h"
 #include "strimpl.h"
 #include "sdct.h"
 #include "sjpeg.h"
@@ -34,22 +28,22 @@ public_st_jpeg_compress_data();
 /* ------ DCTEncode ------ */
 
 /* JPEG destination manager procedures */
-private void
+static void
 dcte_init_destination(j_compress_ptr cinfo)
 {
 }
-private boolean
+static boolean
 dcte_empty_output_buffer(j_compress_ptr cinfo)
 {
     return FALSE;
 }
-private void
+static void
 dcte_term_destination(j_compress_ptr cinfo)
 {
 }
 
 /* Set the defaults for the DCTEncode filter. */
-private void
+static void
 s_DCTE_set_defaults(stream_state * st)
 {
     stream_DCT_state *const ss = (stream_DCT_state *) st;
@@ -63,7 +57,7 @@ s_DCTE_set_defaults(stream_state * st)
 }
 
 /* Initialize DCTEncode filter */
-private int
+static int
 s_DCTE_init(stream_state * st)
 {
     stream_DCT_state *const ss = (stream_DCT_state *) st;
@@ -79,7 +73,7 @@ s_DCTE_init(stream_state * st)
 }
 
 /* Process a buffer */
-private int
+static int
 s_DCTE_process(stream_state * st, stream_cursor_read * pr,
 	       stream_cursor_write * pw, bool last)
 {
@@ -87,12 +81,19 @@ s_DCTE_process(stream_state * st, stream_cursor_read * pr,
     jpeg_compress_data *jcdp = ss->data.compress;
     struct jpeg_destination_mgr *dest = jcdp->cinfo.dest;
 
+    if_debug2('w', "[wde]process avail=%u, last=%d\n",
+	      (uint) (pr->limit - pr->ptr), last);
     dest->next_output_byte = pw->ptr + 1;
     dest->free_in_buffer = pw->limit - pw->ptr;
     switch (ss->phase) {
 	case 0:		/* not initialized yet */
 	    if (gs_jpeg_start_compress(ss, TRUE) < 0)
 		return ERRC;
+	    if_debug4('w', "[wde]width=%u, height=%u, components=%d, scan_line_size=%u\n",
+		      jcdp->cinfo.image_width,
+		      jcdp->cinfo.image_height,
+		      jcdp->cinfo.input_components,
+		      ss->scan_line_size);
 	    pw->ptr = dest->next_output_byte - 1;
 	    ss->phase = 1;
 	    /* falls through */
@@ -141,6 +142,8 @@ s_DCTE_process(stream_state * st, stream_cursor_read * pr,
 		 */
 		/*const */ byte *samples = (byte *) (pr->ptr + 1);
 
+		if_debug1('w', "[wde]next_scanline=%u\n",
+			  jcdp->cinfo.next_scanline);
 		if ((uint) (pr->limit - pr->ptr) < ss->scan_line_size) {
 		    if (last)
 			return ERRC;	/* premature EOD */
@@ -149,6 +152,10 @@ s_DCTE_process(stream_state * st, stream_cursor_read * pr,
 		written = gs_jpeg_write_scanlines(ss, &samples, 1);
 		if (written < 0)
 		    return ERRC;
+		if_debug3('w', "[wde]write returns %d, used=%u, written=%u\n",
+			  written,
+			  (uint) (samples - 1 - pr->ptr),
+			  (uint) (dest->next_output_byte - 1 - pw->ptr));
 		pw->ptr = dest->next_output_byte - 1;
 		if (!written)
 		    return 1;	/* output full */
@@ -174,6 +181,7 @@ s_DCTE_process(stream_state * st, stream_cursor_read * pr,
 		int count = min(jcdp->fcb_size - jcdp->fcb_pos,
 				pw->limit - pw->ptr);
 
+		if_debug1('w', "[wde]copying final %d\n", count);
 		memcpy(pw->ptr + 1, jcdp->finish_compress_buf + jcdp->fcb_pos,
 		       count);
 		jcdp->fcb_pos += count;
@@ -188,7 +196,7 @@ s_DCTE_process(stream_state * st, stream_cursor_read * pr,
 }
 
 /* Release the stream */
-private void
+static void
 s_DCTE_release(stream_state * st)
 {
     stream_DCT_state *const ss = (stream_DCT_state *) st;
