@@ -1,22 +1,17 @@
-/* Copyright (C) 1996, 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: spngp.c,v 1.2.6.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: spngp.c 8250 2007-09-25 13:31:24Z giles $ */
 /* PNG pixel prediction filters */
 #include "memory_.h"
 #include "strimpl.h"
@@ -35,12 +30,12 @@ private_st_PNGP_state();
 #define cOptimum 15
 #define cEncode -10
 #define cDecode -4
-private const byte pngp_case_needs_prev[] = {
+static const byte pngp_case_needs_prev[] = {
     0, 0, 1, 1, 1, 1
 };
 
 /* Set defaults */
-private void
+static void
 s_PNGP_set_defaults(stream_state * st)
 {
     stream_PNGP_state *const ss = (stream_PNGP_state *) st;
@@ -49,7 +44,7 @@ s_PNGP_set_defaults(stream_state * st)
 }
 
 /* Common (re)initialization. */
-private int
+static int
 s_PNGP_reinit(stream_state * st)
 {
     stream_PNGP_state *const ss = (stream_PNGP_state *) st;
@@ -61,7 +56,7 @@ s_PNGP_reinit(stream_state * st)
 }
 
 /* Common initialization. */
-private int
+static int
 s_pngp_init(stream_state * st, bool need_prev)
 {
     stream_PNGP_state *const ss = (stream_PNGP_state *) st;
@@ -89,7 +84,7 @@ s_pngp_init(stream_state * st, bool need_prev)
 }
 
 /* Initialize PNGPredictorEncode filter. */
-private int
+static int
 s_PNGPE_init(stream_state * st)
 {
     stream_PNGP_state *const ss = (stream_PNGP_state *) st;
@@ -98,14 +93,14 @@ s_PNGPE_init(stream_state * st)
 }
 
 /* Initialize PNGPredictorDecode filter. */
-private int
+static int
 s_PNGPD_init(stream_state * st)
 {
     return s_pngp_init(st, true);
 }
 
 /* Release a PNGPredictor filter. */
-private void
+static void
 s_PNGP_release(stream_state *st)
 {
     stream_PNGP_state *const ss = (stream_PNGP_state *) st;
@@ -118,10 +113,12 @@ s_PNGP_release(stream_state *st)
  * Process a partial buffer.  We pass in current and previous pointers
  * to both the current and preceding scan line.  Note that dprev is
  * p - bpp for encoding, q - bpp for decoding; similarly, the 'up' row
- * is the raw data for encoding, the filtered data for decoding.
+ * is the raw data for encoding, the filtered (encoded) data for decoding.
  * Note also that the case_index cannot be cOptimum.
+ *
+ * Uses ss->case_index; uses and updates ss->row_left, pr->ptr, pw->ptr.
  */
-private int
+static int
 paeth_predictor(int a, int b, int c)
 {
     /* The definitions of ac and bc are correct, not a typo. */
@@ -131,7 +128,7 @@ paeth_predictor(int a, int b, int c)
 
     return (pa <= pb && pa <= pc ? a : pb <= pc ? b : c);
 }
-private void
+static void
 s_pngp_process(stream_state * st, stream_cursor_write * pw,
 	       const byte * dprev, stream_cursor_read * pr,
 	       const byte * upprev, const byte * up, uint count)
@@ -185,7 +182,7 @@ s_pngp_process(stream_state * st, stream_cursor_write * pw,
 
 /* Calculate the number of bytes for the next processing step, */
 /* the min of (input data, output data, remaining row length). */
-private uint
+static uint
 s_pngp_count(const stream_state * st_const, const stream_cursor_read * pr,
 	     const stream_cursor_write * pw)
 {
@@ -212,13 +209,16 @@ s_pngp_count(const stream_state * st_const, const stream_cursor_read * pr,
  *        of the current input row.
  *      prev_row[P .. N + B - 1] contain bytes P - B .. N - 1
  *        of the previous input row.
+ * We must handle the edges of each row specially, by clearing ss->prev at
+ * the beginning of each row, and copying trailing bytes from ss->prev (and
+ * possibly the input) to prev_row at the end of each row.
  */
-private int
+static int
 optimum_predictor(const stream_state * st, const stream_cursor_read * pr)
 {
     return cSub;
 }
-private int
+static int
 s_PNGPE_process(stream_state * st, stream_cursor_read * pr,
 		stream_cursor_write * pw, bool last)
 {
@@ -258,10 +258,15 @@ s_PNGPE_process(stream_state * st, stream_cursor_read * pr,
 
 	    /* Process bytes whose predecessors are in prev. */
 	    s_pngp_process(st, pw, ss->prev, pr, up - bpp, up, n);
+	    if (ss->row_left == 0) {
+		if (ss->prev_row) {
+		    memcpy(up - bpp, ss->prev, bpp);
+		    memcpy(up, pr->ptr - (n - 1), n);
+		}
+		continue;
+	    }
 	    if (ss->prev_row)
 		memcpy(up - bpp, ss->prev, n);
-	    if (ss->row_left == 0)
-		continue;
 	    if (n < bpp) {
 		/*
 		 * We didn't have both enough input data and enough output
@@ -303,8 +308,11 @@ s_PNGPE_process(stream_state * st, stream_cursor_read * pr,
  *        of the current output row.
  *      prev_row[P .. N + B - 1] contain bytes P - B .. N - 1
  *        of the previous output row.
+ * We must handle the edges of each row specially, by clearing ss->prev at
+ * the beginning of each row, and copying trailing bytes from ss->prev (and
+ * possibly the output) to prev_row at the end of each row.
  */
-private int
+static int
 s_PNGPD_process(stream_state * st, stream_cursor_read * pr,
 		stream_cursor_write * pw, bool last)
 {
@@ -340,10 +348,15 @@ s_PNGPD_process(stream_state * st, stream_cursor_read * pr,
 
 	    /* Process bytes whose predecessors are in prev. */
 	    s_pngp_process(st, pw, ss->prev, pr, up - bpp, up, n);
+	    if (ss->row_left == 0) {
+		if (ss->prev_row) {
+		    memcpy(up - bpp, ss->prev, bpp);
+		    memcpy(up, pw->ptr - (n - 1), n);
+		}
+		continue;
+	    }
 	    if (ss->prev_row)
 		memcpy(up - bpp, ss->prev, n);
-	    if (ss->row_left == 0)
-		continue;
 	    if (n < bpp) {
 		/*
 		 * We didn't have both enough input data and enough output
