@@ -1,22 +1,17 @@
-/* Copyright (C) 1995, 1996, 1997, 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: srld.c,v 1.2.6.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: srld.c 8250 2007-09-25 13:31:24Z giles $ */
 /* RunLengthDecode filter */
 #include "stdio_.h"		/* includes std.h */
 #include "memory_.h"
@@ -28,7 +23,7 @@
 private_st_RLD_state();
 
 /* Set defaults */
-private void
+static void
 s_RLD_set_defaults(stream_state * st)
 {
     stream_RLD_state *const ss = (stream_RLD_state *) st;
@@ -37,7 +32,7 @@ s_RLD_set_defaults(stream_state * st)
 }
 
 /* Initialize */
-private int
+static int
 s_RLD_init(stream_state * st)
 {
     stream_RLD_state *const ss = (stream_RLD_state *) st;
@@ -46,7 +41,7 @@ s_RLD_init(stream_state * st)
 }
 
 /* Refill the buffer */
-private int
+static int
 s_RLD_process(stream_state * st, stream_cursor_read * pr,
 	      stream_cursor_write * pw, bool last)
 {
