@@ -1,31 +1,25 @@
-/* Copyright (C) 1995, 1996, 1997, 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: szlibd.c,v 1.3.4.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: szlibd.c 8250 2007-09-25 13:31:24Z giles $ */
 /* zlib decoding (decompression) filter stream */
+#include "memory_.h"
 #include "std.h"
-#include "gsmemory.h"
-#include "gsmalloc.h"		/* for gs_memory_default */
 #include "strimpl.h"
 #include "szlibxx.h"
 
 /* Initialize the filter. */
-private int
+static int
 s_zlibD_init(stream_state * st)
 {
     stream_zlib_state *const ss = (stream_zlib_state *)st;
@@ -45,7 +39,7 @@ s_zlibD_init(stream_state * st)
 }
 
 /* Reinitialize the filter. */
-private int
+static int
 s_zlibD_reset(stream_state * st)
 {
     stream_zlib_state *const ss = (stream_zlib_state *)st;
@@ -56,7 +50,7 @@ s_zlibD_reset(stream_state * st)
 }
 
 /* Process a buffer */
-private int
+static int
 s_zlibD_process(stream_state * st, stream_cursor_read * pr,
 		stream_cursor_write * pw, bool ignore_last)
 {
@@ -64,6 +58,7 @@ s_zlibD_process(stream_state * st, stream_cursor_read * pr,
     z_stream *zs = &ss->dynamic->zstate;
     const byte *p = pr->ptr;
     int status;
+    static const unsigned char jaws_empty[] = {0x58, 0x85, 1, 0, 0, 0, 0, 0, 1, 0x0A};
 
     /* Detect no input or full output so that we don't get */
     /* a Z_BUF_ERROR return. */
@@ -75,6 +70,14 @@ s_zlibD_process(stream_state * st, stream_cursor_read * pr,
     zs->avail_in = pr->limit - p;
     zs->next_out = pw->ptr + 1;
     zs->avail_out = pw->limit - pw->ptr;
+    if (zs->total_in == 0 && zs->avail_in >= 10 && !memcmp(zs->next_in, jaws_empty, 10)) {
+        /* JAWS PDF generator encodes empty stream as jaws_empty[].
+         * The stream declares that the data block length is zero
+         * but zlib routines regard a zero length data block to be an error. 
+         */
+        pr->ptr += 10;
+        return EOFC;
+    }
     status = inflate(zs, Z_PARTIAL_FLUSH);
     pr->ptr = zs->next_in - 1;
     pw->ptr = zs->next_out - 1;
@@ -84,12 +87,21 @@ s_zlibD_process(stream_state * st, stream_cursor_read * pr,
 	case Z_STREAM_END:
 	    return EOFC;
 	default:
+            if (!strcmp("incorrect data check", zs->msg))
+            {
+                /* Ignore errors when zlib streams fail on the checksum.
+                 * Adobe, Apple and xpdf don't fail on pdf:s where this happens,
+                 * so neither should we. fixes bug 688716.
+                 */
+                errprintf("warning: ignoring zlib error: %s\n", zs->msg);
+                return EOFC;
+            }
 	    return ERRC;
     }
 }
 
 /* Release the stream */
-private void
+static void
 s_zlibD_release(stream_state * st)
 {
     stream_zlib_state *const ss = (stream_zlib_state *)st;
