@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: zcfont.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: zcfont.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Composite font-related character operators */
 #include "ghost.h"
 #include "oper.h"
@@ -26,11 +26,11 @@
 #include "store.h"
 
 /* Forward references */
-private int cshow_continue(i_ctx_t *);
-private int cshow_restore_font(i_ctx_t *);
+static int cshow_continue(i_ctx_t *);
+static int cshow_restore_font(i_ctx_t *);
 
 /* <proc> <string> cshow - */
-private int
+static int
 zcshow(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -65,7 +65,7 @@ zcshow(i_ctx_t *i_ctx_p)
     pop(2);
     return cshow_continue(i_ctx_p);
 }
-private int
+static int
 cshow_continue(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -137,7 +137,7 @@ cshow_continue(i_ctx_t *i_ctx_p)
     }
     return o_push_estack;
 }
-private int
+static int
 cshow_restore_font(i_ctx_t *i_ctx_p)
 {
     /* We must restore both the root font and the current font. */
@@ -147,7 +147,7 @@ cshow_restore_font(i_ctx_t *i_ctx_p)
 }
 
 /* - rootfont <font> */
-private int
+static int
 zrootfont(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
