@@ -1,22 +1,17 @@
-/* Copyright (C) 1992, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zcharx.c,v 1.3.6.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: zcharx.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Level 2 character operators */
 #include "ghost.h"
 #include "oper.h"
@@ -24,14 +19,16 @@
 #include "gstext.h"
 #include "gxfixed.h"		/* for gxfont.h */
 #include "gxfont.h"
+#include "gxtext.h"
 #include "ialloc.h"
 #include "ichar.h"
 #include "igstate.h"
 #include "iname.h"
 #include "ibnum.h"
+#include "memory_.h"
 
 /* Common setup for glyphshow and .glyphwidth. */
-private int
+static int
 glyph_show_setup(i_ctx_t *i_ctx_p, gs_glyph *pglyph)
 {
     os_ptr op = osp;
@@ -46,13 +43,13 @@ glyph_show_setup(i_ctx_t *i_ctx_p, gs_glyph *pglyph)
 	    break;
 	default:
 	    check_type(*op, t_name);
-	    *pglyph = name_index(op);
+	    *pglyph = name_index(imemory, op);
     }
     return op_show_enum_setup(i_ctx_p);
 }
 
 /* <charname> glyphshow - */
-private int
+static int
 zglyphshow(i_ctx_t *i_ctx_p)
 {
     gs_glyph glyph;
@@ -62,6 +59,7 @@ zglyphshow(i_ctx_t *i_ctx_p)
     if ((code = glyph_show_setup(i_ctx_p, &glyph)) != 0 ||
 	(code = gs_glyphshow_begin(igs, glyph, imemory, &penum)) < 0)
 	return code;
+    *(op_proc_t *)&penum->enum_client_data = zglyphshow;
     if ((code = op_show_finish_setup(i_ctx_p, penum, 1, NULL)) < 0) {
 	ifree_object(penum, "zglyphshow");
 	return code;
@@ -70,7 +68,7 @@ zglyphshow(i_ctx_t *i_ctx_p)
 }
 
 /* <charname> .glyphwidth <wx> <wy> */
-private int
+static int
 zglyphwidth(i_ctx_t *i_ctx_p)
 {
     gs_glyph glyph;
@@ -90,15 +88,16 @@ zglyphwidth(i_ctx_t *i_ctx_p)
 /* <string> <numarray|numstring> xshow - */
 /* <string> <numarray|numstring> yshow - */
 /* <string> <numarray|numstring> xyshow - */
-private int
+static int
 moveshow(i_ctx_t *i_ctx_p, bool have_x, bool have_y)
 {
     os_ptr op = osp;
     gs_text_enum_t *penum;
     int code = op_show_setup(i_ctx_p, op - 1);
     int format;
-    uint i, size;
+    uint i, size, widths_needed;
     float *values;
+    extern bool CPSI_mode;
 
     if (code != 0)
 	return code;
@@ -109,12 +108,34 @@ moveshow(i_ctx_t *i_ctx_p, bool have_x, bool have_y)
     values = (float *)ialloc_byte_array(size, sizeof(float), "moveshow");
     if (values == 0)
 	return_error(e_VMerror);
-    for (i = 0; i < size; ++i) {
+    if (CPSI_mode)
+	memset(values, 0, size * sizeof(values[0])); /* Safety. */
+    if ((code = gs_xyshow_begin(igs, op[-1].value.bytes, r_size(op - 1),
+				(have_x ? values : (float *)0),
+				(have_y ? values : (float *)0),
+				size, imemory, &penum)) < 0) {
+	ifree_object(values, "moveshow");
+	return code;
+    }
+    if (CPSI_mode) {
+	/* CET 13-29.PS page 2 defines a longer width array
+	   then the text requires, and CPSI silently ignores extra elements.
+	   So we need to compute exact number of characters 
+	   to know how many elements to load and type check. */
+	code = gs_text_count_chars(igs, gs_get_text_params(penum), imemory);
+	if (code < 0)
+	    return code;
+	widths_needed = code;
+	if (have_x && have_y)
+	    widths_needed <<= 1;
+    } else
+	widths_needed = size;
+    for (i = 0; i < widths_needed; ++i) {
 	ref value;
 
-	switch (code = num_array_get(op, format, i, &value)) {
+	switch (code = num_array_get(imemory, op, format, i, &value)) {
 	case t_integer:
-	    values[i] = value.value.intval; break;
+	    values[i] = (float)value.value.intval; break;
 	case t_real:
 	    values[i] = value.value.realval; break;
 	case t_null:
@@ -125,28 +146,24 @@ moveshow(i_ctx_t *i_ctx_p, bool have_x, bool have_y)
 	    return code;
 	}
     }
-    if ((code = gs_xyshow_begin(igs, op[-1].value.bytes, r_size(op - 1),
-				(have_x ? values : (float *)0),
-				(have_y ? values : (float *)0),
-				size, imemory, &penum)) < 0 ||
-	(code = op_show_finish_setup(i_ctx_p, penum, 2, NULL)) < 0) {
+    if ((code = op_show_finish_setup(i_ctx_p, penum, 2, NULL)) < 0) {
 	ifree_object(values, "moveshow");
 	return code;
     }
     pop(2);
     return op_show_continue(i_ctx_p);
 }
-private int
+static int
 zxshow(i_ctx_t *i_ctx_p)
 {
     return moveshow(i_ctx_p, true, false);
 }
-private int
+static int
 zyshow(i_ctx_t *i_ctx_p)
 {
     return moveshow(i_ctx_p, false, true);
 }
-private int
+static int
 zxyshow(i_ctx_t *i_ctx_p)
 {
     return moveshow(i_ctx_p, true, true);
