@@ -1,22 +1,17 @@
-/* Copyright (C) 1992, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zdosio.c,v 1.2.6.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: zdosio.c 8250 2007-09-25 13:31:24Z giles $ */
 /* MS-DOS direct I/O operators. */
 /* These should NEVER be included in a released configuration! */
 #include "dos_.h"
@@ -25,7 +20,7 @@
 #include "store.h"
 
 /* <port> .inport <word> */
-private int
+static int
 zinport(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -36,7 +31,7 @@ zinport(i_ctx_t *i_ctx_p)
 }
 
 /* <port> .inportb <byte> */
-private int
+static int
 zinportb(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -47,7 +42,7 @@ zinportb(i_ctx_t *i_ctx_p)
 }
 
 /* <port> <word> .outport - */
-private int
+static int
 zoutport(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -60,7 +55,7 @@ zoutport(i_ctx_t *i_ctx_p)
 }
 
 /* <port> <byte> .outportb - */
-private int
+static int
 zoutportb(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -73,7 +68,7 @@ zoutportb(i_ctx_t *i_ctx_p)
 }
 
 /* <loc> .peek <byte> */
-private int
+static int
 zpeek(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -84,7 +79,7 @@ zpeek(i_ctx_t *i_ctx_p)
 }
 
 /* <loc> <byte> .poke - */
-private int
+static int
 zpoke(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
