@@ -1,22 +1,17 @@
-/* Copyright (C) 1994, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zfbcp.c,v 1.3.6.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zfbcp.c 8250 2007-09-25 13:31:24Z giles $ */
 /* (T)BCP filter creation */
 #include "memory_.h"
 #include "ghost.h"
@@ -29,12 +24,12 @@
 #include "ifilter.h"
 
 /* Define null handlers for the BCP out-of-band signals. */
-private int
+static int
 no_bcp_signal_interrupt(stream_state * st)
 {
     return 0;
 }
-private int
+static int
 no_bcp_request_status(stream_state * st)
 {
     return 0;
@@ -42,7 +37,7 @@ no_bcp_request_status(stream_state * st)
 
 /* <source> BCPEncode/filter <file> */
 /* <source> <dict> BCPEncode/filter <file> */
-private int
+static int
 zBCPE(i_ctx_t *i_ctx_p)
 {
     return filter_write_simple(i_ctx_p, &s_BCPE_template);
@@ -50,7 +45,7 @@ zBCPE(i_ctx_t *i_ctx_p)
 
 /* <target> BCPDecode/filter <file> */
 /* <target> <dict> BCPDecode/filter <file> */
-private int
+static int
 zBCPD(i_ctx_t *i_ctx_p)
 {
     stream_BCPD_state state;
@@ -62,7 +57,7 @@ zBCPD(i_ctx_t *i_ctx_p)
 
 /* <source> TBCPEncode/filter <file> */
 /* <source> <dict> TBCPEncode/filter <file> */
-private int
+static int
 zTBCPE(i_ctx_t *i_ctx_p)
 {
     return filter_write_simple(i_ctx_p, &s_TBCPE_template);
@@ -70,7 +65,7 @@ zTBCPE(i_ctx_t *i_ctx_p)
 
 /* <target> TBCPDecode/filter <file> */
 /* <target> <dict> TBCPDecode/filter <file> */
-private int
+static int
 zTBCPD(i_ctx_t *i_ctx_p)
 {
     stream_BCPD_state state;
