@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
    This software is provided AS-IS with no warranty, either express or
@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: zfdecode.c 6651 2006-03-13 16:18:19Z stefan $ */
+/* $Id: zfdecode.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Additional decoding filter creation */
 #include "memory_.h"
 #include "ghost.h"
@@ -44,7 +44,7 @@
 
 /* <target> ASCII85Encode/filter <file> */
 /* <target> <dict> ASCII85Encode/filter <file> */
-private int
+static int
 zA85E(i_ctx_t *i_ctx_p)
 {
     return filter_write_simple(i_ctx_p, &s_A85E_template);
@@ -52,7 +52,7 @@ zA85E(i_ctx_t *i_ctx_p)
 
 /* <source> ASCII85Decode/filter <file> */
 /* <source> <dict> ASCII85Decode/filter <file> */
-private int
+static int
 zA85D(i_ctx_t *i_ctx_p)
 {
     return filter_read_simple(i_ctx_p, &s_A85D_template);
@@ -78,7 +78,7 @@ zcf_setup(os_ptr op, stream_CF_state *pcfs, gs_ref_memory_t *imem)
 
 /* <source> <dict> CCITTFaxDecode/filter <file> */
 /* <source> CCITTFaxDecode/filter <file> */
-private int
+static int
 zCFD(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -205,7 +205,7 @@ zlz_setup(os_ptr op, stream_LZW_state * plzs)
 
 /* <source> LZWDecode/filter <file> */
 /* <source> <dict> LZWDecode/filter <file> */
-private int
+static int
 zLZWD(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -257,7 +257,7 @@ zpd_setup(os_ptr op, stream_PDiff_state * ppds)
 }
 
 /* <target> <dict> PixelDifferenceEncode/filter <file> */
-private int
+static int
 zPDiffE(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -270,7 +270,7 @@ zPDiffE(i_ctx_t *i_ctx_p)
 }
 
 /* <source> <dict> PixelDifferenceDecode/filter <file> */
-private int
+static int
 zPDiffD(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -292,7 +292,7 @@ zpp_setup(os_ptr op, stream_PNGP_state * ppps)
 
     check_type(*op, t_dictionary);
     check_dict_read(*op);
-    if ((code = dict_int_param(op, "Colors", 1, 16, 1,
+    if ((code = dict_int_param(op, "Colors", 1, s_PNG_max_Colors, 1,
 			       &ppps->Colors)) < 0 ||
 	(code = dict_int_param(op, "BitsPerComponent", 1, 16, 8,
 			       &bpc)) < 0 ||
@@ -308,7 +308,7 @@ zpp_setup(os_ptr op, stream_PNGP_state * ppps)
 }
 
 /* <target> <dict> PNGPredictorEncode/filter <file> */
-private int
+static int
 zPNGPE(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -321,7 +321,7 @@ zPNGPE(i_ctx_t *i_ctx_p)
 }
 
 /* <source> <dict> PNGPredictorDecode/filter <file> */
-private int
+static int
 zPNGPD(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
