@@ -1,22 +1,17 @@
-/* Copyright (C) 1989, 2000, 2001 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zfileio.c,v 1.12.2.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zfileio.c 8250 2007-09-25 13:31:24Z giles $ */
 /* File I/O operators */
 #include "memory_.h"
 #include "ghost.h"
@@ -34,11 +29,11 @@
 #include "estack.h"
 
 /* Forward references */
-private int write_string(P2(ref *, stream *));
-private int handle_read_status(P5(i_ctx_t *, int, const ref *, const uint *,
-				  op_proc_t));
-private int handle_write_status(P5(i_ctx_t *, int, const ref *, const uint *,
-				   op_proc_t));
+static int write_string(ref *, stream *);
+static int handle_read_status(i_ctx_t *, int, const ref *, const uint *,
+			       op_proc_t);
+static int handle_write_status(i_ctx_t *, int, const ref *, const uint *,
+				op_proc_t);
 
 /* ------ Operators ------ */
 
@@ -68,7 +63,7 @@ zclosefile(i_ctx_t *i_ctx_p)
 
 /* <file> read <int> -true- */
 /* <file> read -false- */
-private int
+static int
 zread(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -76,15 +71,27 @@ zread(i_ctx_t *i_ctx_p)
     int ch;
 
     check_read_file(s, op);
+    /* We 'push' first in case of ostack block overflow and the */
+    /* usual case is we will need to push anyway. If we get EOF */
+    /* we will need to 'pop' and decrement the 'op' pointer.    */
+    /* This is required since the 'push' macro might return with*/
+    /* stackoverflow which will result in another stack block   */
+    /* added on, then the operator being retried. We can't read */
+    /* (sgetc) prior to having a place on the ostack to return  */
+    /* the character.						*/
+    push(1);
     ch = sgetc(s);
     if (ch >= 0) {
-	push(1);
 	make_int(op - 1, ch);
 	make_bool(op, 1);
-    } else if (ch == EOFC)
+    } else {
+	pop(1);		/* Adjust ostack back from preparatory 'pop' */
+	op--;
+	if (ch == EOFC) 
 	make_bool(op, 0);
     else
 	return handle_read_status(i_ctx_p, ch, op, NULL, zread);
+    }
     return 0;
 }
 
@@ -109,19 +116,17 @@ zwrite(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <string> readhexstring <substring> <filled_bool> */
-private int zreadhexstring_continue(P1(i_ctx_t *));
+static int zreadhexstring_continue(i_ctx_t *);
 
-/* We keep track of the odd digit in the next byte of the string */
-/* beyond the bytes already used.  (This is just for convenience; */
-/* we could do the same thing by passing 2 state parameters to the */
-/* continuation procedure instead of 1.) */
-private int
-zreadhexstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint start)
+/* We pack the odd digit above the the current position for the  */
+/* convenience of reusing procedures that take 1 state parameter */
+static int
+zreadhexstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint start, int odd)
 {
     stream *s;
     uint len, nread;
     byte *str;
-    int odd;
+    int odd_byte = odd;
     stream_cursor_write cw;
     int status;
 
@@ -129,16 +134,10 @@ zreadhexstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint start)
     /*check_write_type(*op, t_string); *//* done by caller */
     str = op->value.bytes;
     len = r_size(op);
-    if (start < len) {
-	odd = str[start];
-	if (odd > 0xf)
-	    odd = -1;
-    } else
-	odd = -1;
     cw.ptr = str + start - 1;
     cw.limit = str + len - 1;
     for (;;) {
-	status = s_hex_process(&s->cursor.r, &cw, &odd,
+	status = s_hex_process(&s->cursor.r, &cw, &odd_byte,
 			       hex_ignore_garbage);
 	if (status == 1) {	/* filled the string */
 	    ref_assign_inline(op - 1, op);
@@ -154,9 +153,8 @@ zreadhexstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint start)
     }
     nread = cw.ptr + 1 - str;
     if (status != EOFC) {	/* Error */
-	if (nread < len)
-	    str[nread] = (odd < 0 ? 0x10 : odd);
-	return handle_read_status(i_ctx_p, status, op - 1, &nread,
+	nread |= odd_byte << 24;
+        return handle_read_status(i_ctx_p, status, op - 1, &nread,
 				  zreadhexstring_continue);
     }
     /* Reached end-of-file before filling the string. */
@@ -166,37 +164,38 @@ zreadhexstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint start)
     make_false(op);
     return 0;
 }
-private int
+static int
 zreadhexstring(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
 
     check_write_type(*op, t_string);
-    if (r_size(op) > 0)
-	*op->value.bytes = 0x10;
-    return zreadhexstring_at(i_ctx_p, op, 0);
+    return zreadhexstring_at(i_ctx_p, op, 0, -1);
 }
 /* Continue a readhexstring operation after a callout. */
-/* *op is the index within the string. */
-private int
+/* *op contains the index within the string and the odd flag. */
+static int
 zreadhexstring_continue(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
-    int code;
+    int code, length, odd;
 
     check_type(*op, t_integer);
-    if (op->value.intval < 0 || op->value.intval > r_size(op - 1))
+    length = op->value.intval & 0xFFFFFF;
+    odd = op->value.intval >> 24;
+    
+    if (length > r_size(op - 1) || odd < -1 || odd > 0xF)
 	return_error(e_rangecheck);
     check_write_type(op[-1], t_string);
-    code = zreadhexstring_at(i_ctx_p, op - 1, (uint) op->value.intval);
+    code = zreadhexstring_at(i_ctx_p, op - 1, (uint)length, odd);
     if (code >= 0)
 	pop(1);
     return code;
 }
 
 /* <file> <string> writehexstring - */
-private int zwritehexstring_continue(P1(i_ctx_t *));
-private int
+static int zwritehexstring_continue(i_ctx_t *);
+static int
 zwritehexstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint odd)
 {
     register stream *s;
@@ -249,7 +248,7 @@ zwritehexstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint odd)
     return 0;
 #undef MAX_HEX
 }
-private int
+static int
 zwritehexstring(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -258,7 +257,7 @@ zwritehexstring(i_ctx_t *i_ctx_p)
 }
 /* Continue a writehexstring operation after a callout. */
 /* *op is the odd/even hex digit flag for the first byte. */
-private int
+static int
 zwritehexstring_continue(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -274,16 +273,16 @@ zwritehexstring_continue(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <string> readstring <substring> <filled_bool> */
-private int zreadstring_continue(P1(i_ctx_t *));
-private int
+static int zreadstring_continue(i_ctx_t *);
+static int
 zreadstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint start)
 {
     stream *s;
     uint len, rlen;
     int status;
 
-    check_read_file(s, op - 1);
     check_write_type(*op, t_string);
+    check_read_file(s, op - 1);
     len = r_size(op);
     status = sgets(s, op->value.bytes + start, len - start, &rlen);
     rlen += start;
@@ -309,7 +308,7 @@ zreadstring_at(i_ctx_t *i_ctx_p, os_ptr op, uint start)
     make_bool(op, (rlen == len ? 1 : 0));
     return 0;
 }
-private int
+static int
 zreadstring(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -318,7 +317,7 @@ zreadstring(i_ctx_t *i_ctx_p)
 }
 /* Continue a readstring operation after a callout. */
 /* *op is the index within the string. */
-private int
+static int
 zreadstring_continue(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -334,7 +333,7 @@ zreadstring_continue(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <string> writestring - */
-private int
+static int
 zwritestring(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -352,8 +351,8 @@ zwritestring(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <string> readline <substring> <bool> */
-private int zreadline(P1(i_ctx_t *));
-private int zreadline_continue(P1(i_ctx_t *));
+static int zreadline(i_ctx_t *);
+static int zreadline_continue(i_ctx_t *);
 
 /*
  * We could handle readline the same way as readstring,
@@ -365,15 +364,15 @@ private int zreadline_continue(P1(i_ctx_t *));
  * we use start=0 (which we have just ruled out as a possible start value
  * for readline_continue) to indicate interruption after the CR.
  */
-private int
+static int
 zreadline_at(i_ctx_t *i_ctx_p, os_ptr op, uint count, bool in_eol)
 {
     stream *s;
     int status;
     gs_string str;
 
-    check_read_file(s, op - 1);
     check_write_type(*op, t_string);
+    check_read_file(s, op - 1);
     str.data = op->value.bytes;
     str.size = r_size(op);
     status = zreadline_from(s, &str, NULL, &count, &in_eol);
@@ -401,7 +400,7 @@ zreadline_at(i_ctx_t *i_ctx_p, os_ptr op, uint count, bool in_eol)
     make_bool(op, status == 0);
     return 0;
 }
-private int
+static int
 zreadline(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -410,7 +409,7 @@ zreadline(i_ctx_t *i_ctx_p)
 }
 /* Continue a readline operation after a callout. */
 /* *op is the index within the string, or 0 for an interrupt after a CR. */
-private int
+static int
 zreadline_continue(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -447,7 +446,7 @@ zreadline_from(stream *s, gs_string *buf, gs_memory_t *bufmem,
 }
 
 /* <file> bytesavailable <int> */
-private int
+static int
 zbytesavailable(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -491,7 +490,7 @@ zflush(i_ctx_t *i_ctx_p)
 }
 
 /* <file> flushfile - */
-private int
+static int
 zflushfile(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -521,7 +520,7 @@ zflushfile(i_ctx_t *i_ctx_p)
 }
 
 /* <file> resetfile - */
-private int
+static int
 zresetfile(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -536,7 +535,7 @@ zresetfile(i_ctx_t *i_ctx_p)
 }
 
 /* <string> print - */
-private int
+static int
 zprint(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -567,7 +566,7 @@ zprint(i_ctx_t *i_ctx_p)
 }
 
 /* <bool> echo - */
-private int
+static int
 zecho(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -581,7 +580,7 @@ zecho(i_ctx_t *i_ctx_p)
 /* ------ Level 2 extensions ------ */
 
 /* <file> fileposition <int> */
-private int
+static int
 zfileposition(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -598,7 +597,7 @@ zfileposition(i_ctx_t *i_ctx_p)
     return 0;
 }
 /* <file> .fileposition <int> */
-private int
+static int
 zxfileposition(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -614,14 +613,14 @@ zxfileposition(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <int> setfileposition - */
-private int
+static int
 zsetfileposition(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
     stream *s;
 
-    check_file(s, op - 1);
     check_type(*op, t_integer);
+    check_file(s, op - 1);
     if (sseek(s, op->value.intval) < 0)
 	return_error(e_ioerror);
     pop(2);
@@ -632,7 +631,7 @@ zsetfileposition(i_ctx_t *i_ctx_p)
 
 /* <file> .filename <string> true */
 /* <file> .filename false */
-private int
+static int
 zfilename(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -660,7 +659,7 @@ zfilename(i_ctx_t *i_ctx_p)
 }
 
 /* <file> .isprocfilter <bool> */
-private int
+static int
 zisprocfilter(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -674,7 +673,7 @@ zisprocfilter(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <string> .peekstring <substring> <filled_bool> */
-private int
+static int
 zpeekstring(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -687,17 +686,17 @@ zpeekstring(i_ctx_t *i_ctx_p)
     while ((rlen = sbufavailable(s)) < len) {
 	int status = s->end_status;
 
-	/*
-	 * The following is a HACK.  It should reallocate the buffer to hold
-	 * at least len bytes.  However, this raises messy problems about
-	 * which allocator to use and how it should interact with restore.
-	 */
-	if (len >= s->bsize)
-	    return_error(e_rangecheck);
 	switch (status) {
 	case EOFC:
 	    break;
 	case 0:
+	    /*
+	     * The following is a HACK.  It should reallocate the buffer to hold
+	     * at least len bytes.  However, this raises messy problems about
+	     * which allocator to use and how it should interact with restore.
+	     */
+	    if (len >= s->bsize)
+		return_error(e_rangecheck);
 	    s_process_read_buf(s);
 	    continue;
 	default:
@@ -717,7 +716,7 @@ zpeekstring(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <int> .unread - */
-private int
+static int
 zunread(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -736,8 +735,8 @@ zunread(i_ctx_t *i_ctx_p)
 }
 
 /* <file> <obj> <==flag> .writecvp - */
-private int zwritecvp_continue(P1(i_ctx_t *));
-private int
+static int zwritecvp_continue(i_ctx_t *);
+static int
 zwritecvp_at(i_ctx_t *i_ctx_p, os_ptr op, uint start, bool first)
 {
     stream *s;
@@ -750,9 +749,9 @@ zwritecvp_at(i_ctx_t *i_ctx_p, os_ptr op, uint start, bool first)
     check_write_file(s, op - 2);
     check_type(*op, t_integer);
     code = obj_cvp(op - 1, str, sizeof(str), &len, (int)op->value.intval,
-		   start, imemory);
+		   start, imemory, true);
     if (code == e_rangecheck) {
-	code = obj_string_data(op - 1, &data, &len);
+        code = obj_string_data(imemory, op - 1, &data, &len);
 	if (len < start)
 	    return_error(e_rangecheck);
 	data += start;
@@ -791,14 +790,14 @@ zwritecvp_at(i_ctx_t *i_ctx_p, os_ptr op, uint start, bool first)
 	pop(4);
     return 0;
 }
-private int
+static int
 zwritecvp(i_ctx_t *i_ctx_p)
 {
     return zwritecvp_at(i_ctx_p, osp, 0, true);
 }
 /* Continue a .writecvp after a callout. */
 /* *op is the index within the string. */
-private int
+static int
 zwritecvp_continue(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -809,31 +808,6 @@ zwritecvp_continue(i_ctx_t *i_ctx_p)
     return zwritecvp_at(i_ctx_p, op - 1, (uint) op->value.intval, false);
 }
 
-/* Callout for stdin */
-/* - .needstdin - */
-int
-zneedstdin(i_ctx_t *i_ctx_p)
-{
-    return e_NeedStdin;		/* Interpreter will exit to caller. */
-}
-
-/* Callout for stdout */
-/* - .needstdout - */
-int
-zneedstdout(i_ctx_t *i_ctx_p)
-{
-    return e_NeedStdout;	/* Interpreter will exit to caller. */
-}
-
-/* Callout for stderr */
-/* - .needstderr - */
-int
-zneedstderr(i_ctx_t *i_ctx_p)
-{
-    return e_NeedStderr;	/* Interpreter will exit to caller. */
-}
-
-
 
 /* ------ Initialization procedure ------ */
 
@@ -871,9 +845,6 @@ const op_def zfileio2_op_defs[] = {
     {"3%zreadstring_continue", zreadstring_continue},
     {"4%zwritecvp_continue", zwritecvp_continue},
     {"3%zwritehexstring_continue", zwritehexstring_continue},
-    {"0.needstdin", zneedstdin},
-    {"0.needstdout", zneedstdout},
-    {"0.needstderr", zneedstderr},
     op_def_end(0)
 };
 
@@ -915,7 +886,7 @@ file_switch_to_write(const ref * op)
 
 /* Write a string on a file.  The file and string have been validated. */
 /* If the status is INTC or CALLC, updates the string on the o-stack. */
-private int
+static int
 write_string(ref * op, stream * s)
 {
     const byte *data = op->value.const_bytes;
@@ -938,7 +909,7 @@ write_string(ref * op, stream * s)
  * Look for a stream error message that needs to be copied to
  * $error.errorinfo, if any.
  */
-private int
+static int
 copy_error_string(i_ctx_t *i_ctx_p, const ref *fop)
 {
     stream *s;
@@ -959,7 +930,7 @@ copy_error_string(i_ctx_t *i_ctx_p, const ref *fop)
 /* fop points to the ref for the stream. */
 /* ch may be any stream exceptional value. */
 /* Return 0, 1 (EOF), o_push_estack, or an error. */
-private int
+static int
 handle_read_status(i_ctx_t *i_ctx_p, int ch, const ref * fop,
 		   const uint * pindex, op_proc_t cont)
 {
@@ -986,7 +957,7 @@ handle_read_status(i_ctx_t *i_ctx_p, int ch, const ref * fop,
 /* fop points to the ref for the stream. */
 /* ch may be any stream exceptional value. */
 /* Return 0, 1 (EOF), o_push_estack, or an error. */
-private int
+static int
 handle_write_status(i_ctx_t *i_ctx_p, int ch, const ref * fop,
 		    const uint * pindex, op_proc_t cont)
 {
