@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: zfont0.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: zfont0.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Composite font creation operator */
 #include "ghost.h"
 #include "oper.h"
@@ -43,13 +43,13 @@ int ztype0_get_cmap(const gs_cmap_t ** ppcmap, const ref * pfdepvector,
 		    const ref * op, gs_memory_t *imem);
 
 /* Forward references */
-private font_proc_define_font(ztype0_define_font);
-private font_proc_make_font(ztype0_make_font);
-private int ensure_char_entry(i_ctx_t *, os_ptr, const char *, byte *, int);
+static font_proc_define_font(ztype0_define_font);
+static font_proc_make_font(ztype0_make_font);
+static int ensure_char_entry(i_ctx_t *, os_ptr, const char *, byte *, int);
 
 /* <string|name> <font_dict> .buildfont0 <string|name> <font> */
 /* Build a type 0 (composite) font. */
-private int
+static int
 zbuildfont0(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -266,7 +266,7 @@ fail:
 /* any composite sub-fonts, adjust the parent font's FDepVector. */
 /* This is called only if gs_type0_define/make_font */
 /* actually changed the FDepVector. */
-private int
+static int
 ztype0_adjust_FDepVector(gs_font_type0 * pfont)
 {
     gs_memory_t *mem = pfont->memory;
@@ -294,7 +294,7 @@ ztype0_adjust_FDepVector(gs_font_type0 * pfont)
      */
     return dict_put_string(pfont_dict(pfont), "FDepVector", &newdep, NULL);
 }
-private int
+static int
 ztype0_define_font(gs_font_dir * pdir, gs_font * pfont)
 {
     gs_font_type0 *const pfont0 = (gs_font_type0 *)pfont;
@@ -305,7 +305,7 @@ ztype0_define_font(gs_font_dir * pdir, gs_font * pfont)
 	return code;
     return ztype0_adjust_FDepVector(pfont0);
 }
-private int
+static int
 ztype0_make_font(gs_font_dir * pdir, const gs_font * pfont,
 		 const gs_matrix * pmat, gs_font ** ppfont)
 {
@@ -327,7 +327,7 @@ ztype0_make_font(gs_font_dir * pdir, const gs_font * pfont,
 /* ------ Internal routines ------ */
 
 /* Find or add a character entry in a font dictionary. */
-private int
+static int
 ensure_char_entry(i_ctx_t *i_ctx_p, os_ptr op, const char *kstr,
 		  byte * pvalue, int default_value)
 {
