@@ -1,25 +1,21 @@
-/* Copyright (C) 1998, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zfrsd.c,v 1.4.6.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zfrsd.c 8250 2007-09-25 13:31:24Z giles $ */
 /* ReusableStreamDecode filter support */
 #include "memory_.h"
 #include "ghost.h"
+#include "gsfname.h"		/* for gs_parse_file_name */
 #include "gxiodev.h"
 #include "oper.h"
 #include "stream.h"
@@ -41,13 +37,13 @@
 /* <dict|null> .rsdparams <filters> <decodeparms|null> */
 /* filters is always an array; decodeparms is always either an array */
 /* of the same length as filters, or null. */
-private int
+static int
 zrsdparams(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
     ref *pFilter;
     ref *pDecodeParms;
-    int Intent;
+    int Intent = 0;
     bool AsyncRead;
     ref empty_array, filter1_array, parms1_array;
     uint i;
@@ -79,22 +75,24 @@ zrsdparams(i_ctx_t *i_ctx_p)
     for (i = 0; i < r_size(pFilter); ++i) {
 	ref f, fname, dp;
 
-	array_get(pFilter, (long)i, &f);
+	array_get(imemory, pFilter, (long)i, &f);
 	if (!r_has_type(&f, t_name))
 	    return_error(e_typecheck);
-	name_string_ref(&f, &fname);
+	name_string_ref(imemory, &f, &fname);
 	if (r_size(&fname) < 6 ||
 	    memcmp(fname.value.bytes + r_size(&fname) - 6, "Decode", 6)
 	    )
 	    return_error(e_rangecheck);
 	if (pDecodeParms) {
-	    array_get(pDecodeParms, (long)i, &dp);
+	    array_get(imemory, pDecodeParms, (long)i, &dp);
 	    if (!(r_has_type(&dp, t_dictionary) || r_has_type(&dp, t_null)))
 		return_error(e_typecheck);
 	}
     }
-    if ((code = dict_int_param(op, "Intent", 0, 3, 0, &Intent)) < 0 ||
-	(code = dict_bool_param(op, "AsyncRead", false, &AsyncRead)) < 0
+    code = dict_int_param(op, "Intent", 0, 3, 0, &Intent);
+    if (code < 0 && code != e_rangecheck) /* out-of-range int is ok, use 0 */
+	return code;
+    if ((code = dict_bool_param(op, "AsyncRead", false, &AsyncRead)) < 0
 	)
 	return code;
     push(1);
@@ -117,12 +115,12 @@ zrsdparams(i_ctx_t *i_ctx_p)
  * Reusable streams are also reusable sources, but they look just like
  * ordinary file or string streams.
  */
-private int make_rss(P8(i_ctx_t *i_ctx_p, os_ptr op, const byte * data,
-			uint size, int space, long offset, long length,
-			bool is_bytestring));
-private int make_rfs(P5(i_ctx_t *i_ctx_p, os_ptr op, stream *fs,
-			long offset, long length));
-private int
+static int make_rss(i_ctx_t *i_ctx_p, os_ptr op, const byte * data,
+		     uint size, uint space, long offset, long length,
+		     bool is_bytestring);
+static int make_rfs(i_ctx_t *i_ctx_p, os_ptr op, stream *fs,
+		     long offset, long length);
+static int
 zreusablestream(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -201,16 +199,17 @@ rs:
 }
 
 /* Make a reusable string stream. */
-private int
+static int
 make_rss(i_ctx_t *i_ctx_p, os_ptr op, const byte * data, uint size,
-	 int string_space, long offset, long length, bool is_bytestring)
+	 uint string_space, long offset, long length, bool is_bytestring)
 {
+    uint save_space = icurrent_space;
     stream *s;
     long left = min(length, size - offset);
 
-    if (icurrent_space < string_space)
-	return_error(e_invalidaccess);
+    ialloc_set_space(idmemory, string_space);
     s = file_alloc_stream(imemory, "make_rss");
+    ialloc_set_space(idmemory, save_space);
     if (s == 0)
 	return_error(e_VMerror);
     sread_string_reusable(s, data + offset, max(left, 0));
@@ -221,21 +220,31 @@ make_rss(i_ctx_t *i_ctx_p, os_ptr op, const byte * data, uint size,
 }
 
 /* Make a reusable file stream. */
-private int
+static int
 make_rfs(i_ctx_t *i_ctx_p, os_ptr op, stream *fs, long offset, long length)
 {
+    uint save_space = icurrent_space;
+    uint stream_space = imemory_space((const gs_ref_memory_t *)fs->memory);
     gs_const_string fname;
+    gs_parsed_file_name_t pname;
     stream *s;
     int code;
 
     if (sfilename(fs, &fname) < 0)
 	return_error(e_ioerror);
-    if (fname.data[0] == '%')
+    code = gs_parse_file_name(&pname, (const char *)fname.data, fname.size);
+    if (code < 0)
+	return code;
+    if (pname.len == 0)		/* %stdin% etc. won't have a filename */
 	return_error(e_invalidfileaccess); /* can't reopen */
+    if (pname.iodev == NULL)
+	pname.iodev = iodev_default;
     /* Open the file again, to be independent of the source. */
-    code = file_open_stream((const char *)fname.data, fname.size, "r",
-			    fs->cbsize, &s, iodev_default->procs.fopen,
-			    imemory);
+    ialloc_set_space(idmemory, stream_space);
+    code = file_open_stream((const char *)pname.fname, pname.len, "r",
+			    fs->cbsize, &s, pname.iodev,
+			    pname.iodev->procs.fopen, imemory);
+    ialloc_set_space(idmemory, save_space);
     if (code < 0)
 	return code;
     if (sread_subfile(s, offset, length) < 0) {
