@@ -1,22 +1,17 @@
-/* Copyright (C) 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zfunc3.c,v 1.2.6.2.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zfunc3.c 8022 2007-06-05 22:23:38Z giles $ */
 /* PostScript language interface to LL3 Functions */
 #include "memory_.h"
 #include "ghost.h"
@@ -47,8 +42,8 @@ gs_build_function_2(i_ctx_t *i_ctx_p, const ref *op, const gs_function_params_t
     params.C0 = 0;
     params.C1 = 0;
     if ((code = dict_float_param(op, "N", 0.0, &params.N)) != 0 ||
-	(code = n0 = fn_build_float_array(op, "C0", false, false, &params.C0, mem)) < 0 ||
-	(code = n1 = fn_build_float_array(op, "C1", false, false, &params.C1, mem)) < 0
+	(code = n0 = fn_build_float_array_forced(op, "C0", false, &params.C0, mem)) < 0 ||
+	(code = n1 = fn_build_float_array_forced(op, "C1", false, &params.C1, mem)) < 0
 	)
 	goto fail;
     if (params.C0 == 0)
@@ -74,6 +69,7 @@ gs_build_function_3(i_ctx_t *i_ctx_p, const ref *op, const gs_function_params_t
 {
     gs_function_1ItSg_params_t params;
     int code;
+    extern bool CPSI_mode;
 
     *(gs_function_params_t *) & params = *mnDR;
     params.Functions = 0;
@@ -95,15 +91,42 @@ gs_build_function_3(i_ctx_t *i_ctx_p, const ref *op, const gs_function_params_t
 	for (i = 0; i < params.k; ++i) {
 	    ref subfn;
 
-	    array_get(pFunctions, (long)i, &subfn);
-	    code = fn_build_sub_function(i_ctx_p, &subfn, &ptr[i], depth, mem);
+	    array_get(mem, pFunctions, (long)i, &subfn);
+	    code = fn_build_sub_function(i_ctx_p, &subfn, &ptr[i], depth, mem, 0, 0);
 	    if (code < 0)
 		goto fail;
 	}
     }
-    if ((code = fn_build_float_array(op, "Bounds", true, false, &params.Bounds, mem)) != params.k - 1 ||
-	(code = fn_build_float_array(op, "Encode", true, true, &params.Encode, mem)) != 2 * params.k
-	)
+    if ((code = fn_build_float_array(op, "Bounds", true, false, &params.Bounds, mem)) != params.k - 1)
+	goto fail;
+    if (CPSI_mode) {
+	/* Adobe implementation doesn't check the Encode length. */
+	/* Extra elements are ignored; missing elements are filled with 0. */
+	/* CET 12-14m.ps depends on this bug */
+	uint sz, k2 = 2 * params.k;
+	ref *encode;
+	float *p = (float *)gs_alloc_byte_array(mem, k2, sizeof(float), "Encode");
+
+	params.Encode = p;
+	if (p == 0) {
+	    code = gs_note_error(e_VMerror);
+	    goto fail;
+	}
+	if (dict_find_string(op, "Encode", &encode) <= 0) {
+	    code = gs_note_error(e_undefined);
+	    goto fail;
+	}
+	if (!r_is_array(encode)) {
+	    code = gs_note_error(e_typecheck);
+	    goto fail;
+	}
+	sz =  min(k2, r_size(encode));
+	code = process_float_array(mem, encode, sz, p);
+	if (code < 0)
+	    goto fail;
+	while (sz < k2)
+	    p[sz++] = 0.0;
+    } else if ((code = fn_build_float_array(op, "Encode", true, true, &params.Encode, mem)) != 2 * params.k)
 	goto fail;
     if (params.Range == 0)
 	params.n = params.Functions[0]->params.n;
