@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2006 artofcode LLC.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
   
    This software is provided AS-IS with no warranty, either express or
@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: zfzlib.c 6651 2006-03-13 16:18:19Z stefan $ */
+/* $Id: zfzlib.c 8250 2007-09-25 13:31:24Z giles $ */
 /* zlib and Flate filter creation */
 #include "ghost.h"
 #include "oper.h"
@@ -26,7 +26,7 @@
 #include "ifwpred.h"
 
 /* Common setup for zlib (Flate) filter */
-private int
+static int
 filter_zlib(i_ctx_t *i_ctx_p, stream_zlib_state *pzls)
 {
     os_ptr op = osp;
@@ -40,7 +40,7 @@ filter_zlib(i_ctx_t *i_ctx_p, stream_zlib_state *pzls)
 
 /* <source> zlibEncode/filter <file> */
 /* <source> <dict> zlibEncode/filter <file> */
-private int
+static int
 zzlibE(i_ctx_t *i_ctx_p)
 {
     stream_zlib_state zls;
@@ -53,7 +53,7 @@ zzlibE(i_ctx_t *i_ctx_p)
 
 /* <target> zlibDecode/filter <file> */
 /* <target> <dict> zlibDecode/filter <file> */
-private int
+static int
 zzlibD(i_ctx_t *i_ctx_p)
 {
     stream_zlib_state zls;
@@ -64,7 +64,7 @@ zzlibD(i_ctx_t *i_ctx_p)
 
 /* <source> FlateEncode/filter <file> */
 /* <source> <dict> FlateEncode/filter <file> */
-private int
+static int
 zFlateE(i_ctx_t *i_ctx_p)
 {
     stream_zlib_state zls;
@@ -78,7 +78,7 @@ zFlateE(i_ctx_t *i_ctx_p)
 
 /* <target> FlateDecode/filter <file> */
 /* <target> <dict> FlateDecode/filter <file> */
-private int
+static int
 zFlateD(i_ctx_t *i_ctx_p)
 {
     stream_zlib_state zls;
