@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: zhsb.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: zhsb.c 8250 2007-09-25 13:31:24Z giles $ */
 /* HSB color operators */
 #include "ghost.h"
 #include "oper.h"
@@ -20,7 +20,7 @@
 #include "gshsb.h"
 
 /* - currenthsbcolor <hue> <saturation> <brightness> */
-private int
+static int
 zcurrenthsbcolor(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -33,7 +33,7 @@ zcurrenthsbcolor(i_ctx_t *i_ctx_p)
 }
 
 /* <hue> <saturation> <brightness> sethsbcolor - */
-private int
+static int
 zsethsbcolor(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
