@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: zimage.c 8094 2007-07-01 17:18:18Z alexcher $ */
+/* $Id: zimage.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Image operators */
 #include "math_.h"
 #include "memory_.h"
@@ -39,13 +39,13 @@
 #include "gxcspace.h"
 
 /* Forward references */
-private int zimage_data_setup(i_ctx_t *i_ctx_p, const gs_pixel_image_t * pim,
+static int zimage_data_setup(i_ctx_t *i_ctx_p, const gs_pixel_image_t * pim,
 				 gx_image_enum_common_t * pie,
 				 const ref * sources, int npop);
-private int image_proc_process(i_ctx_t *);
-private int image_file_continue(i_ctx_t *);
-private int image_string_continue(i_ctx_t *);
-private int image_cleanup(i_ctx_t *);
+static int image_proc_process(i_ctx_t *);
+static int image_file_continue(i_ctx_t *);
+static int image_string_continue(i_ctx_t *);
+static int image_cleanup(i_ctx_t *);
 
 
 
@@ -197,14 +197,14 @@ image1_setup(i_ctx_t * i_ctx_p, bool has_alpha)
 }
 
 /* <dict> .image1 - */
-private int
+static int
 zimage1(i_ctx_t *i_ctx_p)
 {
     return image1_setup(i_ctx_p, false);
 }
 
 /* <dict> .imagemask1 - */
-private int
+static int
 zimagemask1(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -254,7 +254,7 @@ zimagemask1(i_ctx_t *i_ctx_p)
   ((ep) - 4 - (i) * 2)
 #define ETOP_PLANE_INDEX(ep) ((ep) - 2)
 #define ETOP_NUM_SOURCES(ep) ((ep) - 1)
-private int
+static int
 zimage_data_setup(i_ctx_t *i_ctx_p, const gs_pixel_image_t * pim,
 		  gx_image_enum_common_t * pie, const ref * sources, int npop)
 {
@@ -360,7 +360,7 @@ zimage_data_setup(i_ctx_t *i_ctx_p, const gs_pixel_image_t * pim,
     return o_push_estack;
 }
 /* Pop all the control information off the e-stack. */
-private es_ptr
+static es_ptr
 zimage_pop_estack(es_ptr tep)
 {
     return tep - NUM_PUSH(ETOP_NUM_SOURCES(tep)->value.intval);
@@ -371,7 +371,7 @@ zimage_pop_estack(es_ptr tep)
  * to remember whether we've just called the procedure (1) or whether we're
  * returning from a RemapColor callout (0).
  */
-private int
+static int
 image_proc_continue(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -421,7 +421,7 @@ image_proc_continue(i_ctx_t *i_ctx_p)
     ETOP_PLANE_INDEX(esp)->value.intval = px;
     return image_proc_process(i_ctx_p);
 }
-private int
+static int
 image_proc_process(i_ctx_t *i_ctx_p)
 {
     int px = ETOP_PLANE_INDEX(esp)->value.intval;
@@ -443,7 +443,7 @@ image_proc_process(i_ctx_t *i_ctx_p)
 }
 
 /* Continue processing data from an image with file data sources. */
-private int
+static int
 image_file_continue(i_ctx_t *i_ctx_p)
 {
     gs_image_enum *penum = r_ptr(esp, gs_image_enum);
@@ -540,7 +540,7 @@ image_file_continue(i_ctx_t *i_ctx_p)
 
 /* Process data from an image with string data sources. */
 /* This may still encounter a RemapColor callback. */
-private int
+static int
 image_string_continue(i_ctx_t *i_ctx_p)
 {
     gs_image_enum *penum = r_ptr(esp, gs_image_enum);
@@ -578,7 +578,7 @@ image_string_continue(i_ctx_t *i_ctx_p)
 }
 
 /* Clean up after enumerating an image */
-private int
+static int
 image_cleanup(i_ctx_t *i_ctx_p)
 {
     es_ptr ep_top = esp + NUM_PUSH(EBOT_NUM_SOURCES(esp)->value.intval);
