@@ -1,22 +1,17 @@
-/* Copyright (C) 1992, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zmisc2.c,v 1.3.6.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zmisc2.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Miscellaneous Level 2 operators */
 #include "memory_.h"
 #include "string_.h"
@@ -34,12 +29,12 @@
 #include "store.h"
 
 /* Forward references */
-private int set_language_level(P2(i_ctx_t *, int));
+static int set_language_level(i_ctx_t *, int);
 
 /* ------ Language level operators ------ */
 
 /* - .languagelevel <int> */
-private int
+static int
 zlanguagelevel(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -50,7 +45,7 @@ zlanguagelevel(i_ctx_t *i_ctx_p)
 }
 
 /* <int> .setlanguagelevel - */
-private int
+static int
 zsetlanguagelevel(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -84,10 +79,10 @@ const op_def zmisc2_op_defs[] =
  * This is used for the .setlanguagelevel operator,
  * and (perhaps someday) after a restore.
  */
-private int swap_level_dict(P2(i_ctx_t *i_ctx_p, const char *dict_name));
-private int swap_entry(P4(i_ctx_t *i_ctx_p, ref elt[2], ref * pdict,
-			  ref * pdict2));
-private int
+static int swap_level_dict(i_ctx_t *i_ctx_p, const char *dict_name);
+static int swap_entry(i_ctx_t *i_ctx_p, ref elt[2], ref * pdict,
+		       ref * pdict2);
+static int
 set_language_level(i_ctx_t *i_ctx_p, int new_level)
 {
     int old_level = LANGUAGE_LEVEL;
@@ -127,7 +122,7 @@ set_language_level(i_ctx_t *i_ctx_p, int new_level)
 		    *pgdict = *pdict;
 		}
 		/* Set other flags for Level 2 operation. */
-		dict_auto_expand = true;
+		imemory->gs_lib_ctx->dict_auto_expand = true;
 		}
 		code = swap_level_dict(i_ctx_p, "level2dict");
 		if (code < 0)
@@ -155,11 +150,11 @@ set_language_level(i_ctx_t *i_ctx_p, int new_level)
 
 		while ((index = dict_next(pgdict, index, &elt[0])) >= 0)
 		    if (r_has_type(&elt[0], t_name))
-			name_invalidate_value_cache(&elt[0]);
+		        name_invalidate_value_cache(imemory, &elt[0]);
 		/* Overwrite globaldict in the dictionary stack. */
 		*pgdict = *systemdict;
 		/* Set other flags for Level 1 operation. */
-		dict_auto_expand = false;
+		imemory->gs_lib_ctx->dict_auto_expand = false;
 		}
 		code = swap_level_dict(i_ctx_p, "level2dict");
 		break;
@@ -182,7 +177,7 @@ set_language_level(i_ctx_t *i_ctx_p, int new_level)
  * with the contents of the same dictionary in systemdict.  (This is a hack
  * to swap the contents of statusdict.)
  */
-private int
+static int
 swap_level_dict(i_ctx_t *i_ctx_p, const char *dict_name)
 {
     ref *pleveldict;
@@ -202,7 +197,7 @@ swap_level_dict(i_ctx_t *i_ctx_p, const char *dict_name)
     while ((index = dict_next(&rleveldict, index, &elt[0])) >= 0)
 	if (r_has_type(&elt[1], t_dictionary) &&
 	    dict_find(&elt[1], &elt[0], &psubdict) > 0 &&
-	    obj_eq(&elt[1], psubdict)
+	    obj_eq(imemory, &elt[1], psubdict)
 	    ) {
 	    /* elt[1] is the 2nd-level sub-dictionary */
 	    int isub = dict_first(&elt[1]);
@@ -214,7 +209,7 @@ swap_level_dict(i_ctx_t *i_ctx_p, const char *dict_name)
 		continue;
 	    rsubdict = *psubdict;
 	    while ((isub = dict_next(&elt[1], isub, &subelt[0])) >= 0)
-		if (!obj_eq(&subelt[0], &elt[0])) {
+	        if (!obj_eq(imemory, &subelt[0], &elt[0])) {
 		    /* don't swap dict itself */
 		    int code = swap_entry(i_ctx_p, subelt, &rsubdict, &elt[1]);
 
@@ -235,7 +230,7 @@ swap_level_dict(i_ctx_t *i_ctx_p, const char *dict_name)
  * elt[0] is the key, elt[1] is the current value in the Level 2 dictionary
  * (*pdict2).
  */
-private int
+static int
 swap_entry(i_ctx_t *i_ctx_p, ref elt[2], ref * pdict, ref * pdict2)
 {
     ref *pvalue;
