@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: zmisc3.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: zmisc3.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Miscellaneous LanguageLevel 3 operators */
 #include "ghost.h"
 #include "gscspace.h"		/* for gscolor2.h */
@@ -23,14 +23,14 @@
 #include "store.h"
 
 /* - clipsave - */
-private int
+static int
 zclipsave(i_ctx_t *i_ctx_p)
 {
     return gs_clipsave(igs);
 }
 
 /* - cliprestore - */
-private int
+static int
 zcliprestore(i_ctx_t *i_ctx_p)
 {
     return gs_cliprestore(igs);
@@ -47,7 +47,7 @@ zcliprestore(i_ctx_t *i_ctx_p)
 typedef struct ref2_s {
     ref proc1, proc2;
 } ref2_t;
-private int
+static int
 zeqproc(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
