@@ -1,22 +1,17 @@
-/* Copyright (C) 1994, 1995, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zsysvm.c,v 1.2.6.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zsysvm.c 8250 2007-09-25 13:31:24Z giles $ */
 /* System VM and VM-specific operators */
 #include "ghost.h"
 #include "oper.h"
@@ -33,7 +28,7 @@
  */
 
 /* Execute an operator with a specific VM selected as current VM. */
-private int
+static int
 specific_vm_op(i_ctx_t *i_ctx_p, op_proc_t opproc, uint space)
 {
     uint save_space = icurrent_space;
@@ -46,91 +41,115 @@ specific_vm_op(i_ctx_t *i_ctx_p, op_proc_t opproc, uint space)
 }
 
 /* <int> .globalvmarray <array> */
-private int
+static int
 zglobalvmarray(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zarray, avm_global);
 }
 
 /* <int> .globalvmdict <dict> */
-private int
+static int
 zglobalvmdict(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zdict, avm_global);
 }
 
 /* <obj_0> ... <obj_n-1> <n> .globalvmpackedarray <packedarray> */
-private int
+static int
 zglobalvmpackedarray(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zpackedarray, avm_global);
 }
 
 /* <int> .globalvmstring <string> */
-private int
+static int
 zglobalvmstring(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zstring, avm_global);
 }
 
 /* <int> .localvmarray <array> */
-private int
+static int
 zlocalvmarray(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zarray, avm_local);
 }
 
 /* <int> .localvmdict <dict> */
-private int
+static int
 zlocalvmdict(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zdict, avm_local);
 }
 
 /* <obj_0> ... <obj_n-1> <n> .localvmpackedarray <packedarray> */
-private int
+static int
 zlocalvmpackedarray(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zpackedarray, avm_local);
 }
 
 /* <int> .localvmstring <string> */
-private int
+static int
 zlocalvmstring(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zstring, avm_local);
 }
 
 /* <int> .systemvmarray <array> */
-private int
+static int
 zsystemvmarray(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zarray, avm_system);
 }
 
 /* <int> .systemvmdict <dict> */
-private int
+static int
 zsystemvmdict(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zdict, avm_system);
 }
 
 /* <obj_0> ... <obj_n-1> <n> .systemvmpackedarray <packedarray> */
-private int
+static int
 zsystemvmpackedarray(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zpackedarray, avm_system);
 }
 
 /* <int> .systemvmstring <string> */
-private int
+static int
 zsystemvmstring(i_ctx_t *i_ctx_p)
 {
     return specific_vm_op(i_ctx_p, zstring, avm_system);
 }
 
+/* <name_string> <access_string> .systemvmfile <file> */
+static int
+zsystemvmfile(i_ctx_t *i_ctx_p)
+{
+    return specific_vm_op(i_ctx_p, zfile, avm_system);
+}
+
+/* <string> .systemvmlibfile <file> true */
+/* <string> .systemvmlibfile <string> false */
+static int
+zsystemvmlibfile(i_ctx_t *i_ctx_p)
+{
+    return specific_vm_op(i_ctx_p, zlibfile, avm_system);
+}
+
+/* <source> <EODcount> <EODstring> .systemvmSFD <file> */
+/* <source> <dict> <EODcount> <EODstring> .systemvmSFD <file> */
+/* <source> <dict> .systemvmSFD <file> *//* (LL3 only) */
+static int
+zsystemvmSFD(i_ctx_t *i_ctx_p)
+{
+    return specific_vm_op(i_ctx_p, zSFD, avm_system);
+}
+
 /* <any> .systemvmcheck <bool> */
-private int
+static int
 zsystemvmcheck(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -156,5 +175,8 @@ const op_def zsysvm_op_defs[] =
     {"1.systemvmdict", zsystemvmdict},
     {"1.systemvmpackedarray", zsystemvmpackedarray},
     {"1.systemvmstring", zsystemvmstring},
+    {"1.systemvmfile", zsystemvmfile},
+    {"1.systemvmlibfile", zsystemvmlibfile},
+    {"2.systemvmSFD", zsystemvmSFD},
     op_def_end(0)
 };
