@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: ztrap.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: ztrap.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Operators for setting trapping parameters and zones */
 #include "ghost.h"
 #include "oper.h"
@@ -24,7 +24,7 @@
 gs_trap_params_t i_trap_params;
 
 /* <dict> .settrapparams - */
-private int
+static int
 zsettrapparams(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -44,7 +44,7 @@ zsettrapparams(i_ctx_t *i_ctx_p)
 }
 
 /* - settrapzone - */
-private int
+static int
 zsettrapzone(i_ctx_t *i_ctx_p)
 {
 /****** NYI ******/
