@@ -1,22 +1,17 @@
-/* Copyright (C) 1990, 1996, 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zupath.c,v 1.2.6.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zupath.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Operators related to user paths */
 #include "ghost.h"
 #include "oper.h"
@@ -43,23 +38,36 @@
 extern const gx_device gs_hit_device;
 extern const int gs_hit_detected;
 
+/*
+ * CPSI mode affects two algorithms in this file:
+ * - CPSI allows ucache to appear anywhere in user paths, even though the
+ *   PLRM says ucache must appear (if at all) at the beginning
+ *   (PLRM3 p, 199);
+ * - After appending an empty user path, in CPSI the current point is
+ *   defined, even though the PLRM strongly implies this is incorrect
+ *   (PLRM3 p. 712).
+ * The 'upath_compat' Boolean controls this behavior.
+ */
+
+extern bool CPSI_mode;
+
 /* Forward references */
-private int upath_append(P2(os_ptr, i_ctx_t *));
-private int upath_stroke(P2(i_ctx_t *, gs_matrix *));
+static int upath_append(os_ptr, i_ctx_t *, bool);
+static int upath_stroke(i_ctx_t *, gs_matrix *, bool);
 
 /* ---------------- Insideness testing ---------------- */
 
 /* Forward references */
-private int in_test(P2(i_ctx_t *, int (*)(P1(gs_state *))));
-private int in_path(P3(os_ptr, i_ctx_t *, gx_device *));
-private int in_path_result(P3(i_ctx_t *, int, int));
-private int in_utest(P2(i_ctx_t *, int (*)(P1(gs_state *))));
-private int in_upath(P2(i_ctx_t *, gx_device *));
-private int in_upath_result(P3(i_ctx_t *, int, int));
+static int in_test(i_ctx_t *, int (*)(gs_state *));
+static int in_path(os_ptr, i_ctx_t *, gx_device *);
+static int in_path_result(i_ctx_t *, int, int);
+static int in_utest(i_ctx_t *, int (*)(gs_state *));
+static int in_upath(i_ctx_t *, gx_device *);
+static int in_upath_result(i_ctx_t *, int, int);
 
 /* <x> <y> ineofill <bool> */
 /* <userpath> ineofill <bool> */
-private int
+static int
 zineofill(i_ctx_t *i_ctx_p)
 {
     return in_test(i_ctx_p, gs_eofill);
@@ -67,7 +75,7 @@ zineofill(i_ctx_t *i_ctx_p)
 
 /* <x> <y> infill <bool> */
 /* <userpath> infill <bool> */
-private int
+static int
 zinfill(i_ctx_t *i_ctx_p)
 {
     return in_test(i_ctx_p, gs_fill);
@@ -75,7 +83,7 @@ zinfill(i_ctx_t *i_ctx_p)
 
 /* <x> <y> instroke <bool> */
 /* <userpath> instroke <bool> */
-private int
+static int
 zinstroke(i_ctx_t *i_ctx_p)
 {
     return in_test(i_ctx_p, gs_stroke);
@@ -83,7 +91,7 @@ zinstroke(i_ctx_t *i_ctx_p)
 
 /* <x> <y> <userpath> inueofill <bool> */
 /* <userpath1> <userpath2> inueofill <bool> */
-private int
+static int
 zinueofill(i_ctx_t *i_ctx_p)
 {
     return in_utest(i_ctx_p, gs_eofill);
@@ -91,7 +99,7 @@ zinueofill(i_ctx_t *i_ctx_p)
 
 /* <x> <y> <userpath> inufill <bool> */
 /* <userpath1> <userpath2> inufill <bool> */
-private int
+static int
 zinufill(i_ctx_t *i_ctx_p)
 {
     return in_utest(i_ctx_p, gs_fill);
@@ -101,7 +109,7 @@ zinufill(i_ctx_t *i_ctx_p)
 /* <x> <y> <userpath> <matrix> inustroke <bool> */
 /* <userpath1> <userpath2> inustroke <bool> */
 /* <userpath1> <userpath2> <matrix> inustroke <bool> */
-private int
+static int
 zinustroke(i_ctx_t *i_ctx_p)
 {	/* This is different because of the optional matrix operand. */
     os_ptr op = osp;
@@ -112,7 +120,7 @@ zinustroke(i_ctx_t *i_ctx_p)
 
     if (code < 0)
 	return code;
-    if ((spop = upath_stroke(i_ctx_p, &mat)) < 0) {
+    if ((spop = upath_stroke(i_ctx_p, &mat, false)) < 0) {
 	gs_grestore(igs);
 	return spop;
     }
@@ -130,8 +138,8 @@ zinustroke(i_ctx_t *i_ctx_p)
 /* ------ Internal routines ------ */
 
 /* Do the work of the non-user-path insideness operators. */
-private int
-in_test(i_ctx_t *i_ctx_p, int (*paintproc)(P1(gs_state *)))
+static int
+in_test(i_ctx_t *i_ctx_p, int (*paintproc)(gs_state *))
 {
     os_ptr op = osp;
     gx_device hdev;
@@ -145,7 +153,7 @@ in_test(i_ctx_t *i_ctx_p, int (*paintproc)(P1(gs_state *)))
 }
 
 /* Set up a clipping path and device for insideness testing. */
-private int
+static int
 in_path(os_ptr oppath, i_ctx_t *i_ctx_p, gx_device * phdev)
 {
     int code = gs_gsave(igs);
@@ -166,6 +174,10 @@ in_path(os_ptr oppath, i_ctx_t *i_ctx_p, gx_device * phdev)
 	fr.q.y = fr.p.y + fixed_1;
 	code = gx_clip_to_rectangle(igs, &fr);
 	npop = 2;
+    } else if (code == e_stackunderflow) {
+	/* If 0 elements, definitely a stackunderflow; otherwise, */
+	/* only 1 number, also a stackunderflow. */
+	npop = code;
     } else {			/* Aperture is a user path. */
 	/* We have to set the clipping path without disturbing */
 	/* the current path. */
@@ -175,7 +187,7 @@ in_path(os_ptr oppath, i_ctx_t *i_ctx_p, gx_device * phdev)
 	gx_path_init_local(&save, imemory);
 	gx_path_assign_preserve(&save, ipath);
 	gs_newpath(igs);
-	code = upath_append(oppath, i_ctx_p);
+	code = upath_append(oppath, i_ctx_p, false);
 	if (code >= 0)
 	    code = gx_clip_to_path(igs);
 	gx_path_assign_free(igs->path, &save);
@@ -196,7 +208,7 @@ in_path(os_ptr oppath, i_ctx_t *i_ctx_p, gx_device * phdev)
 }
 
 /* Finish an insideness test. */
-private int
+static int
 in_path_result(i_ctx_t *i_ctx_p, int npop, int code)
 {
     os_ptr op = osp;
@@ -218,8 +230,8 @@ in_path_result(i_ctx_t *i_ctx_p, int npop, int code)
 }
 
 /* Do the work of the user-path insideness operators. */
-private int
-in_utest(i_ctx_t *i_ctx_p, int (*paintproc)(P1(gs_state *)))
+static int
+in_utest(i_ctx_t *i_ctx_p, int (*paintproc)(gs_state *))
 {
     gx_device hdev;
     int npop = in_upath(i_ctx_p, &hdev);
@@ -233,7 +245,7 @@ in_utest(i_ctx_t *i_ctx_p, int (*paintproc)(P1(gs_state *)))
 
 /* Set up a clipping path and device for insideness testing */
 /* with a user path. */
-private int
+static int
 in_upath(i_ctx_t *i_ctx_p, gx_device * phdev)
 {
     os_ptr op = osp;
@@ -242,8 +254,8 @@ in_upath(i_ctx_t *i_ctx_p, gx_device * phdev)
 
     if (code < 0)
 	return code;
-    if ((code = upath_append(op, i_ctx_p)) < 0 ||
-	(npop = in_path(op - 1, i_ctx_p, phdev)) < 0
+    if ((code = upath_append(op, i_ctx_p, false)) < 0 ||
+	(code = npop = in_path(op - 1, i_ctx_p, phdev)) < 0
 	) {
 	gs_grestore(igs);
 	return code;
@@ -252,7 +264,7 @@ in_upath(i_ctx_t *i_ctx_p, gx_device * phdev)
 }
 
 /* Finish an insideness test with a user path. */
-private int
+static int
 in_upath_result(i_ctx_t *i_ctx_p, int npop, int code)
 {
     gs_grestore(igs);		/* matches gsave in in_upath */
@@ -277,15 +289,41 @@ typedef enum {
     upath_op_ucache = 11
 } upath_op;
 
+/* User path interpretation states */
+typedef enum {
+    UPS_INITIAL = 1,		/* (no ops yet) */
+    UPS_UCACHE = 2,		/* ucache */
+    UPS_SETBBOX = 4,		/* [ucache] setbbox */
+    UPS_PATH = 8		/* (within path) */
+} upath_state;
+
+typedef struct up_data_s {
+    byte num_args;
+    byte states_before;
+    byte state_after;
+} up_data_t;
+#define UP_DATA_PATH(n) {n, UPS_SETBBOX | UPS_PATH, UPS_PATH}
+
 #define UPATH_MAX_OP 11
 #define UPATH_REPEAT 32
-static const byte up_nargs[UPATH_MAX_OP + 1] = {
-    4, 2, 2, 2, 2, 6, 6, 5, 5, 5, 0, 0
+static const up_data_t up_data[UPATH_MAX_OP + 1] = {
+    {4, UPS_INITIAL | UPS_UCACHE, UPS_SETBBOX}, /* setbbox */
+    UP_DATA_PATH(2),
+    UP_DATA_PATH(2),
+    UP_DATA_PATH(2),
+    UP_DATA_PATH(2),
+    UP_DATA_PATH(6),
+    UP_DATA_PATH(6),
+    UP_DATA_PATH(5),
+    UP_DATA_PATH(5),
+    UP_DATA_PATH(5),
+    UP_DATA_PATH(0),
+    {0, UPS_INITIAL, UPS_UCACHE}	/* ucache */
 };
 
 /* Declare operator procedures not declared in opextern.h. */
-int zsetbbox(P1(i_ctx_t *));
-private int zucache(P1(i_ctx_t *));
+int zsetbbox(i_ctx_t *);
+static int zucache(i_ctx_t *);
 
 #undef zp
 static const op_proc_t up_ops[UPATH_MAX_OP + 1] = {
@@ -295,7 +333,7 @@ static const op_proc_t up_ops[UPATH_MAX_OP + 1] = {
 };
 
 /* - ucache - */
-private int
+static int
 zucache(i_ctx_t *i_ctx_p)
 {
     /* A no-op for now. */
@@ -303,7 +341,7 @@ zucache(i_ctx_t *i_ctx_p)
 }
 
 /* <userpath> uappend - */
-private int
+static int
 zuappend(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -311,7 +349,7 @@ zuappend(i_ctx_t *i_ctx_p)
 
     if (code < 0)
 	return code;
-    if ((code = upath_append(op, i_ctx_p)) >= 0)
+    if ((code = upath_append(op, i_ctx_p, false)) >= 0)
 	code = gs_upmergepath(igs);
     gs_grestore(igs);
     if (code < 0)
@@ -321,7 +359,7 @@ zuappend(i_ctx_t *i_ctx_p)
 }
 
 /* <userpath> ueofill - */
-private int
+static int
 zueofill(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -329,7 +367,7 @@ zueofill(i_ctx_t *i_ctx_p)
 
     if (code < 0)
 	return code;
-    if ((code = upath_append(op, i_ctx_p)) >= 0)
+    if ((code = upath_append(op, i_ctx_p, CPSI_mode)) >= 0)
 	code = gs_eofill(igs);
     gs_grestore(igs);
     if (code < 0)
@@ -339,7 +377,7 @@ zueofill(i_ctx_t *i_ctx_p)
 }
 
 /* <userpath> ufill - */
-private int
+static int
 zufill(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -347,7 +385,7 @@ zufill(i_ctx_t *i_ctx_p)
 
     if (code < 0)
 	return code;
-    if ((code = upath_append(op, i_ctx_p)) >= 0)
+    if ((code = upath_append(op, i_ctx_p, CPSI_mode)) >= 0)
 	code = gs_fill(igs);
     gs_grestore(igs);
     if (code < 0)
@@ -358,7 +396,7 @@ zufill(i_ctx_t *i_ctx_p)
 
 /* <userpath> ustroke - */
 /* <userpath> <matrix> ustroke - */
-private int
+static int
 zustroke(i_ctx_t *i_ctx_p)
 {
     int code = gs_gsave(igs);
@@ -366,7 +404,7 @@ zustroke(i_ctx_t *i_ctx_p)
 
     if (code < 0)
 	return code;
-    if ((code = npop = upath_stroke(i_ctx_p, NULL)) >= 0)
+    if ((code = npop = upath_stroke(i_ctx_p, NULL, CPSI_mode)) >= 0)
 	code = gs_stroke(igs);
     gs_grestore(igs);
     if (code < 0)
@@ -377,21 +415,33 @@ zustroke(i_ctx_t *i_ctx_p)
 
 /* <userpath> ustrokepath - */
 /* <userpath> <matrix> ustrokepath - */
-private int
+static int
 zustrokepath(i_ctx_t *i_ctx_p)
 {
     gx_path save;
-    int code, npop;
+    gs_matrix saved_matrix;
+    int npop, code = gs_currentmatrix(igs, &saved_matrix);
 
+    if (code < 0)
+	return code;
     /* Save and reset the path. */
     gx_path_init_local(&save, imemory);
     gx_path_assign_preserve(&save, igs->path);
-    if ((code = npop = upath_stroke(i_ctx_p, NULL)) < 0 ||
+    if ((code = npop = upath_stroke(i_ctx_p, NULL, false)) < 0 ||
 	(code = gs_strokepath(igs)) < 0
 	) {
 	gx_path_assign_free(igs->path, &save);
 	return code;
     }
+    /*
+     * If a matrix was specified then restore the previous matrix.
+     */
+    if (npop > 1) {
+        if ((code = gs_setmatrix(igs, &saved_matrix)) < 0) {
+	    gx_path_assign_free(igs->path, &save);
+	    return code;
+        }
+    }
     gx_path_free(&save, "ustrokepath");
     pop(npop);
     return 0;
@@ -400,9 +450,9 @@ zustrokepath(i_ctx_t *i_ctx_p)
 /* <with_ucache> upath <userpath> */
 /* We do all the work in a procedure that is also used to construct */
 /* the UnpaintedPath user path for ImageType 2 images. */
-int make_upath(P5(i_ctx_t *i_ctx_p, ref *rupath, gs_state *pgs, gx_path *ppath,
-		  bool with_ucache));
-private int
+int make_upath(i_ctx_t *i_ctx_p, ref *rupath, gs_state *pgs, gx_path *ppath,
+	       bool with_ucache);
+static int
 zupath(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
@@ -410,38 +460,67 @@ zupath(i_ctx_t *i_ctx_p)
     check_type(*op, t_boolean);
     return make_upath(i_ctx_p, op, igs, igs->path, op->value.boolval);
 }
+
+/* Compute the path length for user path purposes. */
+static int 
+path_length_for_upath(const gx_path *ppath)
+{
+    gs_path_enum penum;
+    int op, size = 0;
+    gs_fixed_point pts[3];
+
+    gx_path_enum_init(&penum, ppath);
+    while ((op = gx_path_enum_next(&penum, pts)) != 0) {
+	switch (op) {
+	    case gs_pe_moveto:
+	    case gs_pe_lineto:
+		size += 3;
+		continue;
+	    case gs_pe_curveto:
+		size += 7;
+		continue;
+	    case gs_pe_closepath:
+		size += 1;
+		continue;
+	    default:
+		return_error(e_unregistered);
+	}
+    }
+    return size;
+}
+
 int
 make_upath(i_ctx_t *i_ctx_p, ref *rupath, gs_state *pgs, gx_path *ppath,
 	   bool with_ucache)
 {
     int size = (with_ucache ? 6 : 5);
     gs_path_enum penum;
+    gs_rect bbox;
     int op;
     ref *next;
     int code;
 
-    /* Compute the size of the user path array. */
-    {
-	gs_fixed_point pts[3];
 
-	gx_path_enum_init(&penum, ppath);
-	while ((op = gx_path_enum_next(&penum, pts)) != 0) {
-	    switch (op) {
-		case gs_pe_moveto:
-		case gs_pe_lineto:
-		    size += 3;
-		    continue;
-		case gs_pe_curveto:
-		    size += 7;
-		    continue;
-		case gs_pe_closepath:
-		    size += 1;
-		    continue;
-		default:
-		    return_error(e_unregistered);
-	    }
-	}
+    /* Compute the bounding box. */
+    if ((code = gs_upathbbox(pgs, &bbox, true)) < 0) {
+	/*
+	 * Note: Adobe throws 'nocurrentpoint' error, but the PLRM does
+	 * not list this as a possible error from 'upath', so if we are
+	 * not in CPSI compatibility mode, we set a reasonable default
+	 * bbox instead.
+	 */
+	if (code != e_nocurrentpoint || CPSI_mode)
+	    return code;
+	bbox.p.x = bbox.p.y = bbox.q.x = bbox.q.y = 0;
     }
+
+    code = path_length_for_upath(ppath);
+    if (code < 0)
+        return code;
+    size += code;
+    if (size >= 65536)
+        return_error(e_limitcheck);
+
     code = ialloc_ref_array(rupath, a_all | a_executable, size,
 			    "make_upath");
     if (code < 0)
@@ -449,24 +528,20 @@ make_upath(i_ctx_t *i_ctx_p, ref *rupath, gs_state *pgs, gx_path *ppath,
     /* Construct the path. */
     next = rupath->value.refs;
     if (with_ucache) {
-	if ((code = name_enter_string("ucache", next)) < 0)
-	    return code;
-	r_set_attrs(next, a_executable | l_new);
-	++next;
-    } {
-	gs_rect bbox;
-
-	gs_upathbbox(pgs, &bbox, true);
-	make_real_new(next, bbox.p.x);
-	make_real_new(next + 1, bbox.p.y);
-	make_real_new(next + 2, bbox.q.x);
-	make_real_new(next + 3, bbox.q.y);
-	next += 4;
-	if ((code = name_enter_string("setbbox", next)) < 0)
+        if ((code = name_enter_string(pgs->memory, "ucache", next)) < 0)
 	    return code;
 	r_set_attrs(next, a_executable | l_new);
 	++next;
     }
+    make_real_new(next, bbox.p.x);
+    make_real_new(next + 1, bbox.p.y);
+    make_real_new(next + 2, bbox.q.x);
+    make_real_new(next + 3, bbox.q.y);
+    next += 4;
+    if ((code = name_enter_string(pgs->memory, "setbbox", next)) < 0)
+	return code;
+    r_set_attrs(next, a_executable | l_new);
+    ++next;
     {
 	gs_point pts[3];
 
@@ -505,7 +580,7 @@ make_upath(i_ctx_t *i_ctx_p, ref *rupath, gs_state *pgs, gx_path *ppath,
 		default:
 		    return_error(e_unregistered);
 	    }
-	    if ((code = name_enter_string(opstr, next)) < 0)
+	    if ((code = name_enter_string(pgs->memory, opstr, next)) < 0)
 		return code;
 	    r_set_attrs(next, a_executable);
 	    ++next;
@@ -514,30 +589,116 @@ make_upath(i_ctx_t *i_ctx_p, ref *rupath, gs_state *pgs, gx_path *ppath,
     return 0;
 }
 
+
+static int
+zgetpath(i_ctx_t *i_ctx_p)
+{
+    os_ptr op = osp;
+    int i, code, path_size, leaf_count;
+    ref *main_ref, *operators[5];
+
+    push(1);
+    path_size = code = path_length_for_upath(igs->path);
+    if (code < 0)
+        return code;
+    leaf_count = (path_size + max_array_size - 1) / max_array_size;
+    code = ialloc_ref_array(op, a_all, leaf_count, "zgetpath_master");
+    if (code < 0)
+        return code;
+    if (path_size == 0)
+        return 0;
+
+    if (dict_find_string(systemdict, "moveto", &operators[1]) <= 0 ||
+  	dict_find_string(systemdict, "lineto", &operators[2]) <= 0 ||
+	dict_find_string(systemdict, "curveto", &operators[3]) <= 0 ||
+	dict_find_string(systemdict, "closepath", &operators[4]) <= 0)
+          return_error(e_undefined);
+
+    main_ref = op->value.refs;
+    for (i = 0; i < leaf_count; i++) {
+       int leaf_size = ( i == leaf_count - 1) ? path_size - i * max_array_size : max_array_size;
+       code = ialloc_ref_array(&main_ref[i], a_all | a_executable, leaf_size, "zgetpath_leaf");
+       if (code < 0)
+            return code;
+    }
+
+    {
+        int pe, j, k;
+        gs_path_enum penum;
+        static const int oper_count[5] = { 0, 2, 2, 6, 0 };
+	gs_point pts[3];
+        const double  *fts[6]; 
+
+        fts[0] = &pts[0].x;
+        fts[1] = &pts[0].y;
+        fts[2] = &pts[1].x;
+        fts[3] = &pts[1].y;
+        fts[4] = &pts[2].x;
+        fts[5] = &pts[2].y;
+
+        main_ref = op->value.refs;
+	gs_path_enum_copy_init(&penum, igs, false);
+        pe = gs_path_enum_next(&penum, pts);
+        k = 0;
+
+        for (i = 0; i < leaf_count; i++) {
+            int leaf_size = ( i == leaf_count - 1) ? path_size - i * max_array_size : max_array_size;
+            ref *leaf_ref = main_ref[i].value.refs;
+            
+            for (j = 0; j < leaf_size; j++) {
+                if (k < oper_count[pe])
+                   make_real_new(&leaf_ref[j], (float)*fts[k++]);
+                else {
+                    k = 0;
+                    ref_assign(&leaf_ref[j], operators[pe]);
+                    pe = gs_path_enum_next(&penum, pts);
+                    if (pe == 0)
+                        goto out;
+                    if (pe >= 5)
+                        return_error(e_unregistered);
+                }
+            }
+        }
+     }
+  out:
+  return 0;
+}
+
 /* ------ Internal routines ------ */
 
 /* Append a user path to the current path. */
-private int
-upath_append(os_ptr oppath, i_ctx_t *i_ctx_p)
+static inline int
+upath_append_aux(os_ptr oppath, i_ctx_t *i_ctx_p, int *pnargs, bool upath_compat)
 {
+    upath_state ups = UPS_INITIAL;
+    ref opcodes;
+
+    if (r_has_type(oppath, t__invalid))
+	return_error(e_stackunderflow);
+    if (!r_is_array(oppath))
+	return_error(e_typecheck);
     check_read(*oppath);
     gs_newpath(igs);
-/****** ROUND tx AND ty ******/
-    if (r_has_type(oppath, t_array) && r_size(oppath) == 2 &&
-	r_has_type(oppath->value.refs + 1, t_string)
-	) {			/* 1st element is operators, 2nd is operands */
-	const ref *operands = oppath->value.refs;
+    /****** ROUND tx AND ty ******/
+    
+    if ( r_size(oppath) == 2 &&
+	 array_get(imemory, oppath, 1, &opcodes) >= 0 &&
+         r_has_type(&opcodes, t_string)
+	) {			/* 1st element is operands, 2nd is operators */
+	ref operands;
 	int code, format;
 	int repcount = 1;
 	const byte *opp;
 	uint ocount, i = 0;
 
-	code = num_array_format(operands);
+        array_get(imemory, oppath, 0, &operands);
+        code = num_array_format(&operands);
 	if (code < 0)
 	    return code;
 	format = code;
-	opp = oppath->value.refs[1].value.bytes;
-	ocount = r_size(&oppath->value.refs[1]);
+	check_read(opcodes);
+	opp = opcodes.value.bytes;
+	ocount = r_size(&opcodes);
 	while (ocount--) {
 	    byte opx = *opp++;
 
@@ -546,13 +707,26 @@ upath_append(os_ptr oppath, i_ctx_t *i_ctx_p)
 	    else if (opx > UPATH_MAX_OP)
 		return_error(e_rangecheck);
 	    else {		/* operator */
+		const up_data_t data = up_data[opx];
+
+		*pnargs = 0;	/* in case of error */
+		if (upath_compat && opx == upath_op_ucache) {
+		    /* CPSI does not complain about incorrect ucache
+		       placement, even though PLRM3 says it's illegal. */
+		    ups = ups > UPS_UCACHE ? ups : data.state_after;
+		} else {
+		    if (!(ups & data.states_before))
+			return_error(e_typecheck);
+		    ups = data.state_after;
+		}
 		do {
 		    os_ptr op = osp;
-		    byte opargs = up_nargs[opx];
+		    byte opargs = data.num_args;
 
 		    while (opargs--) {
 			push(1);
-			code = num_array_get(operands, format, i++, op);
+			(*pnargs)++; /* in case of error */
+			code = num_array_get(imemory, &operands, format, i++, op);
 			switch (code) {
 			    case t_integer:
 				r_set_type_attrs(op, t_integer, 0);
@@ -572,7 +746,7 @@ upath_append(os_ptr oppath, i_ctx_t *i_ctx_p)
 		repcount = 1;
 	    }
 	}
-    } else if (r_is_array(oppath)) {	/* Ordinary executable array. */
+    } else {	/* Ordinary executable array. */
 	const ref *arp = oppath;
 	uint ocount = r_size(oppath);
 	long index = 0;
@@ -584,8 +758,10 @@ upath_append(os_ptr oppath, i_ctx_t *i_ctx_p)
 	    ref rup;
 	    ref *defp;
 	    os_ptr op = osp;
+	    up_data_t data;
 
-	    array_get(arp, index, &rup);
+	    *pnargs = argcount;
+	    array_get(imemory, arp, index, &rup);
 	    switch (r_type(&rup)) {
 		case t_integer:
 		case t_real:
@@ -594,12 +770,10 @@ upath_append(os_ptr oppath, i_ctx_t *i_ctx_p)
 		    *op = rup;
 		    break;
 		case t_name:
-		    if (!r_has_attr(&rup, a_executable))
-			return_error(e_typecheck);
-		    if (dict_find(systemdict, &rup, &defp) <= 0)
-			return_error(e_undefined);
-		    if (r_btype(defp) != t_operator)
-			return_error(e_typecheck);
+		    if (!r_has_attr(&rup, a_executable) ||
+			dict_find(systemdict, &rup, &defp) <= 0 ||
+			r_btype(defp) != t_operator)
+			return_error(e_typecheck); /* all errors = typecheck */
 		    goto xop;
 		case t_operator:
 		    defp = &rup;
@@ -609,35 +783,75 @@ upath_append(os_ptr oppath, i_ctx_t *i_ctx_p)
 		    for (opx = 0; opx <= UPATH_MAX_OP; opx++)
 			if (oproc == up_ops[opx])
 			    break;
-		    if (opx > UPATH_MAX_OP || argcount != up_nargs[opx])
+		    if (opx > UPATH_MAX_OP)
 			return_error(e_typecheck);
-		    code = (*oproc)(i_ctx_p);
-		    if (code < 0)
-			return code;
-		    argcount = 0;
+		    data = up_data[opx];
+		    if (argcount != data.num_args)
+			return_error(e_typecheck);
+		    if (upath_compat && opx == upath_op_ucache) {
+			/* CPSI does not complain about incorrect ucache
+			   placement, even though PLRM3 says it's illegal. */
+			ups = ups > UPS_UCACHE ? ups : data.state_after;
+		    } else {
+			if (!(ups & data.states_before))
+			    return_error(e_typecheck);
+			ups = data.state_after;
+		    }
+		    code = (*up_ops[opx])(i_ctx_p);
+		    if (code < 0) {
+			if (code == e_nocurrentpoint)
+                            return_error(e_rangecheck); /* CET 11-22 */
+                        return code;
+		    }
+                    argcount = 0;
 		    break;
 		default:
 		    return_error(e_typecheck);
 	    }
 	}
-	if (argcount)
+	if (argcount) {
+	    *pnargs = argcount;
 	    return_error(e_typecheck);	/* leftover args */
-    } else
-	return_error(e_typecheck);
+	}
+    }
+    if (ups < UPS_SETBBOX)
+	return_error(e_typecheck);	/* no setbbox */
+    if (ups == UPS_SETBBOX && upath_compat) {
+	/*
+	 * In CPSI compatibility mode, an empty path with a setbbox also
+	 * does a moveto (but only if the path is empty).  Since setbbox
+	 * was the last operator, its operands are still on the o-stack.
+	 */
+	osp += 2;
+	return zmoveto(i_ctx_p);
+    }
+    return 0;
+}
+static int
+upath_append(os_ptr oppath, i_ctx_t *i_ctx_p, bool upath_compat)
+{
+    int nargs = 0;
+    int code = upath_append_aux(oppath, i_ctx_p, &nargs, upath_compat);
+
+    if (code < 0) {
+	/* Pop args on error, to match Adobe interpreters. */
+	pop(nargs);
+	return code;
+    }
     return 0;
 }
 
 /* Append a user path to the current path, and then apply or return */
 /* a transformation if one is supplied. */
-private int
-upath_stroke(i_ctx_t *i_ctx_p, gs_matrix *pmat)
+static int
+upath_stroke(i_ctx_t *i_ctx_p, gs_matrix *pmat, bool upath_compat)
 {
     os_ptr op = osp;
     int code, npop;
     gs_matrix mat;
 
-    if ((code = read_matrix(op, &mat)) >= 0) {
-	if ((code = upath_append(op - 1, i_ctx_p)) >= 0) {
+    if ((code = read_matrix(imemory, op, &mat)) >= 0) {
+	if ((code = upath_append(op - 1, i_ctx_p, upath_compat)) >= 0) {
 	    if (pmat)
 		*pmat = mat;
 	    else
@@ -645,7 +859,7 @@ upath_stroke(i_ctx_t *i_ctx_p, gs_matrix *pmat)
 	}
 	npop = 2;
     } else {
-	if ((code = upath_append(op, i_ctx_p)) >= 0)
+	if ((code = upath_append(op, i_ctx_p, upath_compat)) >= 0)
 	    if (pmat)
 		gs_make_identity(pmat);
 	npop = 1;
@@ -673,5 +887,7 @@ const op_def zupath_l2_op_defs[] =
     {"1upath", zupath},
     {"1ustroke", zustroke},
     {"1ustrokepath", zustrokepath},
+		/* Path access for PDF */
+    {"0.getpath", zgetpath},
     op_def_end(0)
 };
